@@ -1,6 +1,7 @@
-/* 
+/*
  *  Copyright (C) 1999-2002 Bernd Gehrmann
  *                          bernd@mail.berlios.de
+ *  Copyright (c) 2002-2004 Christian Loose <christian.loose@kdemail.net>
  *
  * This program may be distributed under the terms of the Q Public
  * License as defined by Trolltech AS of Norway and appearing in the
@@ -17,10 +18,9 @@
 
 #include <kparts/mainwindow.h>
 
-class QLabel;
-class CervisiaPart;
 class KRecentFilesAction;
 
+
 /**
  * A basic shell that embeds the Cervisia part directly to make a standalone
  * GUI available.
@@ -30,33 +30,34 @@ class CervisiaShell : public KParts::MainWindow
     Q_OBJECT
 
 public:
-    CervisiaShell( const char *name=0 );
+    CervisiaShell(const char* name=0);
     virtual ~CervisiaShell();
 
-    void restorePseudo(const QString &dirname);
-
 public slots:
-    void slotOpenSandbox();
+    void openURL();
+    void openURL(const KURL& url);
     void slotConfigureKeys();
     void slotConfigureToolBars();
-    void slotExit();
-    
+
 protected slots:
-    void slotChangeFilterStatus(QString status);
+    void slotNewToolbarConfig();
 
 protected:
     void setupActions();
-
+    
     bool queryExit();
-    virtual void readProperties(KConfig *config);
-    virtual void saveProperties(KConfig *config);
+    virtual void readProperties(KConfig* config);
+    virtual void saveProperties(KConfig* config);
 
 private:
-    CervisiaPart *part;
-    QLabel *filterLabel;
+    void readSettings();
+    void writeSettings();
 
+    KParts::ReadOnlyPart* m_part;
+    QString               m_lastOpenDir;
 };
 
+
 #endif // CERVISIASHELL_H
 
 // Local Variables:
