@@ -19,18 +19,13 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlistbox.h>
-#include <qmultilineedit.h>
+#include <ktextedit.h>
 #include <kconfig.h>
 #include <klocale.h>
 
 #include "cvsservice_stub.h"
 #include "diffdlg.h"
 
-#include <kdeversion.h>
-#if KDE_VERSION < KDE_MAKE_VERSION(3,1,90)
-#include "configutils.h"
-#endif
-
 
 CommitDialog::CommitDialog(KConfig& cfg, CvsService_stub* service, 
                            QWidget *parent, const char *name)
@@ -65,8 +60,9 @@ CommitDialog::CommitDialog(KConfig& cfg, CvsService_stub* service,
     QLabel *messagelabel = new QLabel(i18n("&Log message:"), mainWidget);
     layout->addWidget(messagelabel);
 
-    edit = new QMultiLineEdit(mainWidget);
+    edit = new KTextEdit(mainWidget);
     messagelabel->setBuddy(edit);
+    edit->setCheckSpellingEnabled(true);
     edit->setFocus();
     edit->setMinimumSize(400, 100);
     layout->addWidget(edit, 10);
@@ -78,22 +74,14 @@ CommitDialog::CommitDialog(KConfig& cfg, CvsService_stub* service,
 
     setHelp("commitingfiles");
 
-#if KDE_IS_VERSION(3,1,90)
     QSize size = configDialogSize(partConfig, "CommitDialog");
-#else
-    QSize size = Cervisia::configDialogSize(this, partConfig, "CommitDialog");
-#endif
     resize(size);
 }
 
 
 CommitDialog::~CommitDialog()
 {
-#if KDE_IS_VERSION(3,1,90)
     saveDialogSize(partConfig, "CommitDialog");
-#else
-    Cervisia::saveDialogSize(this, partConfig, "CommitDialog");
-#endif
 }
 
 
@@ -196,11 +184,18 @@ void CommitDialog::diffClicked()
 
 void CommitDialog::showDiffDialog(const QString& fileName)
 {
-    DiffDialog *l = new DiffDialog(partConfig, this, "diffdialog", true);
+    DiffDialog *l = new DiffDialog(partConfig, this, "diffdialog");
+    
+    // disable diff button so user doesn't open the same diff several times (#83018)
+    enableButton(User1, false);
+    
     if (l->parseCvsDiff(cvsService, fileName, "", ""))
         l->show();
     else
         delete l;
+    
+    // re-enable diff button
+    enableButton(User1, true);
 }
 
 
