@@ -1,7 +1,7 @@
 /*
  *  Copyright (C) 1999-2002 Bernd Gehrmann
  *                          bernd@mail.berlios.de
- *  Copyright (c) 2002-2003 Christian Loose <christian.loose@hamburg.de>
+ *  Copyright (c) 2002-2004 Christian Loose <christian.loose@kdemail.net>
  *
  * This program may be distributed under the terms of the Q Public
  * License as defined by Trolltech AS of Norway and appearing in the
@@ -26,6 +26,7 @@
 #include <qwhatsthis.h>
 #include <kconfig.h>
 #include <kdebug.h>
+#include <kfiledialog.h>
 #include <kfinddialog.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
@@ -35,6 +36,7 @@
 #include <krfcdate.h>
 #include <krun.h>
 #include <kurl.h>
+#include <kdeversion.h>
 
 #include "cvsservice_stub.h"
 #include "annotatedlg.h"
@@ -46,16 +48,12 @@
 #include "logtree.h"
 #include "misc.h"
 #include "progressdlg.h"
-
-#include <kdeversion.h>
-#if KDE_VERSION < KDE_MAKE_VERSION(3,1,90)
-#include "configutils.h"
-#endif
+#include "patchoptiondlg.h"
 
 
 LogDialog::LogDialog(KConfig& cfg, QWidget *parent, const char *name)
     : KDialogBase(parent, name, false, QString::null,
-                  Ok | Close | Help | User1 | User2 | User3, Close, true,
+                  Ok | Apply | Close | Help | User1 | User2 | User3, Close, true,
                   KGuiItem(i18n("&Annotate")),
                   KGuiItem(i18n("&Diff")),
                   KGuiItem(i18n("&Find..."), "find"))
@@ -174,25 +172,21 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent, const char *name)
     connect( this, SIGNAL(user3Clicked()),
              this, SLOT(findClicked()) );
 
-#if KDE_IS_VERSION(3,1,90)
+#if KDE_IS_VERSION(3,2,90)
+    setButtonGuiItem(Ok, KGuiItem(i18n("to view something", "&View"),"fileopen","",""));
+#else
     if( KGlobalSettings::showIconsOnPushButtons() )
       actionButton(Ok)->setIconSet(SmallIcon(QString::fromLatin1("fileopen")));
-#else
-    actionButton(Ok)->setIconSet(SmallIcon(QString::fromLatin1("fileopen")));
-#endif
     setButtonText(Ok, i18n("to view something", "&View"));
     setButtonTip(Ok, QString::null);
     setButtonWhatsThis(Ok, QString::null);
-
+#endif
+    setButtonGuiItem(Apply, KGuiItem(i18n("Create Patch..."), "", "", ""));
     setHelp("browsinglogs");
 
     setWFlags(Qt::WDestructiveClose | getWFlags());
 
-#if KDE_IS_VERSION(3,1,90)
     QSize size = configDialogSize(partConfig, "LogDialog");
-#else
-    QSize size = Cervisia::configDialogSize(this, partConfig, "LogDialog");
-#endif
     resize(size);
 
     KConfigGroupSaver cs(&partConfig, "LogDialog");
@@ -202,11 +196,7 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent, const char *name)
 
 LogDialog::~LogDialog()
 {
-#if KDE_IS_VERSION(3,1,90)
     saveDialogSize(partConfig, "LogDialog");
-#else
-    Cervisia::saveDialogSize(this, partConfig, "LogDialog");
-#endif
 
     KConfigGroupSaver cs(&partConfig, "LogDialog");
     partConfig.writeEntry("ShowTab", tabWidget->currentPageIndex());
@@ -267,7 +257,7 @@ bool LogDialog::parseCvsLog(CvsService_stub* service, const QString& fileName)
                     }
                     if( rev != "1.1.1" )
                     {
-                        TagInfo *taginfo = new TagInfo;
+                        LogDialogTagInfo *taginfo = new LogDialogTagInfo;
                         taginfo->rev = rev;
                         taginfo->tag = tag;
                         taginfo->branchpoint = branchpoint;
@@ -291,13 +281,19 @@ bool LogDialog::parseCvsLog(CvsService_stub* service, const QString& fileName)
                 break;
             case Author:
                 {
-                    QStringList strlist = splitLine(line);
-                    // convert date in ISO format (YYYY-MM-DDTHH:MM:SS)
-                    strlist[1].replace('/', '-');
-                    strlist[2].truncate(8); // Time foramt is HH:MM:SS
-                    logInfo.m_dateTime.setTime_t(KRFCDate::parseDateISO8601(strlist[1] + 'T' + strlist[2]));
-                    logInfo.m_author = strlist[4];
-                    logInfo.m_author.truncate(logInfo.m_author.length() - 1); // remove trailing ';'
+                    QStringList strList = QStringList::split(";", line);
+
+                    // convert date into ISO format (YYYY-MM-DDTHH:MM:SS)
+                    int len = strList[0].length();
+                    QString dateTimeStr = strList[0].right(len-6); // remove 'date: '
+                    dateTimeStr.replace('/', '-');
+
+                    QString date = dateTimeStr.section(' ', 0, 0);
+                    QString time = dateTimeStr.section(' ', 1, 1);
+                    logInfo.m_dateTime.setTime_t(KRFCDate::parseDateISO8601(date + 'T' + time));
+
+                    logInfo.m_author = strList[1].section(':', 1, 1).stripWhiteSpace();
+
                     state = Branches;
                 }
                 break;
@@ -330,7 +326,7 @@ bool LogDialog::parseCvsLog(CvsService_stub* service, const QString& fileName)
                         branchrev = rev.left(pos2);
 
                     // Build Cervisia::TagInfo for logInfo
-                    QPtrListIterator<TagInfo> it(tags);
+                    QPtrListIterator<LogDialogTagInfo> it(tags);
                     for( ; it.current(); ++it )
                     {
                         if( rev == it.current()->rev )
@@ -369,7 +365,7 @@ bool LogDialog::parseCvsLog(CvsService_stub* service, const QString& fileName)
 
     tagcombo[0]->insertItem(QString::null);
     tagcombo[1]->insertItem(QString::null);
-    QPtrListIterator<TagInfo> it(tags);
+    QPtrListIterator<LogDialogTagInfo> it(tags);
     for( ; it.current(); ++it )
     {
         QString str = it.current()->tag;
@@ -429,6 +425,54 @@ void LogDialog::slotOk()
 }
 
 
+void LogDialog::slotApply()
+{
+    if( selectionA.isEmpty() )
+    {
+        KMessageBox::information(this,
+            i18n("Please select revision A or revisions A and B first."),
+            "Cervisia");
+        return;
+    }
+    
+    Cervisia::PatchOptionDialog optionDlg;
+    if( optionDlg.exec() == KDialogBase::Rejected )
+        return;
+    
+    QString format      = optionDlg.formatOption();
+    QString diffOptions = optionDlg.diffOptions();
+    
+    DCOPRef job = cvsService->diff(filename, selectionA, selectionB, diffOptions,
+                                   format);
+    if( !cvsService->ok() )
+        return;
+
+    ProgressDialog dlg(this, "Diff", job, "", i18n("CVS Diff"));
+    if( !dlg.execute() )
+        return;
+
+    QString fileName = KFileDialog::getSaveFileName();
+    if( fileName.isEmpty() )
+        return;
+
+    QFile f(fileName);
+    if( !f.open(IO_WriteOnly) )
+    {
+        KMessageBox::sorry(this,
+                           i18n("Could not open file for writing."),
+                           "Cervisia");
+        return;
+    }
+
+    QTextStream t(&f);
+    QString line;
+    while( dlg.getLine(line) )
+        t << line << '\n';
+
+    f.close();    
+}
+
+
 void LogDialog::findClicked()
 {
     KFindDialog dlg(this);
@@ -489,7 +533,7 @@ void LogDialog::revisionSelected(QString rev, bool rmb)
 }
 
 
-void LogDialog::tagSelected(TagInfo* tag, bool rmb)
+void LogDialog::tagSelected(LogDialogTagInfo* tag, bool rmb)
 {
     if (tag->branchpoint.isEmpty())
         revisionSelected(tag->rev, rmb);
