@@ -75,7 +75,7 @@ private slots:
     void itemExecuted(QListViewItem *item);
     
 private:
-    void updateItem(const QString &filename, Cervisia::Entry::Status status, bool isdir);
+    void updateItem(const QString &filename, Cervisia::EntryStatus status, bool isdir);
     void rememberSelection(bool recursive);
     void syncSelection();
     void markUpdated(bool laststage, bool success);
