@@ -30,6 +30,7 @@
 
 
 using Cervisia::Entry;
+using Cervisia::EntryStatus;
 
 
 // ------------------------------------------------------------------------------
@@ -93,7 +94,7 @@ UpdateDirItem::UpdateDirItem(UpdateView* parent,
  * Update the status of an item; if it doesn't exist yet, create new one
  */
 void UpdateDirItem::updateChildItem(const QString& name,
-                                    Entry::Status status,
+                                    EntryStatus status,
                                     bool isdir)
 {
     if (UpdateItem* item = findItem(name))
@@ -134,11 +135,11 @@ void UpdateDirItem::updateEntriesItem(const Entry& entry,
         if (isFileItem(item))
         {
             UpdateFileItem* fileItem = static_cast<UpdateFileItem*>(item);
-            if (fileItem->entry().m_status == Entry::NotInCVS ||
-                fileItem->entry().m_status == Entry::LocallyRemoved ||
-                entry.m_status == Entry::LocallyAdded ||
-                entry.m_status == Entry::LocallyRemoved ||
-                entry.m_status == Entry::Conflict)
+            if (fileItem->entry().m_status == Cervisia::NotInCVS ||
+                fileItem->entry().m_status == Cervisia::LocallyRemoved ||
+                entry.m_status == Cervisia::LocallyAdded ||
+                entry.m_status == Cervisia::LocallyRemoved ||
+                entry.m_status == Cervisia::Conflict)
             {
                 fileItem->setStatus(entry.m_status);
             }
@@ -181,7 +182,7 @@ void UpdateDirItem::scanDirectory()
             else
             {
                 entry.m_type = Entry::File;
-                entry.m_status = Entry::NotInCVS;
+                entry.m_status = Cervisia::NotInCVS;
                 createFileItem(entry);
             }
         }
@@ -191,21 +192,42 @@ void UpdateDirItem::scanDirectory()
 
 UpdateDirItem* UpdateDirItem::createDirItem(const Entry& entry)
 {
-    UpdateDirItem* dirItem = new UpdateDirItem(this, entry);
-
-    m_itemsByName.insert(entry.m_name, dirItem);
-
-    return dirItem;
+    UpdateItem* item(insertItem(new UpdateDirItem(this, entry)));
+    assert(isDirItem(item));
+    return static_cast<UpdateDirItem*>(item);
 }
 
 
 UpdateFileItem* UpdateDirItem::createFileItem(const Entry& entry)
 {
-    UpdateFileItem* fileItem = new UpdateFileItem(this, entry);
+    UpdateItem* item(insertItem(new UpdateFileItem(this, entry)));
+    assert(isFileItem(item));
+    return static_cast<UpdateFileItem*>(item);
+}
 
-    m_itemsByName.insert(entry.m_name, fileItem);
 
-    return fileItem;
+UpdateItem* UpdateDirItem::insertItem(UpdateItem* item)
+{
+    QPair<TMapItemsByName::iterator, bool> result
+        = m_itemsByName.insert(TMapItemsByName::value_type(item->entry().m_name, item));
+    if (!result.second)
+    {
+        // OK, an item with that name already exists. If the item type is the
+        // same then keep the old one to preserve it's status information
+        UpdateItem* existingItem = *result.first;
+        if (existingItem->rtti() == item->rtti())
+        {
+            delete item;
+            item = existingItem;
+        }
+        else
+        {
+            delete existingItem;
+            *result.first = item;
+        }
+    }
+
+    return item;
 }
 
 
@@ -242,7 +264,7 @@ void UpdateDirItem::syncWithEntries()
             if( line[0] != '/' )
                 continue;
 
-            entry.m_type = isDir ? Entry::Dir : Cervisia::Entry::File;
+            entry.m_type = isDir ? Entry::Dir : Entry::File;
             entry.m_name = line.section('/', 1, 1);
 
             if (isDir)
@@ -262,15 +284,15 @@ void UpdateDirItem::syncWithEntries()
                 entry.m_dateTime = QFileInfo(path + entry.m_name).lastModified();
 
                 if( rev == "0" )
-                    entry.m_status = Entry::LocallyAdded;
+                    entry.m_status = Cervisia::LocallyAdded;
                 else if( rev.length() > 2 && rev[0] == '-' )
                 {
-                    entry.m_status = Entry::LocallyRemoved;
+                    entry.m_status = Cervisia::LocallyRemoved;
                     rev.remove(0, 1);
                 }
                 else if (timestamp.find('+') >= 0)
                 {
-                    entry.m_status = Entry::Conflict;
+                    entry.m_status = Cervisia::Conflict;
                 }
                 else
                 {
@@ -278,7 +300,7 @@ void UpdateDirItem::syncWithEntries()
                     QDateTime fileDateUTC;
                     fileDateUTC.setTime_t(entry.m_dateTime.toTime_t(), Qt::UTC);
                     if (date != fileDateUTC)
-                        entry.m_status = Entry::LocallyModified;
+                        entry.m_status = Cervisia::LocallyModified;
                 }
 
                 entry.m_revision = rev;
@@ -309,7 +331,7 @@ void UpdateDirItem::syncWithDirectory()
             // is file removed?
             if (!dir.exists(it.key()))
             {
-                fileItem->setStatus(Entry::Removed);
+                fileItem->setStatus(Cervisia::Removed);
                 fileItem->setRevTag(QString::null, QString::null);
             }
         }
@@ -418,7 +440,7 @@ UpdateFileItem::UpdateFileItem(UpdateDirItem* parent, const Entry& entry)
 }
 
 
-void UpdateFileItem::setStatus(Entry::Status status)
+void UpdateFileItem::setStatus(EntryStatus status)
 {
     if (status != m_entry.m_status)
     {
@@ -442,11 +464,14 @@ bool UpdateFileItem::applyFilter(UpdateView::Filter filter)
     bool visible(true);
     if (filter & UpdateView::OnlyDirectories)
         visible = false;
-    if ((filter & UpdateView::NoUpToDate) && (entry().m_status == Entry::UpToDate))
+    
+    bool unmodified = (entry().m_status == Cervisia::UpToDate) || 
+                      (entry().m_status == Cervisia::Unknown);
+    if ((filter & UpdateView::NoUpToDate) && unmodified)
         visible = false;
-    if ((filter & UpdateView::NoRemoved) && (entry().m_status == Entry::Removed))
+    if ((filter & UpdateView::NoRemoved) && (entry().m_status == Cervisia::Removed))
         visible = false;
-    if ((filter & UpdateView::NoNotInCVS) && (entry().m_status == Entry::NotInCVS))
+    if ((filter & UpdateView::NoNotInCVS) && (entry().m_status == Cervisia::NotInCVS))
         visible = false;
 
     setVisible(visible);
@@ -512,12 +537,12 @@ void UpdateFileItem::setDate(const QDateTime& date)
 void UpdateFileItem::markUpdated(bool laststage,
                                  bool success)
 {
-    Entry::Status newstatus = m_entry.m_status;
+    EntryStatus newstatus = m_entry.m_status;
 
     if (laststage)
     {
-        if (undefinedState() && m_entry.m_status != Entry::NotInCVS)
-            newstatus = success? Entry::UpToDate : Entry::Unknown;
+        if (undefinedState() && m_entry.m_status != Cervisia::NotInCVS)
+            newstatus = success? Cervisia::UpToDate : Cervisia::Unknown;
         setStatus(newstatus);
     }
     else
@@ -530,31 +555,31 @@ int UpdateFileItem::statusClass() const
     int iResult(0);
     switch (entry().m_status)
     {
-    case Entry::Conflict:
+    case Cervisia::Conflict:
         iResult = 0;
         break;
-    case Entry::LocallyAdded:
+    case Cervisia::LocallyAdded:
         iResult = 1;
         break;
-    case Entry::LocallyRemoved:
+    case Cervisia::LocallyRemoved:
         iResult = 2;
         break;
-    case Entry::LocallyModified:
+    case Cervisia::LocallyModified:
         iResult = 3;
         break;
-    case Entry::Updated:
-    case Entry::NeedsUpdate:
-    case Entry::Patched:
-    case Entry::Removed:
-    case Entry::NeedsPatch:
-    case Entry::NeedsMerge:
+    case Cervisia::Updated:
+    case Cervisia::NeedsUpdate:
+    case Cervisia::Patched:
+    case Cervisia::Removed:
+    case Cervisia::NeedsPatch:
+    case Cervisia::NeedsMerge:
         iResult = 4;
         break;
-    case Entry::NotInCVS:
+    case Cervisia::NotInCVS:
         iResult = 5;
         break;
-    case Entry::UpToDate:
-    case Entry::Unknown:
+    case Cervisia::UpToDate:
+    case Cervisia::Unknown:
         iResult = 6;
         break;
     }
@@ -607,7 +632,7 @@ QString UpdateFileItem::text(int column) const
         result = entry().m_name;
         break;
     case Status:
-        result = entry().statusToString();
+        result = toString(entry().m_status);
         break;
     case Revision:
         result = entry().m_revision;
@@ -636,25 +661,25 @@ void UpdateFileItem::paintCell(QPainter *p,
     QColor color;
     switch (m_entry.m_status)
     {
-    case Entry::Conflict:
+    case Cervisia::Conflict:
         color = view->conflictColor();
         break;
-    case Entry::LocallyAdded:
-    case Entry::LocallyModified:
-    case Entry::LocallyRemoved:
+    case Cervisia::LocallyAdded:
+    case Cervisia::LocallyModified:
+    case Cervisia::LocallyRemoved:
         color = view->localChangeColor();
         break;
-    case Entry::NeedsMerge:
-    case Entry::NeedsPatch:
-    case Entry::NeedsUpdate:
-    case Entry::Patched:
-    case Entry::Removed:
-    case Entry::Updated:
+    case Cervisia::NeedsMerge:
+    case Cervisia::NeedsPatch:
+    case Cervisia::NeedsUpdate:
+    case Cervisia::Patched:
+    case Cervisia::Removed:
+    case Cervisia::Updated:
         color = view->remoteChangeColor();
         break;
-    case Entry::NotInCVS:
-    case Entry::Unknown:
-    case Entry::UpToDate:
+    case Cervisia::NotInCVS:
+    case Cervisia::Unknown:
+    case Cervisia::UpToDate:
         break;
     }
 
