@@ -22,9 +22,10 @@
 
 #include <qstringlist.h>
 
-#include "catalog.h"
+#include "poinfo.h"
 #include <kgenericfactory.h>
 
+using namespace KBabel;
 
 typedef KGenericFactory<KPoPlugin> POFactory;
 K_EXPORT_COMPONENT_FACTORY(kfile_po, POFactory("kfile_po"))
@@ -51,9 +52,9 @@ bool KPoPlugin::readInfo(KFileMetaInfo& metaInfo, uint)
 {
   PoInfo poInfo;
   QStringList wordList;
-  Catalog::IOStatus status = Catalog::info(metaInfo.path(), poInfo,
+  ConversionStatus status = PoInfo::info(metaInfo.path(), poInfo,
 					   wordList, false, false);
-  if (status == Catalog::OK) {
+  if (status == OK) {
     KFileMetaInfoGroup group = appendGroup(metaInfo, "CatalogInfo");
 
     appendItem(group, "Total", poInfo.total);
