@@ -3,7 +3,7 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-		2001-2003 by Stanislav Visnovsky <visnovsky@kde.org>
+		2001-2004 by Stanislav Visnovsky <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,7 +36,9 @@
 #include <kprocess.h>
 #include <qptrlist.h>
 
-#include "settings.h"
+#include "projectsettings.h"
+#include "kbproject.h"
+#include "catalog.h"
 #include "catalogmanagerview.h"
 
 class CatManListItem;
@@ -46,23 +48,22 @@ class QTimer;
 class KProgress;
 class KAction;
 class KConfig;
-class CatalogManagerPreferences;
 class FindInFilesDialog;
 
 namespace KBabel
 {
     class PoInfo;
+    class ProjectDialog;
 }
 
 class CatalogManager : public KMainWindow
 {
    Q_OBJECT
 public:
-   CatalogManager(QString configfile = QString::null);
-   CatalogManager(CatManSettings settings);
+   CatalogManager(QString configfile = KBABEL_DEFAULTPROJECT);
    ~CatalogManager();
 
-   CatManSettings settings() const;
+   KBabel::CatManSettings settings() const;
    /**
    * Sets the window, in which the files should be opened.
    * This is set by KBabel::openCatalogManager
@@ -81,7 +82,8 @@ public:
    static QStringList _toBeSearched;
 
 public slots:
-   void setSettings(CatManSettings newSettings);
+   /*** updates the settings from the project */
+   void updateSettings();
    void enableMenuForFiles(bool enable);
    void selectedChanged(uint actionValue);
    virtual void slotHelp();
@@ -90,11 +92,15 @@ public slots:
    virtual void replace();
    virtual void stopSearching();
    virtual void optionsPreferences();
-   virtual void optionsKeys();
-   virtual void optionsEditToolbars();
    virtual void optionsShowStatusbar(bool on);
    virtual void dummySlot() {}
    
+    void projectNew();
+    void projectOpen();
+    void projectClose();
+    void projectConfigure();
+    void changeProjectActions(const QString& project);
+
    virtual void clearProgressBar();
    virtual void prepareProgressBar(QString msg, int max);
 
@@ -110,7 +116,7 @@ protected slots:
    virtual bool queryClose();
 
 signals:
-   void settingsChanged(CatManSettings);
+   void settingsChanged(KBabel::CatManSettings);
    void signalQuit();
    void searchStopped();
 
@@ -121,7 +127,6 @@ private:
    void saveView();
    
    void saveSettings( QString configFile = QString::null );
-   void restoreSettings( QString configFile = QString::null );
 
    void setupActions();
    void setupStatusBar();
@@ -149,6 +154,14 @@ private slots:
    void spellcheck();
    
    void newToolbarConfig();
+
+   /*** updates views and _settings variable */
+   void restoreSettings();
+   
+   void enableActions();
+   void disableActions();
+   
+   void enableActions(bool enable);
    
 private:
    CatalogManagerView* _catalogManager;
@@ -159,7 +172,7 @@ private:
 
    FindInFilesDialog* _findDialog;
    FindInFilesDialog* _replaceDialog;
-   CatalogManagerPreferences* _prefDialog;
+   KBabel::ProjectDialog* _prefDialog;
    
    // update progress bar
    KProgress* _progressBar;
@@ -175,7 +188,7 @@ private:
    QTimer* _timerFind;
    bool _searchStopped;
    
-   CatManSettings _settings;
+   KBabel::CatManSettings _settings;
    KBabel::MiscSettings _miscSettings;
    
     // options used in findNextFile
@@ -183,6 +196,7 @@ private:
    
    // project configuration file
    QString _configFile;
+   KBabel::Project::Ptr _project;
 
    KConfig* config;
 
