@@ -3,7 +3,7 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-                2001-2003 by Stanislav Visnovsky
+                2001-2004 by Stanislav Visnovsky
                             <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,6 @@
 
 #include "resources.h"
 #include "multiroughtransdlg.h"
-#include "prefwidgets.h"
 #include "msgfmt.h"
 #include "kbmailer.h"
 #include "validateprogress.h"
@@ -58,6 +57,7 @@
 #include <kio/netaccess.h>
 #include <kprogress.h>
 #include <kwin.h>
+#include <ktar.h>
 
 #include <qfileinfo.h>
 #include <qdir.h>
@@ -178,7 +178,7 @@ CatalogManagerView::CatalogManagerView(QString configFile, QWidget* parent,const
    QWhatsThis::add(this,i18n("<qt><p><b>Catalog Manager</b></p>\n"
 "<p>The Catalog Manager merges two folders into one tree and displays all\n"
 "PO and POT files in these folders. This way you can easily see if a\n"
-"new template has been added or removed. Also some information about the files\n"
+"template has been added or removed. Also some information about the files\n"
 "is displayed.</p>"
 "<p>For more information see section <b>The Catalog Manager</b>"
 " in the online help.</p></qt>"));
@@ -228,6 +228,8 @@ void CatalogManagerView::saveView( KConfig *config) const
 {
     saveMarker(config);
 
+    KConfigGroupSaver( config, "CatalogManager" );
+
     config->writeEntry( "ValidateMarkAsFuzzy", _markAsFuzzy );
     config->writeEntry( "ValidateIgnoreFuzzy", _ignoreFuzzy );
 }
@@ -385,13 +387,32 @@ void CatalogManagerView::clearAllMarks()
    checkSelected();
 }
 
+void CatalogManagerView::markModifiedFiles()
+{
+    QDictIterator<CatManListItem> it( _fileList );
+    while ( it.current() )
+   {
+      CatManListItem* item=it.current();
+      /*if(item->marked())
+         _markerList.remove(item->package());
+      */
+      if(item->isModified() && ! item->marked() ) {
+          item->setMarked(true);
+	  _markerList.append(item->package( ));
+      }
+      ++it;
+   }
+
+   checkSelected();
+}
+
 void CatalogManagerView::loadMarks()
 {
     KURL url = KFileDialog::getOpenURL("","*.marklist", this);
     if( url.isEmpty() ) return;
 
     QString filename;
-    if( !KIO::NetAccess::download( url.url(), filename ) )
+    if( !KIO::NetAccess::download( url, filename ) )
     {
 	KMessageBox::error(this,i18n(
 	    "Error while trying to open file:\n %1").arg(url.url()));
@@ -495,8 +516,7 @@ void CatalogManagerView::saveMarks()
 
     if( !error && !url.isLocalFile())
     {
-	KURL temp(filename);
-	if( !KIO::NetAccess::upload( temp.url(), url.url() ) )
+	if( !KIO::NetAccess::upload( filename, url ) )
 	{
     	    KMessageBox::error(this,
 		i18n("An error occurred while trying to upload the file:\n%1\n").arg(url.url()));
@@ -573,7 +593,7 @@ void CatalogManagerView::statistics()
    if(isActive() && i->isDir())
    {
       if(KMessageBox::warningContinueCancel(this
-         ,i18n("The Catalog Manager is still updating information about the files!\n"
+         ,i18n("The Catalog Manager is still updating information about the files.\n"
 "If you continue, it will try to update all necessary files, however this can take "
 "a long time and may lead to wrong results. Please wait until all files are updated."),i18n("Warning")
          ,KStdGuiItem::cont()) == KMessageBox::Cancel)
@@ -600,7 +620,7 @@ void CatalogManagerView::markedStatistics()
    if(isActive() && i->isDir())
    {
       if(KMessageBox::warningContinueCancel(this
-         ,i18n("The Catalog Manager is still updating information about the files!\n"
+         ,i18n("The Catalog Manager is still updating information about the files.\n"
 "If you continue, it will try to update all necessary files, however this can take "
 "a long time and may lead to wrong results. Please wait until all files are updated."),i18n("Warning")
          ,KStdGuiItem::cont()) == KMessageBox::Cancel)
@@ -729,17 +749,17 @@ void CatalogManagerView::checkSyntax()
       {
          case Msgfmt::Ok:
          {
-            KMessageBox::information(this,i18n("The file is syntactically correct!\nOutput of \"msgfmt --statistics\":")+"\n"+output);
+            KMessageBox::information(this,i18n("The file is syntactically correct.\nOutput of \"msgfmt --statistics\":")+"\n"+output);
             break;
          }
          case Msgfmt::SyntaxError:
          {
-            KMessageBox::information(this,i18n("The file has syntax errors!\nOutput of \"msgfmt --statistics\":")+"\n"+output);
+            KMessageBox::information(this,i18n("The file has syntax errors.\nOutput of \"msgfmt --statistics\":")+"\n"+output);
             break;
          }
          case Msgfmt::HeaderError:
          {
-            KMessageBox::information(this,i18n("The file has header syntax error!\nOutput of \"msgfmt --statistics\":")+"\n"+output);
+            KMessageBox::information(this,i18n("The file has header syntax error.\nOutput of \"msgfmt --statistics\":")+"\n"+output);
             break;
          }
          case Msgfmt::Error:
@@ -749,7 +769,7 @@ void CatalogManagerView::checkSyntax()
          }
          case Msgfmt::NoExecutable:
          {
-            KMessageBox::sorry(this,i18n("Can't execute msgfmt. Please make sure you have msgfmt in your PATH!"));
+            KMessageBox::sorry(this,i18n("Can not execute msgfmt. Please make sure you have msgfmt in your PATH!"));
             break;
          }
 	 case Msgfmt::Unsupported:
@@ -777,12 +797,12 @@ void CatalogManagerView::checkSyntax()
             QString msg;
             if(!name.isEmpty())
             {
-               msg=i18n("All files in folder %1 are syntactically correct!\n"
+               msg=i18n("All files in folder %1 are syntactically correct.\n"
 "Output of \"msgfmt --statistics\":\n").arg(name)+output;
             }
             else
             {
-               msg=i18n("All files in the base folder are syntactically correct!\n"
+               msg=i18n("All files in the base folder are syntactically correct.\n"
 "Output of \"msgfmt --statistics\":\n")+output;
             }
             KMessageBox::information(this,msg);
@@ -793,12 +813,12 @@ void CatalogManagerView::checkSyntax()
             QString msg;
             if(!name.isEmpty())
             {
-               msg=i18n("At least one file in folder %1 has syntax errors!\n"
+               msg=i18n("At least one file in folder %1 has syntax errors.\n"
 "Output of \"msgfmt --statistics\":\n").arg(name)+output;
             }
             else
             {
-               msg=i18n("At least one file in the base folder has syntax errors!\n"
+               msg=i18n("At least one file in the base folder has syntax errors.\n"
 "Output of \"msgfmt --statistics\":\n")+output;
             }
             KMessageBox::information(this,msg);
@@ -809,12 +829,12 @@ void CatalogManagerView::checkSyntax()
             QString msg;
             if(!name.isEmpty())
             {
-               msg=i18n("At least one file in folder %1 has header syntax errors!\n"
+               msg=i18n("At least one file in folder %1 has header syntax errors.\n"
 "Output of \"msgfmt --statistics\":\n").arg(name)+output;
             }
             else
             {
-               msg=i18n("At least one file in the base folder has header syntax errors!\n"
+               msg=i18n("At least one file in the base folder has header syntax errors.\n"
 "Output of \"msgfmt --statistics\":\n")+output;
             }
             KMessageBox::information(this,msg);
@@ -838,7 +858,7 @@ void CatalogManagerView::checkSyntax()
          }
          case Msgfmt::NoExecutable:
          {
-            KMessageBox::sorry(this,i18n("Can't execute msgfmt. Please make sure you have msgfmt in your PATH!"));
+            KMessageBox::sorry(this,i18n("Cannot execute msgfmt. Please make sure you have msgfmt in your PATH."));
             break;
          }
 	 case Msgfmt::Unsupported:
@@ -930,6 +950,49 @@ void CatalogManagerView::mailMarkedFiles()
   mailer->sendFiles(filesToSend);
 }
 
+void CatalogManagerView::packageFiles( )
+{
+    CatManListItem* item = (CatManListItem*)currentItem();
+    if(item->isDir()) {
+        QStringList filesToPackage;
+        QStringList childrenList = item->allChildrenList(true);
+
+        QStringList::Iterator it;
+        for (it = childrenList.begin(); it != childrenList.end(); ++it) {
+          CatManListItem* i = _fileList[(*it)];
+          if (i->hasPo()) {
+	    filesToPackage << i->poFile();
+          }
+        }
+	QString packageFileName = KFileDialog::getSaveFileName(QString::null,"*.tar.bz2\n*.tar.gz",this);
+	mailer->buildArchive( filesToPackage, packageFileName, QString::null, false );
+    }
+    else {
+        if (item->hasPo()) {
+          QStringList fileToPackage(item->poFile());
+	  QString packageFileName = KFileDialog::getSaveFileName(QString::null,"*.tar.bz2\n*.tar.gz",this);
+	  mailer->buildArchive( fileToPackage, packageFileName, QString::null, false );
+        }
+    }
+}
+void CatalogManagerView::packageMarkedFiles( )
+{
+    if (_markerList.count() == 0)
+      return;
+
+    QStringList filesToPackage;
+    QStringList::Iterator it;
+    for (it = _markerList.begin(); it != _markerList.end(); ++it) {
+      CatManListItem* i = _fileList[(*it)];
+      if (i->hasPo()) {
+        filesToPackage << i->poFile();
+      }
+    }
+
+    QString packageFileName = KFileDialog::getSaveFileName(QString::null,"*.tar.bz2\n*.tar.gz",this);
+    mailer->buildArchive( filesToPackage, packageFileName, QString::null, false );
+}
+
 void CatalogManagerView::cvsUpdate( )
 {
   doCVSCommand( CVS::Update );
@@ -980,6 +1043,11 @@ void CatalogManagerView::cvsCommitMarkedTemplate( )
   doCVSCommand( CVS::Commit, true, true );
 }
 
+void CatalogManagerView::cvsDiff( )
+{
+  doCVSCommand( CVS::Diff, false, false );
+}
+
 void CatalogManagerView::doCVSCommand( CVS::Command cmd, bool marked, bool templates )
 {
   if ( marked ) {
@@ -998,9 +1066,9 @@ void CatalogManagerView::doCVSCommand( CVS::Command cmd, bool marked, bool templ
     QString basedir = ( templates ? _settings.potBaseDir : _settings.poBaseDir );
     QString cvsItem;
     CatManListItem * item = (CatManListItem*)currentItem( );
-    if ( cmd == CVS::Commit && item->isDir( ) ) {
+    if ( ( cmd == CVS::Commit || cmd == CVS::Diff ) && item->isDir( ) ) {
       // all children including directories
-      QStringList cvsItems = item->allChildrenFileList ();
+      QStringList cvsItems = item->allChildrenFileList (true, false, true);
       if ( !cvsItems.isEmpty( ) )
         cvshandler->execCVSCommand(cmd, cvsItems, templates);
     } else {
@@ -2179,8 +2247,6 @@ void CatalogManagerView::setSettings(CatManSettings newSettings)
    _fileCommandsMenu->insertItem(i18n("Log Window"),this,SLOT(showLog()));
 
 
-   emit settingsChanged(_settings);
-
    bool pathChanged=false;
    if(oldSettings.poBaseDir!=_settings.poBaseDir)
    {
@@ -2721,7 +2787,7 @@ void CatalogManagerView::validate_internal( const QStringList& files, const KDat
 
     if( !t )
     {
-	KMessageBox::error( this, i18n("Can't instantiate a validation tool.\n"
+	KMessageBox::error( this, i18n("Can not instantiate a validation tool.\n"
 	"Please, check your installation."), i18n("Validation Tool Error") );
 	return;
     }
@@ -2780,7 +2846,7 @@ void CatalogManagerView::showError( const QString package, const int num )
     CatManListItem* item = _fileList[ package];
     if( !item )
     {
-	kdWarning() << "Can't find error package: " << package << endl;
+	kdWarning() << "Can not find error package: " << package << endl;
 	return;
     }
 
