@@ -3,7 +3,7 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-                2001-2003 by Stanislav Visnovsky <visnovsky@kde.org>
+                2001-2004 by Stanislav Visnovsky <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 #include <kprocess.h>
 #include <qptrlist.h>
 
-#include "settings.h"
+#include "projectsettings.h"
 #include "findoptions.h"
 #include "cvsresources.h"
 
@@ -66,7 +66,7 @@ public:
    CatalogManagerView(QString configFile, QWidget* parent=0, const char* name=0);
    virtual ~CatalogManagerView();
 
-   CatManSettings settings() const;
+   KBabel::CatManSettings settings() const;
    /** clears the tree */
    virtual void clear();
 
@@ -83,16 +83,16 @@ public:
 
    void restoreView(KConfig *config);
    void saveView(KConfig *config) const;
-   
+
    void setRMBMenuFile( QPopupMenu *m);
    void setRMBMenuDir( QPopupMenu *m);
    void setDirCommandsMenu( QPopupMenu *m);
    void setFileCommandsMenu( QPopupMenu *m);
-   
+
    CVSHandler * cvsHandler( );
-   
+
 public slots:
-   void setSettings(CatManSettings newSettings);
+   void setSettings(KBabel::CatManSettings newSettings);
    void toggleMark();
    /**
    * removes all marks in directory of current item (must be a directory)
@@ -100,6 +100,7 @@ public slots:
    void slotClearMarksInDir();
    void clearAllMarks();
    void toggleAllMarks();
+   void markModifiedFiles();
    void loadMarks();
    void saveMarks();
    void slotMarkPattern( );
@@ -118,16 +119,16 @@ public slots:
    * parent directory is used instead.
    */
    void markedStatistics();
-   /** 
-	* calls @ref Msgfmt::checkSyntax, to check the po-file of 
-	* the selected item 
+   /**
+	* calls @ref Msgfmt::checkSyntax, to check the po-file of
+	* the selected item
 	*/
    void checkSyntax();
-   
+
    void roughTranslation();
    void markedRoughTranslation();
 
-   /** Send the selected item as a compressed mail attachment. If the 
+   /** Send the selected item as a compressed mail attachment. If the
     *  selected item is a directory send the items contained in the
     *  directory.
     */
@@ -135,7 +136,10 @@ public slots:
    /** Send the marked items as a compressed mail attachment.
     */
    void mailMarkedFiles();
-   
+
+   void packageFiles();
+   void packageMarkedFiles();
+
    void cvsUpdate( );
    void cvsUpdateMarked( );
    void cvsCommit( );
@@ -146,26 +150,27 @@ public slots:
    void cvsUpdateMarkedTemplate( );
    void cvsCommitTemplate( );
    void cvsCommitMarkedTemplate( );
-   
+   void cvsDiff( );
+
    QString find(KBabel::FindOptions &options, QStringList &rest);
 
    void showLog();
 
    void stop(bool s = true);
-   
+
    /**
    * Stop searching, do not try to proceed to the next file
    * @ref @find will return clear list of rest to be searched
    * and @ref QString::null, if search string was not is the last searched file
    */
    void stopSearch();
-   
+
    /**
-   * Information for this file has been read. If the file is in 
+   * Information for this file has been read. If the file is in
    * @ref @_readInfoFileList, it will update progress bar by emitting @ref @progress
    */
    void fileInfoRead( QString file );
-   
+
    void gotoNextUntranslated();
    void gotoPreviousUntranslated();
    void gotoNextFuzzy();
@@ -180,21 +185,21 @@ public slots:
    void gotoPreviousPo();
    void gotoNextMarked();
    void gotoPreviousMarked();
-   
+
    void validateUsingTool( const KDataToolInfo &, const QString& );
    void validateMarkedUsingTool( const KDataToolInfo &, const QString& );
-   
+
    void showError( const QString package, const int num);
-   
+
    void updateCurrent();
-   
+
    /**
-    * An update for more than one file has become necessary. For instance 
+    * An update for more than one file has become necessary. For instance
     * after 'cvs commit' the file contents have not changed but the cvs file
     * status could have changed.
     */
    void updateFiles( const QStringList& files );
-   
+
    /**
    * Returns the list of all currently selected files. If current selection is dir,
    * it returns list of all its children.
@@ -204,14 +209,13 @@ public slots:
    * Returns the list of all currently marked files.
    */
    QStringList marked();
-   
+
 signals:
    void openFile(QString filename,QString package);
    void openFileInNewWindow(QString filename,QString package);
    void openTemplate(QString openFilename,QString saveFileName,QString package);
    void openTemplateInNewWindow(QString openFilename,QString saveFileName,QString package);
    void gotoFileEntry(QString filename,QString package,int msgid);
-   void settingsChanged(CatManSettings);
    void prepareProgressBar(QString msg,int max);
    void progress(int);
    void clearProgressBar();
@@ -227,10 +231,10 @@ signals:
    void setMaxValidationFileProgressBar(int);
 
    /**
-    * The selected item in the tree view has changed. 
+    * The selected item in the tree view has changed.
     * This signal emits the corresponding action value for this item.
     * @param actionValue Action value for the selected item.
-    */   
+    */
    void selectedChanged(uint actionValue);
 
 signals:
@@ -251,7 +255,7 @@ protected:
    bool buildDir(QString relDir,bool fast=true);
 
    /**
-   * This function is traversing the real directory on the 
+   * This function is traversing the real directory on the
    * disc using baseDir as the
    * base directory and starts at baseDir+relDir
    * @param extension the extension of the files in this directory
@@ -264,7 +268,7 @@ protected:
    bool buildDir(const QString& baseDir,const QString& relDir, const QString extension,bool fast=true);
 
    /**
-   * updates dir relDir and if any new subdir is added 
+   * updates dir relDir and if any new subdir is added
    * builds this with @ref buildDir
    *
    * This function doesn't enters subdirs except when a new subdir is added.
@@ -289,7 +293,7 @@ protected:
    virtual void contentsMousePressEvent(QMouseEvent* e);
    /** used for dragging */
    virtual void contentsMouseMoveEvent(QMouseEvent* e);
-   
+
    void showStatistics( CatManListItem *i, QStringList &packages);
 
 protected slots:
@@ -336,7 +340,7 @@ private slots:
 
    void slotValidPORepository( bool );
    void slotValidPOTRepository( bool );
-   
+
 private:
    void toggleColumn( uint id, bool show);
 
@@ -346,8 +350,8 @@ private:
    * remove marked entries, which are not in the current file list
    */
    void updateMarkerList();
-   
-   /** 
+
+   /**
     * Mark or unmark entries.
     *
     * @param mark If true the items are marked, if false the marks are removed.
@@ -359,14 +363,14 @@ private:
 	* and makes sure, that all subitems are removed from the lists
 	*/
    void deleteDirItem(QString relDir);
-   
+
    bool hasMatchingWords( QStringList &itemWords, QStringList &searchWords);
-   
+
    CatManListItem *itemBelow( CatManListItem *item );
    CatManListItem *itemAbove( CatManListItem *item );
 
    void validate_internal( const QStringList&, const KDataToolInfo &, const QString& );
-   
+
    void doCVSCommand( CVS::Command cmd, bool marked = false, bool templates = false );
 
 private:
@@ -375,13 +379,13 @@ private:
 
    KDirWatch *_dirWatch;
    QTimer *_updateTimer;
-   
+
    // list of files for which was calculated the progress bar for reading file info
    QStringList _readInfoFileList;
    // current count of already read files in @ref @_readInfoFileList.
    int _readInfoCount;
-   
-   CatManSettings _settings;
+
+   KBabel::CatManSettings _settings;
 
    QStringList _markerList;
 
@@ -403,17 +407,17 @@ private:
 
    /** used for starting a drag */
    QPoint _pressPos;
-   
+
    KBabelDictBox* _dictBox;
 
    KBabel::KBabelMailer* mailer;
-   
+
    CVSHandler * cvshandler;
    bool validPORepository;
    bool validPOTRepository;
-   
+
    MarkPatternDialog * markPatternDialog;
-   
+
    //validation
    ValidateProgressDialog* _validateDialog;
    ValidationOptions* _validateOptions;
