@@ -91,7 +91,7 @@ void CatManListItem::init(const QString& fullPath, const QString& fullPotPath, c
     _wordListUpdated = false;
 
     update(parent()->isOpen(),false,true);
-    
+
     if( !isDir() )  setPixmap(COL_MARKER,ICON_NOFLAG);
 }
 
@@ -121,7 +121,7 @@ bool CatManListItem::marked() const
     	    else if(myChild->isDir() && myChild->marked() ) return true;
 	    myChild = (CatManListItem*)myChild->nextSibling();
 	}
-	
+
     }
     return false;
 }
@@ -195,14 +195,15 @@ QStringList CatManListItem::allChildrenList(bool onlyFiles) const
 }
 
 
-QStringList CatManListItem::allChildrenFileList(bool onlyFiles, bool emptyDirs) const
+QStringList CatManListItem::allChildrenFileList(bool onlyFiles, bool emptyDirs, bool onlyModified) const
 {
    QStringList childrenList;
 
    CatManListItem * myChild = (CatManListItem*)firstChild();
    while( myChild )
    {
-      if(myChild->isFile() && myChild->hasPo())
+      if(myChild->isFile() && myChild->hasPo() &&
+       !(!myChild->isModified() && onlyModified))
       {
          childrenList.append(myChild->poFile());
       }
@@ -211,9 +212,9 @@ QStringList CatManListItem::allChildrenFileList(bool onlyFiles, bool emptyDirs)
          if(!onlyFiles && (emptyDirs || myChild->_primary.exists() ))
 	 {
             childrenList.append(myChild->poFile());
-	}
+	 }
 
-         childrenList+=myChild->allChildrenFileList(onlyFiles);
+         childrenList+=myChild->allChildrenFileList(onlyFiles,false,onlyModified);
       }
 
       myChild = (CatManListItem*)myChild->nextSibling();
@@ -298,7 +299,18 @@ QString CatManListItem::key(int col, bool) const
    {
       key=key.rightJustify(10,'0');
    }
-
+   // marked po's
+   else if(col==COL_MARKER)
+   {
+     if(_marked)
+     {
+       key="1";
+     }
+     else
+     {
+       key="0";
+     }
+   }
 
    return key;
 }
@@ -332,14 +344,14 @@ void CatManListItem::update(bool showPoInfo,bool includeChildren
           {
              QDir dir=_primary.dir();
              setText(COL_NAME,dir.dirName());
-	     
+
 	     // count the childen numbers
 	     int fuzzy = 0;
 	     int untrans = 0;
 	     int total = 0;
-	     
+
 	     CatManListItem* ch = static_cast<CatManListItem*>(firstChild ());
-	     
+
 	     while (ch)
 	     {
 	        fuzzy += ch->fuzzy ();
@@ -405,6 +417,8 @@ void CatManListItem::update(bool showPoInfo,bool includeChildren
 
 		    _hasErrors=false;
 
+                    _isModified=(_view->cvsHandler()->fstatus(poFile()) == 1 || _view->cvsHandler()->fstatus(poFile()) == 4) ? 1 : 0;
+
 		    setText(COL_FUZZY,QString::number(poInfo.fuzzy));
                     setText(COL_UNTRANS,QString::number(poInfo.untranslated));
                     setText(COL_TOTAL,QString::number(poInfo.total));
@@ -455,9 +469,9 @@ void CatManListItem::update(bool showPoInfo,bool includeChildren
 
 	     // count the childen numbers
 	     int total = 0;
-	     
+
 	     CatManListItem* ch = static_cast<CatManListItem*>(firstChild ());
-	     
+
 	     while (ch)
 	     {
 		total += ch->total ();
@@ -509,7 +523,7 @@ void CatManListItem::update(bool showPoInfo,bool includeChildren
         	if( _view->isStopped() ) return;
              }
 	     setPixmap(COL_NAME,ICON_MISSING);
-	     
+
 	     updateParent = true;
           }
        }
@@ -539,7 +553,7 @@ void CatManListItem::update(bool showPoInfo,bool includeChildren
           myChild = (CatManListItem*)myChild->nextSibling();
        }
     }
-    
+
     // HACK to get the signal emitted
     if (isSelected( )) {
       listView( )->setSelected(this, false);
@@ -640,6 +654,11 @@ bool CatManListItem::hasPot() const
    return _template.exists();
 }
 
+bool CatManListItem::isModified() const
+{
+   return _isModified;
+}
+
 int CatManListItem::fuzzy() const
 {
    bool success;
@@ -809,11 +828,11 @@ void CatManListItem::checkErrors(KDataTool* tool, QObject* progressSignalHandler
     bool hasError=false;
     _errors.clear();
     Catalog* cat = new Catalog();
-    
+
     QObject::connect( cat, SIGNAL( signalProgress(int) ), progressSignalHandler, SIGNAL( setValidationProgressBar(int)));
     QObject::connect( cat, SIGNAL( signalResetProgressBar(QString, int) ), progressSignalHandler, SLOT( setupFileProgressBar(QString, int)));
 
-    if( cat->openURL(poFile()) == OK )
+    if( cat->openURL(KURL( poFile() )) == OK )
     {
 	kdDebug(KBABEL_CATMAN) << "File opened succesfully" << endl;
 	if( !cat->checkUsingTool(tool,true) )
@@ -824,23 +843,23 @@ void CatManListItem::checkErrors(KDataTool* tool, QObject* progressSignalHandler
     	kdDebug(KBABEL_CATMAN) << "File not opened !!!!!" << endl;
 	hasError=true;
     }
-    
+
     if( hasError )
     {
 	QString errortext;
 	_hasErrors = true;
-	
+
 	DocPosition dummy;
 	IgnoreItem i;
 	i.fileURL = poFile();
-	
+
 	if( cat->hasError(0,dummy) && (!ignoreFuzzy || !cat->isFuzzy(0)))
 	{
 	    i.msgid = cat->msgid(0);
 	    i.msgstr = cat->msgstr(0);
 	    i.index = 0;
 	    _errors.append( i );
-	    
+
 	    if( markAsFuzzy ) cat->setFuzzy(0, true);
 	}
 
@@ -857,16 +876,16 @@ void CatManListItem::checkErrors(KDataTool* tool, QObject* progressSignalHandler
 		if( markAsFuzzy ) cat->setFuzzy(index, true);
 	    }
 	} while(index>=0);
-	
+
 	// change icon only if there were non-ignored errors
     	if( !_errors.isEmpty() )
 	{
 	    setPixmap(COL_NAME, ICON_ERROR);
 	}
-	
+
 	// if we changed fuzzy flags, save the result
 	if( cat->isModified() ) cat->saveFile();
     }
-    
+
     delete cat;
 }
