@@ -55,13 +55,13 @@ public:
    /** creates the toplevel root item with package name "/" */
    CatManListItem(CatalogManagerView *view, QListView* parent,QString fullPath, QString fullPotPath);
 
-   /** 
-	* returns the package names (including relative path) of the 
-	* children of this item 
+   /**
+	* returns the package names (including relative path) of the
+	* children of this item
 	*/
    QStringList contentsList(bool onlyFiles=false) const;
    /**
-   * returns the package names of all children of this item 
+   * returns the package names of all children of this item
    * (including all subdirectries)
    * @param onlyFiles flag, if only the names of files should be returned
    * @see CatManListItem::contentsList
@@ -69,13 +69,14 @@ public:
    QStringList allChildrenList(bool onlyFiles=false) const;
 
    /**
-   * returns the relative file names of all children of this item 
+   * returns the relative file names of all children of this item
    * (including all subdirectries)
    * @param onlyFiles flag, if only the names of files should be returned
    * @param emptyDirs flag, if the empty dirs (dirs without PO files in them) should be returned
+   * @param onlyModified, if only modified files should be returned
    * @see CatManListItem::contentsList
    */
-   QStringList allChildrenFileList(bool onlyFiles=false, bool emptyDirs=false) const;
+   QStringList allChildrenFileList(bool onlyFiles=false, bool emptyDirs=false, bool onlyModified=false) const;
 
    void setMarked(bool on);
    bool marked() const;
@@ -83,7 +84,7 @@ public:
    * checks if the file on the disc has changed,
    * reads information about the file and displays it
    * @param noParents flag, if the update has to include the parent
-   * of the item, if the status has changed. Since at the first build of 
+   * of the item, if the status has changed. Since at the first build of
    * the tree, the status of every item changes, this is not useful then.
    */
    void checkUpdate(bool noParents=false);
@@ -99,14 +100,14 @@ public:
    * @param markAsFuzzy flag, whether the error messages should be marked as fuzzy (this alters the PO file)
    */
    void checkErrors(KDataTool* validator, QObject* progressSignalHandler, bool ignoreFuzzy, bool markAsFuzzy);
-   
+
    /** return the absolute filename of the po-File */
    QString poFile() const;
    /** return the absolute filename of the pot-File */
    QString potFile() const;
    /** returns the package name (inlcuding relative path to base-directory) */
    QString package(bool rootSlash=true) const;
-   
+
    /** returns the relative path of a dir or QString::null if not a dir. */
    QString packageDir( ) const;
 
@@ -124,25 +125,26 @@ public:
    bool hasPo() const;
    /** returns true, if the pot-file exists*/
    bool hasPot() const;
-   /** 
-	* @return the number of fuzzy messages in the po-file, 
+   bool isModified() const;
+   /**
+	* @return the number of fuzzy messages in the po-file,
 	* 0 if no po-file exists
 	*/
    int fuzzy() const;
-   /** 
-	* @return the number of untranslated messages in the po-file, 
+   /**
+	* @return the number of untranslated messages in the po-file,
 	* @ref total if no po-file exists
 	*/
    int untranslated() const;
    /** @return number of messages in the po- or pot-file */
    int total() const;
-   /** 
+   /**
 	* @return true, if there are untranslated or fuzzy items.
 	* If this item is a directory, it returns true, if a subitem
 	* contains untranslated or fuzzy items
 	*/
    bool needsWork() const;
-   /** 
+   /**
 	* @return true, if there were errors while parsing the file
 	*/
    bool hasErrors() const {return _hasErrors;}
@@ -153,9 +155,9 @@ public:
 
    /** paints the marking, if this package has no template */
    QPixmap paintExclamation(QPixmap*);
-   
+
    void updateAfterSave( KBabel::PoInfo &po);
-   
+
    QStringList &wordList() { return _wordList; }
    bool wordsUpdated() { return _wordListUpdated; }
 
@@ -167,11 +169,11 @@ private:
    void init(const QString& fullPath, const QString& fullPotPath,const QString& package);
    /**
    * updates the item
-   * @param showPoInfo if true, reads information about the 
+   * @param showPoInfo if true, reads information about the
    * file using @ref Catalog::info
    * ( slow for big files )
    * @param includeChildren flag, if possible children should be updated,too
-   * @param noParents flag, if parents should be updated, when state 
+   * @param noParents flag, if parents should be updated, when state
    * of the item has changed
    */
    void update(bool showPoInfo=true,bool includeChildren=false
@@ -191,7 +193,7 @@ private:
    /** the pot-file */
    QFileInfo _template;
    /**
-   * The package name, includes the relative path beginning 
+   * The package name, includes the relative path beginning
    * at the base directory.
    * The package name begins with "/" and if this is a directory it end with "/"
    * The root item has the package name "/"
@@ -206,14 +208,17 @@ private:
    /** flag, to detect if file has been deleted or is new */
    bool _hasPot;
 
+   bool _isModified;
+   /** flag, to detect if file has been modified or new */
+
    /** flag, if the PO-file has a syntax error */
    bool _hasErrors;
    /** a list of errors found by validation tool*/
    QValueList<IgnoreItem> _errors;
-   
+
    /** parent view for this item, used for stopping the activity */
    CatalogManagerView *_view;
-   
+
    /** index of words, but it does not contain any useful information as values */
    QStringList _wordList;
    bool _wordListUpdated;
