@@ -3,7 +3,7 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-                2001-2003 by Stanislav Visnovsky
+                2001-2002 by Stanislav Visnovsky
                             <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 **************************************************************************** */
 
@@ -32,9 +32,9 @@
 #define COL_FUZZY 2
 #define COL_UNTRANS 3
 #define COL_TOTAL 4
-#define COL_REVISION 5
-#define COL_TRANSLATOR 6
-
+#define COL_CVS 5
+#define COL_REVISION 6
+#define COL_TRANSLATOR 7
 
 #define ICON_OK UserIcon("ok",KIcon::DefaultState)
 #define ICON_MISSING UserIcon("missing",KIcon::DefaultState)
@@ -45,6 +45,15 @@
 #define ICON_FOLDER_CLOSED_OK SmallIcon("folder_green")
 #define ICON_FOLDER_CLOSED_WORK SmallIcon("folder_red")
 #define ICON_FOLDER_OPEN SmallIcon("folder_open")
+#define ICON_ERROR UserIcon("error",KIcon::DefaultState)
 #define ICON_NOFLAG UserIcon("noflag",KIcon::DefaultState)
 
+// Needed for determining which actions should be enabled and which not.
+#define NEEDS_PO       1
+#define NEEDS_POT      2
+#define NEEDS_MARK     4
+#define NEEDS_DIR      8
+#define NEEDS_PO_CVS  16
+#define NEEDS_POT_CVS 32
+
 #endif
