@@ -3,7 +3,7 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-		2001-2003 by Stanislav Visnovsky
+		2001-2004 by Stanislav Visnovsky
 			    <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
@@ -98,18 +98,19 @@ public:
    
    int numberOfPluralForms;
 
-   QString _configFile;
+   Project::Ptr _project;
    RegExpExtractor *_tagExtractor, *_argExtractor;
    
    QStringList _catalogExtra;
    
-   CatalogPrivate() : 
+   CatalogPrivate(Project::Ptr project) : 
 	_packageName( QString::null ), _packageDir( QString::null ),
+	_header (project), 
 	_importID( QString::null ), _mimeTypes( "text/plain" ),
 	_modified(false), _readOnly(false), _generatedFromDocbook(false), 
 	_active(false), _stop(false),
 	fileCodec(0),  diffCache(30,76), numberOfPluralForms(-1), 
-	_configFile( QString::null )
+	_project(project) 
    {
 	_entries.clear();
 	_obsoleteEntries.clear();
