@@ -36,10 +36,11 @@
 
 using namespace KBabel;
 
-CatalogItem::CatalogItem()
+CatalogItem::CatalogItem(Project::Ptr project)
 {
    d=0;
    clear();
+   d->_project = project;
 }
 
 CatalogItem::CatalogItem(const CatalogItem& item)
@@ -478,3 +479,13 @@ void CatalogItem::removeError(const QString& error )
 {
     d->_errors.remove(error);
 }
+
+Project::Ptr CatalogItem::project() const
+{
+    return d->_project;
+}
+
+void CatalogItem::setProject( Project::Ptr project )
+{
+    d->_project = project;
+}
