@@ -123,9 +123,14 @@ QString KBabelMailer::createArchive(QStringList fileList, QString initialName)
     archiveName += ".tar.gz";
     mimetype = "application/x-gzip";
   }
+  
+  return buildArchive (fileList, tempDir+archiveName, mimetype, true);
+}
 
+QString KBabelMailer::buildArchive(QStringList fileList, QString archiveName, QString mimetype, bool remove)
+{
   // create a new archive
-  KTar archive(tempDir + archiveName, mimetype);
+  KTar archive(archiveName, mimetype);
   if (!archive.open(IO_WriteOnly)) {
     KMessageBox::error(0, i18n("Error while trying to create archive file."));
     return QString::null;
@@ -165,7 +170,9 @@ QString KBabelMailer::createArchive(QStringList fileList, QString initialName)
   archive.close();
 
   // add archive's filename to the list of files to be deleted later
-  tempFileNames << archive.fileName();
+  if (remove)
+    tempFileNames << archive.fileName();
+
   return archive.fileName();
 }
 
