@@ -223,7 +223,7 @@ QTextCodec* PoInfo::codecForFile(QString gettextHeader)
    return codec;
 }
 
-PoInfo PoInfo::headerInfo(const CatalogItem headerItem)
+PoInfo PoInfo::headerInfo(const CatalogItem& headerItem)
 {
    QStringList header=headerItem.msgstrAsList();
 
@@ -329,7 +329,7 @@ PoInfo PoInfo::headerInfo(const CatalogItem headerItem)
 }
 
 
-ConversionStatus PoInfo::info(const QString url, PoInfo& info, QStringList &wordList, bool updateWordList, bool interactive)
+ConversionStatus PoInfo::info(const QString& url, PoInfo& info, QStringList &wordList, bool updateWordList, bool interactive)
 {
    stopStaticRead = false;
 
@@ -337,7 +337,7 @@ ConversionStatus PoInfo::info(const QString url, PoInfo& info, QStringList &word
        return OK;
 
    QString target;
-   if(KIO::NetAccess::download(url, target))
+   if(KIO::NetAccess::download(KURL( url ), target))
    {
        QFile file(target);
 
@@ -475,13 +475,13 @@ ConversionStatus PoInfo::info(const QString url, PoInfo& info, QStringList &word
    return OK;
 }
 
-bool PoInfo::findInFile( const QString url, FindOptions options )
+bool PoInfo::findInFile( const QString& url, FindOptions options )
 {
    enum {Begin, Comment, Msgid, Msgstr} part = Begin;
    
    stopStaticRead = false;
    QString target;
-   if(KIO::NetAccess::download(url, target))
+   if(KIO::NetAccess::download(KURL( url ), target))
    {
        std::ifstream* stream = new std::ifstream( target.local8Bit()); 
        if(stream->is_open())
