@@ -47,10 +47,10 @@ FindDialog::FindDialog(bool forReplace, QWidget* parent)
 {
 	QWidget* page = new QWidget(this);
 	QVBoxLayout *layout = new QVBoxLayout(page, 0, spacingHint());
-	
+
 	QLabel *label = new QLabel(i18n("&Find:"),page);
 	layout->addWidget(label);
-	
+
 	_findCombo = new KComboBox(true, page, "findCombo");
 	_findCombo->setMaxCount(10);
 	_findCombo->setInsertionPolicy(KComboBox::AtTop);
@@ -67,8 +67,9 @@ FindDialog::FindDialog(bool forReplace, QWidget* parent)
 	QWhatsThis::add(_findCombo,msg);
 
 	if(forReplace) {
-		setCaption("Replace");
-	
+		setCaption(i18n("Replace"));
+                setButtonOK(i18n("&Replace"));
+
 		_replaceLabel = new QLabel(i18n("&Replace with:"),page);
 		layout->addWidget(_replaceLabel);
 		_replaceCombo = new KComboBox(true, page, "replaceCombo");
@@ -79,27 +80,28 @@ FindDialog::FindDialog(bool forReplace, QWidget* parent)
 
 	    	msg=i18n("<qt><p><b>Replace text</b></p>"
 	    	"<p>Here you can enter the text you want the found text to get "
-		"replaced with. The text is used as is. It is not possible to make a back " 
+		"replaced with. The text is used as is. It is not possible to make a back "
 		"reference, if you have searched for a regular expression.</p></qt>");
 
 		QWhatsThis::add(_replaceLabel,msg);
 		QWhatsThis::add(_replaceCombo,msg);
 	}
 	else {
-		setCaption("Find");
-		
+		setCaption(i18n("Find"));
+	        setButtonOK(KGuiItem(i18n("&Find"),"find"));
+
 		_replaceLabel=0;
 		_replaceCombo=0;
 	}
-	
+
 	_buttonGrp = new QButtonGroup(3, Qt::Horizontal, i18n("Where to Search"), page);
 	connect(_buttonGrp,SIGNAL(clicked(int)), this, SLOT(inButtonsClicked(int)));
 	layout->addWidget(_buttonGrp);
-	
+
 	_inMsgid = new QCheckBox(i18n("&Msgid"),_buttonGrp);
 	_inMsgstr = new QCheckBox(i18n("M&sgstr"),_buttonGrp);
 	_inComment = new QCheckBox(i18n("Comm&ent"),_buttonGrp);
-	
+
 	QWhatsThis::add(_buttonGrp,i18n("<qt><p><b>Where to search</b></p>"
 		"<p>Select here in which parts of a catalog entry you want "
 		"to search.</p></qt>"));
@@ -180,7 +182,7 @@ int FindDialog::show(QString initialStr)
 	}
 	_findCombo->lineEdit()->selectAll();
    _findCombo->setFocus();
-	
+
 
 	KDialogBase::show();
 
@@ -192,25 +194,25 @@ int FindDialog::show(QString initialStr)
 			_replaceList.prepend(_replaceCombo->currentText());
 			if(_replaceList.count() > 10 )
 				_replaceList.remove(_replaceList.fromLast());
-				
+
 			_replaceCombo->clear();
 			_replaceCombo->insertStringList(_replaceList);
-			
+
 			_replaceFindList.remove(_findCombo->currentText());
 			_replaceFindList.prepend(_findCombo->currentText());
 			if(_replaceFindList.count() > 10 )
 				_replaceFindList.remove(_replaceFindList.fromLast());
-				
+
 			_findCombo->clear();
 			_findCombo->insertStringList(_replaceFindList);
-		
+
 			_replaceOptions.findStr = _findCombo->currentText();
 			_replaceOptions.replaceStr = _replaceCombo->currentText();
 
 			_replaceOptions.inMsgstr = _inMsgstr->isChecked();
 			_replaceOptions.inComment = _inComment->isChecked();
 			_replaceOptions.inMsgid = false;
-		
+
 			_replaceOptions.caseSensitive = _caseSensitive->isChecked();
 			_replaceOptions.wholeWords = _wholeWords->isChecked();
 			_replaceOptions.ignoreAccelMarker = _ignoreAccelMarker->isChecked();
@@ -225,15 +227,15 @@ int FindDialog::show(QString initialStr)
 			_findList.prepend(_findCombo->currentText());
 			if(_findList.count() > 10 )
 				_findList.remove(_findList.fromLast());
-			
+
 			_findCombo->clear();
 			_findCombo->insertStringList(_findList);
-				
+
 			_findOptions.findStr = _findCombo->currentText();
 			_findOptions.inMsgid = _inMsgid->isChecked();
 			_findOptions.inMsgstr = _inMsgstr->isChecked();
 			_findOptions.inComment = _inComment->isChecked();
-		
+
 			_findOptions.caseSensitive = _caseSensitive->isChecked();
 			_findOptions.wholeWords = _wholeWords->isChecked();
 			_findOptions.ignoreAccelMarker = _ignoreAccelMarker->isChecked();
@@ -243,7 +245,7 @@ int FindDialog::show(QString initialStr)
 			_findOptions.isRegExp = _isRegExp->isChecked();
 		}
 	}
-	
+
 	return r;
 }
 
@@ -254,7 +256,7 @@ int FindDialog::exec(QString initialStr)
 	}
 	_findCombo->lineEdit()->selectAll();
    _findCombo->setFocus();
-	
+
 
 	KDialogBase::exec();
 
@@ -266,25 +268,25 @@ int FindDialog::exec(QString initialStr)
 			_replaceList.prepend(_replaceCombo->currentText());
 			if(_replaceList.count() > 10 )
 				_replaceList.remove(_replaceList.fromLast());
-				
+
 			_replaceCombo->clear();
 			_replaceCombo->insertStringList(_replaceList);
-			
+
 			_replaceFindList.remove(_findCombo->currentText());
 			_replaceFindList.prepend(_findCombo->currentText());
 			if(_replaceFindList.count() > 10 )
 				_replaceFindList.remove(_replaceFindList.fromLast());
-				
+
 			_findCombo->clear();
 			_findCombo->insertStringList(_replaceFindList);
-		
+
 			_replaceOptions.findStr = _findCombo->currentText();
 			_replaceOptions.replaceStr = _replaceCombo->currentText();
 
 			_replaceOptions.inMsgstr = _inMsgstr->isChecked();
 			_replaceOptions.inComment = _inComment->isChecked();
 			_replaceOptions.inMsgid = false;
-		
+
 			_replaceOptions.caseSensitive = _caseSensitive->isChecked();
 			_replaceOptions.wholeWords = _wholeWords->isChecked();
 			_replaceOptions.ignoreAccelMarker = _ignoreAccelMarker->isChecked();
@@ -299,15 +301,15 @@ int FindDialog::exec(QString initialStr)
 			_findList.prepend(_findCombo->currentText());
 			if(_findList.count() > 10 )
 				_findList.remove(_findList.fromLast());
-			
+
 			_findCombo->clear();
 			_findCombo->insertStringList(_findList);
-				
+
 			_findOptions.findStr = _findCombo->currentText();
 			_findOptions.inMsgid = _inMsgid->isChecked();
 			_findOptions.inMsgstr = _inMsgstr->isChecked();
 			_findOptions.inComment = _inComment->isChecked();
-		
+
 			_findOptions.caseSensitive = _caseSensitive->isChecked();
 			_findOptions.wholeWords = _wholeWords->isChecked();
 			_findOptions.ignoreAccelMarker = _ignoreAccelMarker->isChecked();
@@ -317,7 +319,7 @@ int FindDialog::exec(QString initialStr)
 			_findOptions.isRegExp = _isRegExp->isChecked();
 		}
 	}
-	
+
 	return r;
 }
 
@@ -329,10 +331,10 @@ FindOptions FindDialog::findOpts()
 void FindDialog::setFindOpts(FindOptions options)
 {
     _findOptions = options;
-    _inMsgid->setChecked(_findOptions.inMsgid);	
+    _inMsgid->setChecked(_findOptions.inMsgid);
     _inMsgstr->setChecked(_findOptions.inMsgstr);
     _inComment->setChecked(_findOptions.inComment);
-		
+
     _caseSensitive->setChecked(_findOptions.caseSensitive);
     _wholeWords->setChecked(_findOptions.wholeWords);
     _ignoreAccelMarker->setChecked(_findOptions.ignoreAccelMarker);
@@ -341,7 +343,7 @@ void FindDialog::setFindOpts(FindOptions options)
     _fromCursor->setChecked(_findOptions.fromCursor);
     _isRegExp->setChecked(_findOptions.isRegExp);
     if( _regExpButton ) _regExpButton->setEnabled( _findOptions.isRegExp );
-	
+
     _findCombo->setEditText(_findOptions.findStr);
 }
 
@@ -353,10 +355,10 @@ ReplaceOptions FindDialog::replaceOpts()
 void FindDialog::setReplaceOpts(ReplaceOptions options)
 {
    _replaceOptions = options;
-    _inMsgid->setChecked(_replaceOptions.inMsgid);	
+    _inMsgid->setChecked(_replaceOptions.inMsgid);
     _inMsgstr->setChecked(_replaceOptions.inMsgstr);
     _inComment->setChecked(_replaceOptions.inComment);
-		
+
     _caseSensitive->setChecked(_replaceOptions.caseSensitive);
     _wholeWords->setChecked(_replaceOptions.wholeWords);
     _ignoreAccelMarker->setChecked(_replaceOptions.ignoreAccelMarker);
@@ -366,7 +368,7 @@ void FindDialog::setReplaceOpts(ReplaceOptions options)
     _isRegExp->setChecked(_replaceOptions.isRegExp);
     _askForReplace->setChecked(_replaceOptions.ask);
     if( _regExpButton ) _regExpButton->setEnabled( _replaceOptions.isRegExp );
-	
+
     _findCombo->setEditText(_replaceOptions.findStr);
     _replaceCombo->setEditText(_replaceOptions.replaceStr);
 }
@@ -379,11 +381,11 @@ void FindDialog::readSettings()
 		KConfigGroupSaver cgs(config,"ReplaceDialog");
 		_replaceOptions.inMsgstr = config->readBoolEntry("InMsgstr",true);
 		_replaceOptions.inComment = config->readBoolEntry("InComment",false);
-	
-		_replaceOptions.caseSensitive = 
+
+		_replaceOptions.caseSensitive =
             config->readBoolEntry("CaseSensitive",true);
 		_replaceOptions.wholeWords = config->readBoolEntry("WholeWords",false);
-		_replaceOptions.ignoreAccelMarker = 
+		_replaceOptions.ignoreAccelMarker =
             config->readBoolEntry("IgnoreAccelMarker",true);
 		_replaceOptions.backwards = config->readBoolEntry("Backwards",false);
 		_replaceOptions.fromCursor = config->readBoolEntry("FromCursor",true);
@@ -391,7 +393,7 @@ void FindDialog::readSettings()
 		_replaceOptions.ask = config->readBoolEntry("AskForReplace",true);
 		_replaceFindList = config->readListEntry("FindList");
 		_replaceList = config->readListEntry("ReplaceList");
-		
+
 		_inMsgstr->setChecked(_replaceOptions.inMsgstr);
 		_inComment->setChecked(_replaceOptions.inComment);
 
@@ -417,20 +419,20 @@ void FindDialog::readSettings()
 		_findOptions.caseSensitive = config->readBoolEntry("CaseSensitive"
                 ,false);
 		_findOptions.wholeWords = config->readBoolEntry("WholeWords",false);
-		_findOptions.ignoreAccelMarker = 
+		_findOptions.ignoreAccelMarker =
             config->readBoolEntry("IgnoreAccelMarker",true);
-		_findOptions.ignoreContextInfo = 
+		_findOptions.ignoreContextInfo =
             config->readBoolEntry("IgnoreContextInfo",true);
 		_findOptions.backwards = config->readBoolEntry("Backwards",false);
 		_findOptions.fromCursor = config->readBoolEntry("FromCursor",false);
 		_findOptions.isRegExp = config->readBoolEntry("RegExp",false);
 		_findList = config->readListEntry("List");
 		if( _regExpButton ) _regExpButton->setEnabled( _findOptions.isRegExp );
-		
-		_inMsgid->setChecked(_findOptions.inMsgid);	
+
+		_inMsgid->setChecked(_findOptions.inMsgid);
 		_inMsgstr->setChecked(_findOptions.inMsgstr);
 		_inComment->setChecked(_findOptions.inComment);
-		
+
 		_caseSensitive->setChecked(_findOptions.caseSensitive);
 		_wholeWords->setChecked(_findOptions.wholeWords);
 		_ignoreAccelMarker->setChecked(_findOptions.ignoreAccelMarker);
@@ -438,10 +440,10 @@ void FindDialog::readSettings()
 		_backwards->setChecked(_findOptions.backwards);
 		_fromCursor->setChecked(_findOptions.fromCursor);
 		_isRegExp->setChecked(_findOptions.isRegExp);
-		
+
 		_findCombo->insertStringList(_findList);
 	}
-	
+
 }
 
 void FindDialog::saveSettings()
@@ -499,7 +501,7 @@ void FindDialog::inButtonsClicked(int id)
 			else {
 					_buttonGrp->setButton(id);
 			}
-			
+
 		}
 	}
 }
