@@ -28,10 +28,11 @@ class ToolSelectionWidget : public KActionSelector
 {
     Q_OBJECT
 public:
-    ToolSelectionWidget( const QStringList& commands, const QValueList<KDataToolInfo> & tools, 
-	QWidget* parent=0, const char* name=0 );
+    ToolSelectionWidget(QWidget* parent=0, const char* name=0 );
 	
     QStringList selectedTools();
+    
+    void loadTools (const QStringList& commands, const QValueList<KDataToolInfo> & tools);
 
 public slots:
     void setSelectedTools( const QStringList& tools );
