@@ -21,9 +21,12 @@
 #ifndef __main_h__
 #define __main_h__
 
-#include <qregexp.h>
+#include "kbproject.h"
+
 #include <kdatatool.h>
 
+#include <qregexp.h>
+
 class ArgumentTool : public KDataTool
 {
     Q_OBJECT
@@ -32,6 +35,7 @@ public:
     ArgumentTool( QObject* parent, const char* name, const QStringList & );
     virtual bool run( const QString& command, void* data, const QString& datatype, const QString& mimetype);
 private:
+    KBabel::Project::Ptr _cache_origin;
     QRegExp _context;
     bool _checkPlurals;
 };
