@@ -21,7 +21,8 @@
 #ifndef __main_h__
 #define __main_h__
 
-#include <qregexp.h>
+#include "kbproject.h"
+
 #include <kdatatool.h>
 
 class ContextTool : public KDataTool
@@ -32,6 +33,7 @@ public:
     ContextTool( QObject* parent, const char* name, const QStringList & );
     virtual bool run( const QString& command, void* data, const QString& datatype, const QString& mimetype);
 private:
+    KBabel::Project::Ptr _cache_origin;
     QRegExp _context;
 };
 
