@@ -22,6 +22,8 @@
 #ifndef __main_h__
 #define __main_h__
 
+#include "kbproject.h"
+
 #include <qregexp.h>
 #include <kdatatool.h>
 
@@ -33,10 +35,9 @@ public:
     WhitespaceTool( QObject* parent, const char* name, const QStringList & );
     virtual bool run( const QString& command, void* data, const QString& datatype, const QString& mimetype);
 private:
-    QRegExp _context;
+    KBabel::Project::Ptr _cache_origin;
     QRegExp _plurals;
     QRegExp _equation;
-    int _neededForms;
 };
 
 #endif
