@@ -3,7 +3,7 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-		2002-2003 by Stanislav Visnovsky
+		2002-2004 by Stanislav Visnovsky
 			    <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
@@ -24,10 +24,17 @@
 
 #include "kbabel.h"
 
+#include "kbabelsettings.h"
 #include "kbabelpref.h"
+#include "projectpref.h"
 #include "kbabelsplash.h"
 #include "regexpextractor.h"
 #include "toolaction.h"
+#include "commentview.h"
+#include "contextview.h"
+#include "charselectview.h"
+#include "taglistview.h"
+#include "sourceview.h"
 
 #include <qdragobject.h>
 #include <qlineedit.h>
@@ -49,18 +56,19 @@
 #include <kled.h>
 #include <klocale.h>
 #include <kiconloader.h>
-#include <kkeydialog.h>
 #include <ktoolbar.h>
 #include <kfiledialog.h>
 #include <kconfig.h>
 #include <kurl.h>
 #include <kdialogbase.h>
 #include <kprogress.h>
+#include <kpushbutton.h>
 #include <kmessagebox.h>
 #include <kwin.h>
 #include <kaction.h>
 #include <kstdaction.h>
 #include <kspelldlg.h>
+#include <ksqueezedtextlabel.h>
 #include <kurldrag.h>
 
 #include "resources.h"
@@ -69,6 +77,9 @@
 #include "kbabeldictbox.h"
 #include "kbmailer.h"
 #include "kbbookmarkhandler.h"
+#include "kbprojectmanager.h"
+#include "projectpref.h"
+#include "projectwizard.h"
 
 #include "version.h"
 
@@ -98,34 +109,32 @@ public:
 };
 
 KBabelMW::KBabelMW(QString projectFile)
-	: KMainWindow(0,0)
+	: KDockMainWindow (), m_charselectorview(0)
 {
-   if( projectFile.isEmpty() ) _projectFile = QString::null;
-   else _projectFile = projectFile;
-
-   if( !projectFile.isEmpty() ) kdDebug(KBABEL) << "KBabel has project file " << _projectFile << endl;
-
-   KBCatalog* catalog=new KBCatalog(_projectFile);
-   init(catalog);
+    _project = ProjectManager::open(projectFile);
+    KBCatalog* catalog=new KBCatalog(projectFile);
+    init(catalog);
 }
 
 KBabelMW::KBabelMW(KBCatalog* catalog, QString projectFile)
-	:KMainWindow(0,0)
+	: KDockMainWindow (), m_charselectorview(0)
 {
-   if( projectFile.isEmpty() ) _projectFile = QString::null;
-   else _projectFile = projectFile;
-
+    _project = ProjectManager::open(projectFile);
     init(catalog);
 }
 
 void KBabelMW::init(KBCatalog* catalog)
 {
+    _config = KSharedConfig::openConfig( "kbabelrc" );
+
     _toolsShortcuts.clear();
 
     _fuzzyLed=0;
     _untransLed=0;
     _errorLed=0;
 
+    _projectDialog=0;
+
     _prefDialog=0;
     prefDialogs.setAutoDelete(true);
 
@@ -133,9 +142,14 @@ void KBabelMW::init(KBCatalog* catalog)
     connect(_statusbarTimer,SIGNAL(timeout()),this
 	,SLOT(clearStatusbarMsg()));
 
-    m_view=new KBabelView(catalog,this, _projectFile);
-    // tell the KMainWindow that this is indeed the main widget
-    setCentralWidget(m_view);
+    // FIXME:
+    Q_ASSERT(_project);
+
+    m_view=new KBabelView(catalog,this, _project);
+
+    setXMLFile ("kbabelui.rc");
+
+    createGUI (0);
 
     // accept dnd
     setAcceptDrops(true);
@@ -144,7 +158,6 @@ void KBabelMW::init(KBCatalog* catalog)
     // setup our menubars and toolbars
     setupStatusBar();
     setupActions();
-
     stateChanged( "fileopened" , StateReverse );
     stateChanged( "readonly", StateNoReverse );
 
@@ -179,14 +192,11 @@ void KBabelMW::init(KBCatalog* catalog)
     connect(catalog,SIGNAL(signalFileOpened(bool)),m_view,SLOT(newFileOpened(bool)));
     connect(catalog,SIGNAL(signalModified(bool)),this,SLOT(showModified(bool)));
 
-
     // allow the view to change the statusbar and caption
     connect(m_view, SIGNAL(signalChangeStatusbar(const QString&)),
             this,   SLOT(changeStatusbar(const QString&)));
     connect(m_view, SIGNAL(signalChangeCaption(const QString&)),
             this,   SLOT(changeCaption(const QString&)));
-//    connect(m_view,SIGNAL(signalNewFileOpened(KURL)),this
-//           ,SLOT(addToRecentFiles(KURL)));
     connect(m_view,SIGNAL(signalFirstDisplayed(bool, bool)),this
            ,SLOT(firstEntryDisplayed(bool, bool)));
     connect(m_view,SIGNAL(signalLastDisplayed(bool, bool)),this
@@ -197,8 +207,8 @@ void KBabelMW::init(KBCatalog* catalog)
            ,SLOT(untranslatedDisplayed(bool)));
     connect(m_view,SIGNAL(signalFaultyDisplayed(bool)),this
            ,SLOT(faultyDisplayed(bool)));
-    connect(m_view,SIGNAL(signalDisplayed(uint)),this
-           ,SLOT(displayedEntryChanged(uint)));
+    connect(m_view,SIGNAL(signalDisplayed(const KBabel::DocPosition&)),this
+           ,SLOT(displayedEntryChanged(const KBabel::DocPosition&)));
     connect(m_view,SIGNAL(signalFuzzyAfterwards(bool)),this
             ,SLOT(hasFuzzyAfterwards(bool)));
     connect(m_view,SIGNAL(signalFuzzyInFront(bool)),this
@@ -223,8 +233,6 @@ void KBabelMW::init(KBCatalog* catalog)
 
     connect(m_view,SIGNAL(signalSearchActive(bool)),this,SLOT(enableStop(bool)));
 
-    connect(m_view,SIGNAL(signalToolsShown()),this,SLOT(checkMenuItemTools()));
-    connect(m_view,SIGNAL(signalCommentsShown()),this,SLOT(checkMenuItemComments()));
     connect(m_view,SIGNAL(signalProgress(int)),_progressBar,SLOT(setProgress(int)));
     connect(m_view,SIGNAL(signalClearProgressBar()),this,SLOT(clearProgressBar()));
     connect(m_view,SIGNAL(signalResetProgressBar(QString,int))
@@ -232,13 +240,9 @@ void KBabelMW::init(KBCatalog* catalog)
 
     connect(m_view,SIGNAL(signalDictionariesChanged())
            , this, SLOT(buildDictMenus()));
-
     connect(m_view,SIGNAL(signalCursorPosChanged(int,int)), this
             , SLOT(updateCursorPosition(int,int)));
 
-    connect(m_view, SIGNAL(signalDisplayed(uint)),
-	    this, SLOT(slotSetCurrentIndex(uint)));
-
     if(!catalog->currentURL().isEmpty())
     {
        enableDefaults(catalog->isReadOnly());
@@ -254,7 +258,7 @@ void KBabelMW::init(KBCatalog* catalog)
        changeCaption(catalog->currentURL().prettyURL());
     }
 
-    mailer = new KBabelMailer( (_projectFile.isEmpty( ) ? QString("kbabelrc") : _projectFile ) );
+    mailer = new KBabelMailer( _project->filename() );
 
     bmHandler = new KBabelBookmarkHandler((QPopupMenu*)factory()->container("bookmark", this));
     // the earlier created KAction for "clear_bookmarks" is now reconnected
@@ -269,16 +273,12 @@ void KBabelMW::init(KBCatalog* catalog)
     connect(m_view, SIGNAL(signalNewFileOpened(KURL)),
 	    bmHandler, SLOT(slotClearBookmarks()));
 
-    KConfig* config;
-    if( !_projectFile.isEmpty() )
-        config=new KConfig(_projectFile);
-    else config=KGlobal::config();
+    _config = KSharedConfig::openConfig( "kbabelrc" );
+    restoreSettings();
 
-    restoreSettings(config);
+    _config->setGroup("KBabel");
 
-    config->setGroup("KBabel");
-
-    if(!config->hasKey("Version"))
+    if(!_config->hasKey("Version"))
     {
       QString encodingStr;
       switch(catalog->saveSettings().encoding)
@@ -306,10 +306,9 @@ void KBabelMW::init(KBCatalog* catalog)
       QTimer::singleShot(1,this,SLOT(optionsPreferences()));
     }
 
-    config->writeEntry("Version",VERSION);
-    config->sync();
-    if ( !_projectFile.isEmpty() )
-       delete config;
+    _config->writeEntry("Version",VERSION);
+    _config->sync();
+
 }
 
 KBabelMW::~KBabelMW()
@@ -318,50 +317,51 @@ KBabelMW::~KBabelMW()
    {
       prefDialogs.remove(_prefDialog);
    }
+   if(_projectDialog)
+   {
+      delete _projectDialog;
+   }
    delete mailer;
    delete bmHandler;
 }
 
 
-void KBabelMW::setSettings(SearchSettings searchOpts, EditorSettings editOpts
-                       , SaveSettings saveOpts,IdentitySettings idOpts)
+void KBabelMW::setSettings(SaveSettings saveOpts,IdentitySettings idOpts)
 {
-   m_view->setSettings(searchOpts);
-   m_view->setSettings(editOpts);
+   m_view->updateSettings();
    m_view->catalog()->setSettings(saveOpts);
    m_view->catalog()->setSettings(idOpts);
 
    if(_fuzzyLed)
    {
-      _fuzzyLed->setColor(editOpts.ledColor);
+      _fuzzyLed->setColor(KBabelSettings::ledColor());
    }
    if(_untransLed)
    {
-      _untransLed->setColor(editOpts.ledColor);
+      _untransLed->setColor(KBabelSettings::ledColor());
    }
    if(_errorLed)
    {
-      _errorLed->setColor(editOpts.ledColor);
+      _errorLed->setColor(KBabelSettings::ledColor());
    }
 
 }
 
-void KBabelMW::setSettings(SearchSettings searchOpts, EditorSettings editOpts)
+void KBabelMW::updateSettings()
 {
-   m_view->setSettings(searchOpts);
-   m_view->setSettings(editOpts);
+   m_view->updateSettings();
 
    if(_fuzzyLed)
    {
-      _fuzzyLed->setColor(editOpts.ledColor);
+      _fuzzyLed->setColor(KBabelSettings::ledColor());
    }
    if(_untransLed)
    {
-      _untransLed->setColor(editOpts.ledColor);
+      _untransLed->setColor(KBabelSettings::ledColor());
    }
    if(_errorLed)
    {
-      _errorLed->setColor(editOpts.ledColor);
+      _errorLed->setColor(KBabelSettings::ledColor());
    }
 
 }
@@ -401,10 +401,10 @@ void KBabelMW::setupActions()
    // the edit menu
    action = KStdAction::undo(m_view, SLOT(undo()), actionCollection());
    action = KStdAction::redo(m_view, SLOT(redo()), actionCollection());
-   action = KStdAction::cut(m_view, SLOT(textCut()), actionCollection());
-   action = KStdAction::copy(m_view, SLOT(textCopy()), actionCollection());
-   action = KStdAction::paste(m_view, SLOT(textPaste()), actionCollection());
-   action = KStdAction::selectAll(m_view, SLOT(selectAll()), actionCollection());
+   action = KStdAction::cut(m_view, SIGNAL(signalCut()), actionCollection());
+   action = KStdAction::copy(m_view, SIGNAL(signalCopy()), actionCollection());
+   action = KStdAction::paste(m_view, SIGNAL(signalPaste()), actionCollection());
+   action = KStdAction::selectAll(m_view, SIGNAL(signalSelectAll()), actionCollection());
    action = KStdAction::find(m_view, SLOT(find()), actionCollection());
    action = KStdAction::findNext(m_view, SLOT(findNext()), actionCollection());
    action = KStdAction::findPrev(m_view, SLOT(findPrev()), actionCollection());
@@ -419,8 +419,8 @@ void KBabelMW::setupActions()
 			actionCollection(), "search2msgstr");
    action = new KAction(i18n("Copy Msgstr to Other &Plurals"), Key_F11, m_view
                    ,SLOT(plural2msgstr()), actionCollection(), "plural2msgstr");
-   action = new KAction(i18n("Copy Selected Character to Msgstr"), Key_F10, m_view
-                   ,SLOT(insertSelectedChar()), actionCollection(), "char2msgstr");
+   action = new KAction(i18n("Copy Selected Character to Msgstr"), Key_F10, m_charselectorview
+                   ,SLOT(emitChar()), actionCollection(), "char2msgstr");
 
    a_unsetFuzzy = new KAction(i18n("To&ggle Fuzzy Status"), "togglefuzzy", CTRL+Key_U, m_view
                  , SLOT(removeFuzzyStatus()), actionCollection(), "edit_toggle_fuzzy");
@@ -544,7 +544,7 @@ void KBabelMW::setupActions()
            , SLOT(editDictionary(const QString)));
 
 
-   actionMenu=new KActionMenu(i18n("Con&figure Dictionary..."),
+   actionMenu=new KActionMenu(i18n("Con&figure Dictionary"),
          "transsearch",actionCollection(),"dict_configure");
    configDictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),this);
    connect(configDictMenu,SIGNAL(activated(const QString)), m_view
@@ -558,6 +558,24 @@ void KBabelMW::setupActions()
 
    buildDictMenus();
 
+    // the project menu
+   action = new KAction(i18n("&New..."), "filenew"
+           , this, SLOT(projectNew()),actionCollection()
+           ,"project_new");
+
+   action = new KAction(i18n("&Open..."), "fileopen"
+           , this, SLOT(projectOpen()),actionCollection()
+           ,"project_open");
+
+   action = new KAction(i18n("C&lose"), "fileclose"
+           , this, SLOT(projectClose()),actionCollection()
+           ,"project_close");
+   action->setEnabled (_project->filename() != KBABEL_DEFAULTPROJECT);
+
+   action = new KAction(i18n("&Configure..."), "configure"
+           , this, SLOT(projectConfigure()),actionCollection()
+           ,"project_settings");
+
     // the tools menu
    action = new KAction(i18n("&Spell Check..."), "spellcheck", CTRL+Key_I
            , m_view, SLOT(spellcheckCommon()),actionCollection()
@@ -608,23 +626,11 @@ void KBabelMW::setupActions()
    new KAction( i18n("Toggle Edit Mode"), 0, Key_Insert,this,SLOT(toggleEditMode()), actionCollection(), "toggle_insert_mode");
 
     // next, the settings menu
-#if KDE_IS_VERSION(3,1,90)
     createStandardStatusBarAction();
-#else
-    toggleAction=KStdAction::showStatusbar(this,SLOT(dummySlot()), actionCollection());
-    connect(toggleAction,SIGNAL(toggled(bool)), this, SLOT(optionsShowStatusbar(bool)));
-#endif
 
     KStdAction::configureToolbars(this,SLOT(optionsEditToolbars()),actionCollection());
 
-    toggleAction = new KToggleAction(i18n("Show Co&mments"), 0,
-                  actionCollection(),"settings_show_comments");
-    connect(toggleAction,SIGNAL(toggled(bool)), m_view, SLOT(showComments(bool)));
-    toggleAction = new KToggleAction(i18n("Show T&ools"), 0,
-                  actionCollection(),"settings_show_tools");
-    connect(toggleAction,SIGNAL(toggled(bool)), m_view, SLOT(showTools(bool)));
-
-    KStdAction::keyBindings(this,SLOT(optionsConfigure()),actionCollection());
+    KStdAction::keyBindings(guiFactory(),SLOT(configureShortcuts()),actionCollection());
     KStdAction::preferences(this,SLOT(optionsPreferences()),actionCollection());
 
     setStandardToolBarMenuEnabled ( true );
@@ -649,7 +655,10 @@ void KBabelMW::setupActions()
 
    setupDynamicActions();
 
-   createGUI();
+   createGUI(0);
+
+   QPopupMenu *popup = static_cast<QPopupMenu*>(factory()->container("settings",this));
+   popup->insertItem( i18n("&Views"), dockHideShowMenu(), -1, 0 );
 }
 
 
@@ -660,9 +669,9 @@ void KBabelMW::setupStatusBar()
     statusBar()->insertItem(i18n("Fuzzy: 0"),ID_STATUS_FUZZY);
     statusBar()->insertItem(i18n("Untranslated: 0"),ID_STATUS_UNTRANS);
 
-    if(m_view->editorSettings().ledInStatusbar)
+    if(KBabelSettings::ledInStatusbar())
     {
-       QColor ledColor=m_view->editorSettings().ledColor;
+       QColor ledColor=KBabelSettings::ledColor();
        QHBox* statusBox = new QHBox(statusBar(),"statusBox");
        statusBox->setSpacing(2);
        new QLabel(" "+i18n("Status: "),statusBox);
@@ -692,7 +701,7 @@ void KBabelMW::setupStatusBar()
 
     QHBox* progressBox = new QHBox(statusBar(),"progressBox");
     progressBox->setSpacing(2);
-    _progressLabel = new QLabel( "", progressBox );
+    _progressLabel = new KSqueezedTextLabel( "", progressBox );
     _progressBar=new MyKProgress(progressBox,"progressbar");
     _progressBar->hide();
     progressBox->setStretchFactor(_progressBar,1);
@@ -810,55 +819,34 @@ void KBabelMW::setupDynamicActions()
    }
 }
 
-void KBabelMW::saveSettings( KConfig *config )
+void KBabelMW::saveSettings()
 {
     {
-        KConfigGroupSaver saver(config,"View");
-
-        KToggleAction* toggleAction;
-
-        toggleAction=(KToggleAction*)actionCollection()->action("settings_show_tools");
-        config->writeEntry("Tools",toggleAction->isChecked());
-        toggleAction=(KToggleAction*)actionCollection()->action("settings_show_comments");
-        config->writeEntry("Comments",toggleAction->isChecked());
-
-	saveMainWindowSettings(config, "View");
+	saveMainWindowSettings(_config, "View");
+	writeDockConfig (_config, "View");
     }
 
     {
-       a_recent->saveEntries(config);
+       a_recent->saveEntries(_config);
     }
 
-    config->sync();
+    _config->sync();
 }
 
-void KBabelMW::restoreSettings( KConfig* config )
+void KBabelMW::restoreSettings()
 {
     {
-       applyMainWindowSettings(config, "View");
+       applyMainWindowSettings(_config, "View");
+       KConfigGroupSaver saver(_config,"View");
 
-       KToggleAction* toggleAction=(KToggleAction*)actionCollection()->action(KStdAction::stdName(KStdAction::ShowStatusbar));
-       toggleAction->setChecked(!statusBar()->isHidden());
+       _config->setGroup("View");
+       m_view->restoreView(_config);
 
-       KConfigGroupSaver saver(config,"View");
-
-       toggleAction=(KToggleAction*)actionCollection()->action("settings_show_comments");
-       bool show=config->readBoolEntry("Comments",true);
-       toggleAction->setChecked(show);
-       m_view->showComments(show); // hmm, this should be called by the action, but it doesn't
-
-       toggleAction=(KToggleAction*)actionCollection()->action(
-                   "settings_show_tools");
-       show=config->readBoolEntry("Tools",true);
-       toggleAction->setChecked(show);
-       m_view->showTools(show); // hmm, this should be called by the action, but it doesn't
-
-       config->setGroup("View");
-       m_view->restoreView(config);
+	readDockConfig (_config, "View");
     }
 
     {
-       a_recent->loadEntries(config);
+       a_recent->loadEntries(_config);
 
        // cleanup maybe broken list
        QStringList list = a_recent->items();
@@ -918,7 +906,7 @@ bool KBabelMW::queryClose()
        return false;
    }
 
-   if(m_view->isLastView() && m_view->isModified())
+   if(m_view->isModified())
    {
       switch(KMessageBox::warningYesNoCancel(this,
       i18n("The document contains unsaved changes.\n\
@@ -941,16 +929,11 @@ Do you want to save your changes or discard them?"),i18n("Warning"),
 
 bool KBabelMW::queryExit()
 {
-   KConfig* config;
-   if( _projectFile.isEmpty() ) config=KGlobal::config();
-   else config=new KConfig(_projectFile);
-   saveSettings(config);
-   m_view->saveSettings(config);
-   config->setGroup("View");
-   m_view->saveView(config);
+   saveSettings();
+   _config->setGroup("View");
+   m_view->saveView(_config);
 
-   if ( !_projectFile.isEmpty() )
-      delete config;
+   m_view->saveSettings();
    return true;
 }
 
@@ -981,7 +964,7 @@ void KBabelMW::openRecent(const KURL& url)
    KBabelView *view = KBabelView::viewForURL(url,QString::null);
    if(view)
    {
-       KWin::setActiveWindow(view->topLevelWidget()->winId());
+       KWin::activateWindow(view->topLevelWidget()->winId());
        return;
    }
 
@@ -995,13 +978,13 @@ void KBabelMW::open(const KURL& url)
 
 void KBabelMW::open(const KURL& url, const QString package, bool newWindow)
 {
-   kdDebug(KBABEL) << "opening file with project:" << _projectFile << endl;
+   kdDebug(KBABEL) << "opening file with project:" << _project->filename() << endl;
    kdDebug(KBABEL) << "URL:" << url.prettyURL() << endl;
-   KBabelView *view = KBabelView::viewForURL(url, _projectFile);
+   KBabelView *view = KBabelView::viewForURL(url, _project->filename());
    if(view)
    {
 	kdDebug(KBABEL) << "there is a such view" << endl;
-       KWin::setActiveWindow(view->topLevelWidget()->winId());
+       KWin::activateWindow(view->topLevelWidget()->winId());
        return;
    }
 
@@ -1119,17 +1102,16 @@ void KBabelMW::fileMail()
 
 void KBabelMW::fileNewView()
 {
-   KBabelMW* b=new KBabelMW(m_view->catalog(),_projectFile);
-   b->setSettings(m_view->searchSettings(),m_view->editorSettings());
+   KBabelMW* b=new KBabelMW(m_view->catalog(),_project->filename());
+   b->updateSettings();
    b->initBookmarks(bmHandler->bookmarks());
    b->show();
 }
 
 KBabelMW* KBabelMW::fileNewWindow()
 {
-   KBabelMW* b=new KBabelMW(_projectFile);
-   b->setSettings(m_view->searchSettings(),m_view->editorSettings()
-            ,m_view->catalog()->saveSettings(),m_view->catalog()->identitySettings());
+   KBabelMW* b=new KBabelMW(_project->filename());
+   b->setSettings(m_view->catalog()->saveSettings(),m_view->catalog()->identitySettings());
    b->show();
 
    return b;
@@ -1170,67 +1152,19 @@ void KBabelMW::optionsEditToolbars()
 
 void KBabelMW::newToolbarConfig()
 {
-    createGUI();
+    createGUI(0);
     applyMainWindowSettings( KGlobal::config(), "View" );
 }
 
-void KBabelMW::checkMenuItemTools()
-{
-   KToggleAction* action=(KToggleAction*)actionCollection()->action("settings_show_tools");
-   action->setChecked(true);
-}
-
-void KBabelMW::checkMenuItemComments()
-{
-   KToggleAction* action=(KToggleAction*)actionCollection()->action("settings_show_comments");
-   action->setChecked(true);
-}
-
-void KBabelMW::optionsConfigure()
-{
-
-    KKeyDialog::configure(actionCollection());
-}
-
 void KBabelMW::optionsPreferences()
 {
     if(!_prefDialog)
     {
-        _prefDialog = new KBabelPreferences(m_view->searchSettings()
-                        , m_view->editorSettings()
-			, m_view->spellcheckSettings()
-                        , m_view->catalog()->saveSettings()
-                        , m_view->catalog()->identitySettings()
-                        , m_view->catalog()->miscSettings()
-			, m_view->sourceContextSettings()
-                        , m_view->dictionaries());
+        _prefDialog = new KBabelPreferences(m_view->dictionaries());
         prefDialogs.append(_prefDialog);
 
-        connect(_prefDialog,SIGNAL(identityOptionsChanged(KBabel::IdentitySettings))
-                ,m_view->catalog(),SLOT(setSettings(KBabel::IdentitySettings)));
-        connect(_prefDialog,SIGNAL(saveOptionsChanged(KBabel::SaveSettings))
-                ,m_view->catalog(),SLOT(setSettings(KBabel::SaveSettings)));
-        connect(_prefDialog,SIGNAL(editorOptionsChanged(EditorSettings))
-                ,m_view,SLOT(setSettings(EditorSettings)));
-        connect(_prefDialog,SIGNAL(spellcheckOptionsChanged(SpellcheckSettings))
-                ,m_view,SLOT(setSettings(SpellcheckSettings)));
-        connect(_prefDialog,SIGNAL(searchOptionsChanged(SearchSettings))
-                ,m_view,SLOT(setSettings(SearchSettings)));
-        connect(_prefDialog,SIGNAL(miscOptionsChanged(KBabel::MiscSettings))
-                , m_view->catalog(),SLOT(setSettings(KBabel::MiscSettings)));
-        connect(_prefDialog,SIGNAL(sourceContextOptionsChanged(SourceContextSettings))
-                , m_view,SLOT(setSettings(SourceContextSettings)));
-
-        connect(m_view->catalog(),SIGNAL(signalSettingsChanged(KBabel::SaveSettings))
-                ,_prefDialog, SLOT(updateSaveSettings(KBabel::SaveSettings)));
-        connect(m_view->catalog()
-                , SIGNAL(signalSettingsChanged(KBabel::IdentitySettings)),_prefDialog
-                , SLOT(updateIdentitySettings(KBabel::IdentitySettings)));
-        connect(m_view,SIGNAL(signalSearchSettingsChanged(SearchSettings))
-                ,_prefDialog, SLOT(updateSearchSettings(SearchSettings)));
-
-        connect(m_view->catalog(),SIGNAL(signalSettingsChanged(KBabel::MiscSettings))
-                ,_prefDialog, SLOT(updateMiscSettings(KBabel::MiscSettings)));
+        connect(_prefDialog,SIGNAL(settingsChanged())
+                ,m_view,SLOT(updateSettings()));
     }
 
     int prefHeight=_prefDialog->height();
@@ -1249,7 +1183,7 @@ void KBabelMW::optionsPreferences()
     }
 
     _prefDialog->raise();
-    KWin::setActiveWindow(_prefDialog->winId());
+    KWin::activateWindow(_prefDialog->winId());
 }
 
 void KBabelMW::setLedColor(const QColor& color)
@@ -1390,9 +1324,10 @@ void KBabelMW::faultyDisplayed(bool flag)
 }
 
 
-void KBabelMW::displayedEntryChanged(uint index)
+void KBabelMW::displayedEntryChanged(const KBabel::DocPosition& pos)
 {
-   statusBar()->changeItem(i18n("Current: %1").arg(index),ID_STATUS_CURRENT);
+   statusBar()->changeItem(i18n("Current: %1").arg(pos.item+1),ID_STATUS_CURRENT);
+  _currentIndex = pos.item;
 }
 
 void KBabelMW::setNumberOfTotal(uint number)
@@ -1538,7 +1473,9 @@ void KBabelMW::clearStatusbarMsg()
 void KBabelMW::changeCaption(const QString& text)
 {
     // display the text on the caption
-    setCaption(text,m_view->isModified());
+    setCaption(text + ( _project->filename () != KBABEL_DEFAULTPROJECT ?
+	    " (" + _project->name() + ")" : "" /* KDE 3.4: i18n("(No project)")*/ )
+	,m_view->isModified());
 }
 
 
@@ -1696,7 +1633,7 @@ void KBabelMW::spellcheckDone( int result)
 	QString file = _toSpellcheck.first();
 	_toSpellcheck.pop_front();
 	if( m_view->isModified() ) fileSave();
-	open(file, QString::null, false);
+	open(KURL( file ), QString::null, false);
 	kdDebug(KBABEL) << "Starting another spellcheck" << endl;
 	QTimer::singleShot( 1, m_view, SLOT(spellcheckAllMulti()));
     }
@@ -1707,11 +1644,6 @@ void KBabelMW::initBookmarks(QPtrList<KBabelBookmark> list)
   bmHandler->setBookmarks(list);
 }
 
-void KBabelMW::slotSetCurrentIndex(uint index)
-{
-  _currentIndex = index;
-}
-
 void KBabelMW::slotAddBookmark()
 {
   bmHandler->addBookmark(_currentIndex,
@@ -1726,4 +1658,96 @@ void KBabelMW::slotOpenBookmark(int index)
   m_view->gotoEntry(pos);
 }
 
+void KBabelMW::projectNew()
+{
+    KBabel::Project::Ptr p = KBabel::ProjectWizard::newProject();
+    if( p )
+    {
+	_project = p;
+	m_view->useProject(p);
+	changeProjectActions(p->filename());
+    }
+}
+
+void KBabelMW::projectOpen()
+{
+    QString oldproject = m_view->project();
+    if( oldproject == KBABEL_DEFAULTPROJECT )
+    {
+	oldproject = "";
+    }
+    QString file = KFileDialog::getOpenFileName(oldproject, i18n("*|All Files"), this);
+    if (file.isEmpty())
+    {
+        return;
+    }
+    KBabel::Project::Ptr p = KBabel::ProjectManager::open(file);
+    if( p )
+    {
+	_project = p;
+	m_view->useProject(p);
+	changeProjectActions(file);
+    }
+}
+
+void KBabelMW::projectOpen(const QString& file)
+{
+    QString oldproject = m_view->project();
+    if( oldproject == KBABEL_DEFAULTPROJECT )
+    {
+	oldproject = "";
+    }
+    if (file.isEmpty())
+    {
+        return;
+    }
+    KBabel::Project::Ptr p = KBabel::ProjectManager::open(file);
+    if( p )
+    {
+	_project = p;
+	m_view->useProject(p);
+	changeProjectActions(file);
+    }
+}
+
+void KBabelMW::projectClose()
+{
+    m_view->useProject( KBabel::ProjectManager::open(KBABEL_DEFAULTPROJECT) );
+    changeProjectActions(KBABEL_DEFAULTPROJECT);
+}
+
+void KBabelMW::changeProjectActions(const QString& project)
+{
+    bool def = project == KBABEL_DEFAULTPROJECT;
+
+    KAction* saveAction=(KAction*)actionCollection()->action( "project_close" );
+    saveAction->setEnabled( ! def );
+}
+
+void KBabelMW::projectConfigure()
+{
+    if(!_projectDialog)
+    {
+        _projectDialog = new ProjectDialog(_project);
+    }
+
+    int prefHeight=_projectDialog->height();
+    int prefWidth=_projectDialog->width();
+    int width=this->width();
+    int height=this->height();
+
+    int x=width/2-prefWidth/2;
+    int y=height/2-prefHeight/2;
+
+    _projectDialog->move(mapToGlobal(QPoint(x,y)));
+
+    if(!_projectDialog->isVisible())
+    {
+       _projectDialog->show();
+    }
+
+    _projectDialog->raise();
+    KWin::activateWindow(_projectDialog->winId());
+}
+
 #include "kbabel.moc"
