@@ -3,7 +3,7 @@
 
   Copyright (C) 1999-2001 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-		2002-2003  by Stanislav Visnovsky
+		2002-2004  by Stanislav Visnovsky
 			    <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
@@ -54,11 +54,11 @@ public:
     virtual void gotoFileEntry(QCString url, QCString msgid);
     virtual void gotoFileEntry(QCString url, QCString package, int msgid);
     virtual void gotoFileEntry(QCString url, QCString package, int msgid, QCString projectFile);
-    virtual bool findInFile(QCString fileSource, QCString url, 
+    virtual bool findInFile(QCString fileSource, QCString url,
 	QString findStr, int caseSensitive, int wholeWords, int isRegExp,
 	int inMsgid, int inMsgstr, int inComment,
 	int ignoreAccelMarker, int ignoreContextInfo, int askForNextFile, int askForSave);
-    virtual bool replaceInFile(QCString fileSource, QCString url, 
+    virtual bool replaceInFile(QCString fileSource, QCString url,
 	QString findStr, QString replaceStr, int caseSensitive, int wholeWords, int isRegExp,
 	int inMsgid, int inMsgstr, int inComment,
 	int ignoreAccelMarker, int ignoreContextInfo, int ask, int askForNextFile, int askForSave);
@@ -98,14 +98,19 @@ int KBabelApp::newInstance()
     {
         first=false;
     }
-        
-    // see if we are starting with session management => isRestored and first
+
+    // see if we are starting with session management
+#if KDE_IS_VERSION(3,3,0)
+    if (!restoringSession())
+#else
     if (!isRestored() || !first)
+#endif
     {
+	kdDebug () << "Suspending DCOP" << endl;
 	kapp->dcopClient()->suspend();
-    
+
         KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-        
+
         QTimer timer;
         QWidget *splash=0;
         bool showSplash=args->isSet("splash");
@@ -123,13 +128,20 @@ int KBabelApp::newInstance()
 	{
 	    QFileInfo fi(projectFile);
 	    projectFile = fi.absFilePath();
+	} else
+	{
+	    projectFile = KBABEL_DEFAULTPROJECT;
 	}
-	
+
+	kdDebug() << "Project: " << projectFile << endl;
 	QCString msgid=args->getOption("gotomsgid");
         if(!msgid.isEmpty() && args->count() > 0)
         {
             kdDebug(KBABEL) << "gotomsgid" << endl;
             QString m = QString::fromLocal8Bit(msgid);
+
+	    kdDebug () << "Resuming DCOP" << endl;
+	    kapp->dcopClient()->resume();
             kbInterface->gotoFileEntry(args->url(0).url().utf8(),m.utf8());
         }
         else
@@ -147,15 +159,18 @@ int KBabelApp::newInstance()
 
             if(!widget)
                 widget=new KBabelMW(projectFile);
-        
+
             while(timer.isActive()) // let the user admire the splash screen ;-)
                 processEvents();
-        
+
             widget->show();
             for (int i=0; i < args->count(); i++)
             {
                widget->open( args->url(i) , QString::null, i != 0 );
             }
+
+	    kdDebug () << "Resuming DCOP" << endl;
+	    kapp->dcopClient()->resume();
         }
 
 
@@ -177,8 +192,6 @@ int KBabelApp::newInstance()
                     "Thanks.", "Warning");
             */
         }
-
-	kapp->dcopClient()->resume();
     }
 
     return 0;
@@ -191,20 +204,24 @@ KBabelInterface::KBabelInterface()
 
 void KBabelInterface::openURL(QCString url, QCString package, WId window, int newWindow)
 {
-    openURL(url,package,window,newWindow, QCString());
+    openURL(url,package,window,newWindow, KBABEL_DEFAULTPROJECT);
 }
 
 void KBabelInterface::openURL(QCString url, QCString package, WId window, int newWindow, QCString projectFile)
 {
     QString project(projectFile);
-    
+
     kdDebug() << "openURL " << url << endl;
-    
+
     KURL u(QString::fromLocal8Bit(url));
+
+    kdDebug () << "Suspending DCOP" << endl;
+    kapp->dcopClient()->suspend();
+
     KBabelMW *kb = KBabelMW::winForURL(u,project);
     if(kb)
     {
-        KWin::setActiveWindow(kb->topLevelWidget()->winId());
+        KWin::activateWindow(kb->topLevelWidget()->winId());
     }
     else
     {
@@ -217,13 +234,17 @@ void KBabelInterface::openURL(QCString url, QCString package, WId window, int ne
 	    if( mw->inherits("KBabelMW") && mw->winId() == window)
     	    {
         	kb = static_cast<KBabelMW*>(mw);
-        	KWin::setActiveWindow(kb->topLevelWidget()->winId());
+        	KWin::activateWindow(kb->topLevelWidget()->winId());
         	kb->open(u, QString::fromUtf8(package),newWindow);
+
+		kdDebug () << "Resuming DCOP" << endl;
+		kapp->dcopClient()->resume();
+
 		return ;
 	    }
 	    mw = KMainWindow::memberList->next();
         }
-	
+
 	// now, the empty window
 	kb = KBabelMW::emptyWin(projectFile);
 	if (kb)
@@ -231,10 +252,15 @@ void KBabelInterface::openURL(QCString url, QCString package, WId window, int ne
 	    // here, we don't care about "open in new window", because
 	    // it's empty
     	    KWin::setActiveWindow(kb->topLevelWidget()->winId());
+	    kb->projectOpen(projectFile);
     	    kb->open(u,QString::fromUtf8(package),false);
+
+	    kdDebug () << "Resuming DCOP" << endl;
+	    kapp->dcopClient()->resume();
+
 	    return;
 	}
-	
+
         if(KMainWindow::memberList && !KMainWindow::memberList->isEmpty())
             mw=KMainWindow::memberList->first();
 
@@ -242,38 +268,49 @@ void KBabelInterface::openURL(QCString url, QCString package, WId window, int ne
 	    if( mw->inherits("KBabelMW") && static_cast<KBabelMW*>(mw)->project()==project)
     	    {
         	kb = static_cast<KBabelMW*>(mw);
-        	KWin::setActiveWindow(kb->topLevelWidget()->winId());
+        	KWin::activateWindow(kb->topLevelWidget()->winId());
         	kb->open(u, QString::fromUtf8(package),newWindow);
+
+		kdDebug () << "Resuming DCOP" << endl;
+		kapp->dcopClient()->resume();
+
 		return ;
 	    }
 	    mw = KMainWindow::memberList->next();
         }
 
-        if( !mw ) 
+        if( !mw )
 	{
 	    kb = new KBabelMW(project);
     	    kb->show();
 	} else kb = static_cast<KBabelMW*>(mw);
-        KWin::setActiveWindow(kb->topLevelWidget()->winId());
+        KWin::activateWindow(kb->topLevelWidget()->winId());
         kb->open(u,QString::fromUtf8(package),newWindow);
     }
+    
+    kdDebug () << "Resuming DCOP" << endl;
+    kapp->dcopClient()->resume();
 }
 
 void KBabelInterface::openTemplate(QCString openFilename, QCString saveFilename, QCString package, int newWindow)
 {
-    openTemplate(openFilename, saveFilename, package, newWindow, QCString());
+    openTemplate(openFilename, saveFilename, package, newWindow, KBABEL_DEFAULTPROJECT);
 }
 
 void KBabelInterface::openTemplate(QCString openFilename, QCString saveFilename, QCString package, int newWindow, QCString projectFile)
 {
     QString project(projectFile);
-    
+
     KURL u(saveFilename.data());
     KURL t(openFilename.data());
+
+    kdDebug () << "Suspending DCOP" << endl;
+    kapp->dcopClient()->suspend();
+
     KBabelMW *kb = KBabelMW::winForURL(u, project);
     if(kb)
     {
-        KWin::setActiveWindow(kb->topLevelWidget()->winId());
+        KWin::activateWindow(kb->topLevelWidget()->winId());
     }
     else
     {
@@ -284,26 +321,30 @@ void KBabelInterface::openTemplate(QCString openFilename, QCString saveFilename,
         if(mw && mw->inherits("KBabelMW") && static_cast<KBabelMW*>(mw)->project()==project)
         {
             kb = static_cast<KBabelMW*>(mw);
-            KWin::setActiveWindow(kb->topLevelWidget()->winId());
+            KWin::activateWindow(kb->topLevelWidget()->winId());
+	    kb->projectOpen(projectFile);
             kb->openTemplate(t,u,QString::fromUtf8(package),newWindow);
         }
         else
         {
             kb = new KBabelMW(project);
             kb->show();
-            KWin::setActiveWindow(kb->topLevelWidget()->winId());
+            KWin::activateWindow(kb->topLevelWidget()->winId());
             kb->openTemplate(t,u,QString::fromUtf8(package));
         }
     }
+
+    kdDebug () << "Resuming DCOP" << endl;
+    kapp->dcopClient()->resume();
 }
 
 void KBabelInterface::gotoFileEntry(QCString url, QCString m)
 {
     QString msgid = QString::fromUtf8(m);
-    KBabelMW *kb = findInstance( url, QCString(), QCString() );
+    KBabelMW *kb = findInstance( url, KBABEL_DEFAULTPROJECT, QCString() );
 
     if(!kb) return;
-    
+
     int index = kb->m_view->catalog()->indexForMsgid(msgid);
     if(index >= 0)
     {
@@ -315,34 +356,34 @@ void KBabelInterface::gotoFileEntry(QCString url, QCString m)
 }
 
 void KBabelInterface::gotoFileEntry(QCString url, QCString package, int m)
-{    
-    gotoFileEntry(url, package, m, QCString() );
+{
+    gotoFileEntry(url, package, m, KBABEL_DEFAULTPROJECT );
 }
 
 void KBabelInterface::gotoFileEntry(QCString url, QCString package, int m, QCString projectFile)
-{    
+{
     QString project(projectFile);
     KBabelMW *kb = findInstance( url, projectFile, package );
 
     if(!kb) return;
-    
+
     KBabel::DocPosition pos;
     pos.item=m;
     pos.form=0;
     kb->m_view->gotoEntry(pos);
 }
 
-bool KBabelInterface::findInFile(QCString fileSource, QCString url, 
+bool KBabelInterface::findInFile(QCString fileSource, QCString url,
 	QString findStr, int caseSensitive, int wholeWords, int isRegExp,
 	int inMsgid, int inMsgstr, int inComment,
 	int ignoreAccelMarker, int ignoreContextInfo, int askForNextFile, int askForSave)
-{    
+{
     kdDebug(KBABEL) << "findInFile (" <<fileSource<< "): " << url << " for " << findStr << endl;
-    
-    KBabelMW *kb = findInstance(url, QCString(), QCString());
+
+    KBabelMW *kb = findInstance(url, KBABEL_DEFAULTPROJECT, QCString());
 
     if(!kb) return false;
-    
+
     KBabel::FindOptions options;
     options.findStr = findStr;
     options.caseSensitive = (caseSensitive>0);
@@ -358,19 +399,19 @@ bool KBabelInterface::findInFile(QCString fileSource, QCString url,
     options.askForNextFile = (askForNextFile>0);
     options.askForSave = (askForSave>0);
     kb->m_view->findInFile(fileSource, options);
-    
+
     return true;
 }
 
-bool KBabelInterface::replaceInFile(QCString fileSource, QCString url, 
+bool KBabelInterface::replaceInFile(QCString fileSource, QCString url,
 	QString findStr, QString replaceStr, int caseSensitive, int wholeWords, int isRegExp,
 	int inMsgid, int inMsgstr, int inComment,
 	int ignoreAccelMarker, int ignoreContextInfo, int ask, int askForNextFile, int askForSave)
-{    
+{
     kdDebug(KBABEL) << "replaceInFile (" <<fileSource<< "): " << url << " for " << findStr << endl;
 
-    KBabelMW *kb = findInstance( url, QCString(), QCString() );
-    
+    KBabelMW *kb = findInstance( url, KBABEL_DEFAULTPROJECT, QCString() );
+
     if( !kb ) return false;
 
     KBabel::ReplaceOptions options;
@@ -390,21 +431,24 @@ bool KBabelInterface::replaceInFile(QCString fileSource, QCString url,
     options.askForNextFile = (askForNextFile>0);
     options.askForSave = (askForSave>0);
     kb->m_view->replaceInFile(fileSource, options);
-    
+
     return true;
 }
 
 void KBabelInterface::spellcheck(QStringList fileList)
 {
     QCString nullString;
-    KBabelMW *kb = findInstance(nullString, nullString, nullString);
+    KBabelMW *kb = findInstance(nullString, KBABEL_DEFAULTPROJECT, nullString);
     kb->show();
     kb->spellcheckMoreFiles( fileList );
 }
 
 KBabelMW* KBabelInterface::findInstance( QCString url, QCString project, QCString package)
 {
-    KURL u = url;
+    kdDebug () << "Suspending DCOP" << endl;
+    kapp->dcopClient()->suspend();
+
+    KURL u ( url );
     KBabelMW *kb = 0;
     if( !url.isNull() )
     {
@@ -412,26 +456,38 @@ KBabelMW* KBabelInterface::findInstance( QCString url, QCString project, QCStrin
 
 	if(kb)
 	{
-    	    KWin::setActiveWindow(kb->topLevelWidget()->winId());
+    	    KWin::activateWindow(kb->topLevelWidget()->winId());
 	}
     }
-    
+
     if( !kb )
     {
 	kb = KBabelMW::emptyWin(project);
-	if( !kb ) kb = new KBabelMW(project);
+	if( !kb ) 
+	{
+	    kb = new KBabelMW(project);
+	}
+	else
+	{
+	    kb->projectOpen(project);
+	}
+
         kb->show();
         if( !url.isEmpty() ) kb->open(u,QString::fromUtf8(package),false);
-    } 
+    }
+
+    kdDebug () << "Resuming DCOP" << endl;
+    kapp->dcopClient()->resume();
+
     return kb;
 }
 
 static KCmdLineOptions options[] =
 {
    {"gotomsgid <msgid>",I18N_NOOP("Go to entry with msgid <msgid>"),0},
-   {"nosplash",I18N_NOOP("disable splashscreen at startup"),0},
+   {"nosplash",I18N_NOOP("Disable splashscreen at startup"),0},
    {"project <configfile>",I18N_NOOP("File to load configuration from"),0},
-   {"+[file]",I18N_NOOP("files to open"),0},
+   {"+[file]",I18N_NOOP("Files to open"),0},
    KCmdLineLastOption
 };
 
@@ -440,7 +496,7 @@ int main(int argc, char **argv)
 {
     KAboutData about("kbabel",I18N_NOOP("KBabel"),VERSION,
        I18N_NOOP("An advanced PO file editor"),KAboutData::License_GPL,
-       I18N_NOOP("(c) 1999,2000,2001,2002,2003 The KBabel developers"),0,"http://i18n.kde.org/tools/kbabel");
+       I18N_NOOP("(c) 1999,2000,2001,2002,2003,2004 The KBabel developers"),0,"http://i18n.kde.org/tools/kbabel");
 
     about.addAuthor("Matthias Kiefer",I18N_NOOP("Original author"),"kiefer@kde.org");
     about.addAuthor("Wolfram Diestel"
@@ -451,7 +507,7 @@ int main(int argc, char **argv)
             ,"rizzi@kde.org");
     about.addAuthor("Stanislav Visnovsky",I18N_NOOP("Current maintainer, porting to KDE3/Qt3.")
 	,"visnovsky@kde.org");
-    about.addAuthor("Marco Wegner",I18N_NOOP("Bug fixes and KFilePlugin for PO files.")
+    about.addAuthor("Marco Wegner",I18N_NOOP("Bug fixes, KFilePlugin for PO files, CVS support, mailing files")
          ,"dubbleu@web.de");
 
     about.addCredit("Claudiu Costin",I18N_NOOP("Wrote documentation and sent "
@@ -490,9 +546,9 @@ int main(int argc, char **argv)
     {
         return 0;
     }
-    
+
     KBabelApp app;
-    
+
     if( app.isRestored() )
     {
 	RESTORE(KBabelMW)
