@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 **************************************************************************** */
 
@@ -58,7 +58,7 @@ private slots:
     void searchStarted();
     void switchModule(int);
     void progressStopped();
-    void progressStarted(const QString);
+    void progressStarted(const QString&);
     void slotClearSearch();
 
 private:
