@@ -16,11 +16,12 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 **************************************************************************** */
 #include "compendiumdata.h"
 
+#include <resources.h>
 #include <catalog.h>
 #include <tagextractor.h>
 
@@ -28,6 +29,8 @@
 #include <kdebug.h>
 #include <klocale.h>
 
+using namespace KBabel;
+
 CompendiumData::CompendiumData(QObject *parent)
             : QObject(parent)
             , _active(false)
@@ -37,11 +40,13 @@ CompendiumData::CompendiumData(QObject *parent)
             , _exactDict(9887)
             , _allDict(9887)
             , _wordDict(9887)
+            , _textonlyDict(9887)
 {
     _catalog = new Catalog(this, "CompendiumData::catalog", QString::null);
     _exactDict.setAutoDelete(true);
     _allDict.setAutoDelete(true);
     _wordDict.setAutoDelete(true);
+    _textonlyDict.setAutoDelete(true);
 }
 
 
@@ -57,21 +62,21 @@ bool CompendiumData::load(KURL url)
     _exactDict.clear();
     _allDict.clear();
     _wordDict.clear();
+    _textonlyDict.clear();
     
 
     emit progressStarts(i18n("Loading PO compendium"));
-    bool e;
     connect(_catalog, SIGNAL(signalProgress(int)), this, SIGNAL(progress(int)));
 
-    Catalog::IOStatus stat=_catalog->openURL(url,e);
+    ConversionStatus stat=_catalog->openURL(url);
         
     disconnect(_catalog, SIGNAL(signalProgress(int))
             , this, SIGNAL(progress(int)));
         
 
-    if( stat!= Catalog::OK && stat != Catalog::RECOVERED_PARSE_ERROR)
+    if( stat!= OK && stat != RECOVERED_PARSE_ERROR)
     {
-        kdDebug() << "error while opening file " << url.prettyURL() << endl;
+        kdDebug(KBABEL_SEARCH) << "error while opening file " << url.prettyURL() << endl;
                 
         _error = true;
         _errorMsg = i18n("Error while trying to read file for PO Compendium module:\n%1")
@@ -96,7 +101,8 @@ bool CompendiumData::load(KURL url)
             kapp->processEvents(100);
         }
 
-        QString temp = _catalog->msgid(i,true);
+	// FIXME: shoudl care about plural forms
+        QString temp = _catalog->msgid(i,true).first();
         
         int *index = new int(i);
         _exactDict.insert(temp,index);
@@ -107,6 +113,7 @@ bool CompendiumData::load(KURL url)
 
         if(!temp.isEmpty() && temp.length() > 1)
         {
+	    // add to allDict
             QValueList<int> *indexList=_allDict[temp];
             
             if(!indexList)
@@ -117,6 +124,22 @@ bool CompendiumData::load(KURL url)
 
             indexList->append(i);
 
+	    // add to textonlyDict
+	    QString temp1 = temp;
+	    temp1.remove( ' ' );
+	    
+            indexList=_textonlyDict[temp1];
+            
+            if(!indexList)
+            {
+                indexList = new QValueList<int>;
+                _textonlyDict.insert(temp1,indexList);
+		kdDebug() << "Adding " << temp1 << endl;
+            }
+
+            indexList->append(i);
+
+	    // add to wordDict
             QStringList wList = wordList(temp);
             for ( QStringList::Iterator it = wList.begin()
                     ; it != wList.end(); ++it ) 
@@ -179,6 +202,11 @@ const QValueList<int>* CompendiumData::wordDict(const QString text) const
     return _wordDict[text];
 }
 
+const QValueList<int>* CompendiumData::textonlyDict(const QString text) const
+{
+    return _textonlyDict[text];
+}
+
 
 void CompendiumData::registerObject(QObject *obj)
 {
@@ -202,7 +230,8 @@ QString CompendiumData::simplify(const QString string)
 { 
     QString result;
 
-    TagExtractor te(string);
+    TagExtractor te;
+    te.setString(string);
     result=te.plainString();
 
     result=result.simplifyWhiteSpace();
