@@ -31,7 +31,6 @@
 #include <kdebug.h>
 #include <kdialog.h>
 #include <kinputdialog.h>
-#include <kkeydialog.h>
 #include <klineedit.h>
 #include <klistview.h>
 #include <klocale.h>
@@ -40,6 +39,8 @@
 #include <kstatusbar.h>
 #include <kstdaction.h>
 #include <kstdguiitem.h>
+#include <kedittoolbar.h>
+
 
 #include "bugcommand.h"
 #include "bugserver.h"
@@ -96,7 +97,7 @@ KBBMainWindow::KBBMainWindow( const QCString &initialPackage,
 {
     BugSystem::self()->setCurrentServer( KBBPrefs::instance()->mCurrentServer );
 
-    m_statusLabel = new QLabel( i18n( "Welcome to <b>KBugBuster</b>!" ), statusBar() );
+    m_statusLabel = new QLabel( i18n( "Welcome to <b>KBugBuster</b>." ), statusBar() );
     m_statusLabel->setMaximumHeight( statusBar()->fontMetrics().height() + 6 );
     m_statusLabel->setIndent( KDialog::marginHint() / 2 );
     statusBar()->addWidget( m_statusLabel, 1 );
@@ -119,8 +120,6 @@ KBBMainWindow::KBBMainWindow( const QCString &initialPackage,
     connect( m_mainWidget, SIGNAL( searchBugNumber() ),
              this, SLOT( searchBugNumber() ) );
 
-    setAutoSaveSettings();
-
     connect( BugSystem::self(), SIGNAL( infoMessage( const QString & ) ),
              SLOT( slotStatusMsg( const QString & ) ) );
 
@@ -149,7 +148,7 @@ void KBBMainWindow::initActions()
                         SLOT( close() ), actionCollection() );
     fileQuit->setStatusText( i18n( "Quit KBugBuster" ) );
 
-    new KAction( i18n("See &Pending Changes..."), "contents", 0, this, SLOT( slotListChanges() ),
+    new KAction( i18n("See &Pending Changes"), "contents", 0, this, SLOT( slotListChanges() ),
                  actionCollection(), "file_seechanges" );
     new KAction( i18n("&Submit Changes"), "mail_send", 0, this, SLOT( slotSubmit() ),
                  actionCollection(), "file_submit" );
@@ -160,6 +159,8 @@ void KBBMainWindow::initActions()
                  actionCollection(), "reload_package" );
     reloadbug = new KAction( i18n("Reload Bug &Details (for current bug)"), "reload", SHIFT+Qt::Key_F5, m_mainWidget, SLOT( slotReloadBug() ),
                  actionCollection(), "reload_bug" );
+    loadMyBugs = new KAction( i18n( "Load &My Bugs List" ), 0, m_mainWidget, SLOT( slotLoadMyBugs() ),
+                 actionCollection(), "load_my_bugs" );
     reloadall = new KAction( i18n("Load All Bug Details (for current product)"), Qt::Key_F6, m_mainWidget, SLOT( slotRetrieveAllBugDetails() ), actionCollection(), "load_allbugs" );
     new KAction( i18n("Extract &Attachments"), "filesave", Qt::Key_F4, m_mainWidget, SLOT( slotExtractAttachments() ),
                  actionCollection(), "extract_attachments" );
@@ -216,12 +217,18 @@ void KBBMainWindow::initActions()
 
     KStdAction::preferences( this, SLOT(preferences()), actionCollection() );
 
-    KToggleAction *toggleTmp =  new KToggleAction( i18n("Toggle Show Closed Bugs"), "recycled", 0, this, SLOT( slotToggleDone() ),
+    KToggleAction *toggleTmp =  new KToggleAction( i18n("Show Closed Bugs"), "recycled", 0, this, SLOT( slotToggleDone() ),
                  actionCollection(), "cmd_toggle_done" );
+#if KDE_IS_VERSION( 3, 2, 90 )
+    toggleTmp->setCheckedState(i18n("Hide Closed Bugs"));
+#endif
     toggleTmp->setChecked( KBBPrefs::instance()->mShowClosedBugs );
 
-    toggleTmp =new KToggleAction( i18n("Toggle Show Wishes"), "history", 0, this, SLOT( slotToggleWishes() ),
+    toggleTmp =new KToggleAction( i18n("Show Wishes"), "history", 0, this, SLOT( slotToggleWishes() ),
                  actionCollection(), "cmd_toggle_wishes" );
+#if KDE_IS_VERSION( 3, 2, 90 )
+    toggleTmp->setCheckedState(i18n("Hide Wishes"));
+#endif
     toggleTmp->setChecked(KBBPrefs::instance()->mShowWishes);
 
     mSelectServerAction = new KSelectAction( i18n( "Select Server" ), 0, 0,
@@ -231,7 +238,6 @@ void KBBMainWindow::initActions()
                                              "select_server" );
 
     setupSelectServerAction();
-    KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
 
     if ( KBBPrefs::instance()->mDebugMode ) {
       new KAction( i18n("Show Last Server Response..."), 0 , this,
@@ -242,7 +248,11 @@ void KBBMainWindow::initActions()
                    "debug_showbugsource" );
     }
 
+#if KDE_IS_VERSION( 3, 2, 90 )
+    setupGUI( (ToolBar | Keys | StatusBar | Save | Create ), "kbugbusterui.rc" );
+#else
     createGUI();
+#endif
 }
 
 void KBBMainWindow::slotToggleMenubar()
@@ -256,11 +266,6 @@ void KBBMainWindow::slotToggleMenubar()
         menuBar()->show();
 }
 
-void KBBMainWindow::slotConfigureKeys()
-{
-    KKeyDialog::configure( actionCollection(), this );
-}
-
 void KBBMainWindow::setupSelectServerAction()
 {
     QStringList servers;
@@ -309,22 +314,14 @@ void KBBMainWindow::slotDisconnectedAction()
 {
     BugSystem::self()->setDisconnected( m_disconnectedAction->isChecked() );
 
-    if( m_disconnectedAction->isChecked() )
-    {
-        reloadpacklist->setEnabled(false);
-        reloadpacklist->setEnabled(false);
-        reloadpack->setEnabled(false);
-        reloadbug->setEnabled(false);
-        reloadall->setEnabled(false);
-     }
-     else
-     {
-        reloadpacklist->setEnabled(true);
-        reloadpacklist->setEnabled(true);
-        reloadpack->setEnabled(true);
-        reloadbug->setEnabled(true);
-        reloadall->setEnabled(true);
-     }
+    bool enable = !m_disconnectedAction->isChecked();
+
+    reloadpacklist->setEnabled( enable );
+    reloadpacklist->setEnabled( enable );
+    reloadpack->setEnabled( enable );
+    reloadbug->setEnabled( enable );
+    reloadall->setEnabled( enable );
+    loadMyBugs->setEnabled( enable );
 }
 
 void KBBMainWindow::slotStatusMsg( const QString &text )
@@ -357,7 +354,7 @@ void KBBMainWindow::slotListChanges()
    }
    else
    {
-       KMessageBox::information( this, i18n("There are no pending commands") );
+       KMessageBox::information( this, i18n("There are no pending commands.") );
    }
 }
 
