@@ -8,6 +8,7 @@
 
 #include "bugsystem.h"
 #include "kbbprefs.h"
+#include "bugserver.h"
 
 #include "packagelvi.h"
 #include "packageselectdialog.h"
@@ -51,14 +52,7 @@ PackageSelectDialog::PackageSelectDialog(QWidget *parent,const char *name) :
     mRecentList->setMaximumHeight( mRecentList->fontMetrics().height() *
                                    KBBPrefs::instance()->mRecentPackagesCount );
     topLayout->addWidget( mRecentList, 0 );
-
-    QStringList::ConstIterator it;
-    for( it = KBBPrefs::instance()->mRecentPackages.begin();
-         it != KBBPrefs::instance()->mRecentPackages.end();
-         ++it) {
-        new QListViewItem( mRecentList, *it );
-    }
-
+    
     connect( mRecentList, SIGNAL( mouseButtonPressed( int, QListViewItem *, const QPoint &, int) ),
              SLOT( recentSelected( int, QListViewItem * ) ) );
     connect( mRecentList, SIGNAL( doubleClicked( QListViewItem * ) ),
@@ -86,8 +80,6 @@ PackageSelectDialog::PackageSelectDialog(QWidget *parent,const char *name) :
     connect( mPackageEdit, SIGNAL( textChanged( const QString & ) ),
              SLOT( completeTyped( const QString & ) ) );
     enableButtonOK( !mPackageEdit->text().isEmpty() );
-
-    setPackages( BugSystem::self()->packageList() );
 }
 
 PackageSelectDialog::~PackageSelectDialog()
@@ -95,8 +87,18 @@ PackageSelectDialog::~PackageSelectDialog()
     delete mCompletion;
 }
 
+void PackageSelectDialog::setRecentPackages( const QStringList &recent )
+{
+    mRecentList->clear();
+    QStringList::ConstIterator it;
+    for( it = recent.begin(); it != recent.end(); ++it ) {
+        new QListViewItem( mRecentList, *it );
+    }
+}
+
 void PackageSelectDialog::setPackages( const Package::List &pkgs )
 {
+    mCompleteList->clear();
     mCompletion->clear();
     mCompletionDict.clear();
     Package::List::ConstIterator it;
@@ -138,7 +140,7 @@ void PackageSelectDialog::completeSelected( int, QListViewItem *item )
 
     if ( lvi ) {
         mRecentList->clearSelection();
-        if ( lvi->component().isNull() ) {
+        if ( lvi->component().isEmpty() ) {
             mPackageEdit->setText( lvi->package().name() );
         }
         else {
@@ -155,18 +157,20 @@ void PackageSelectDialog::slotOk()
         mSelectedComponent = item->component();
 
         QString recent_key;
-        if (item->component().isNull())
+        if ( item->component().isEmpty() )
             recent_key = item->package().name();
         else
             recent_key = item->package().name() + "/" + item->component();
 
-        QStringList recent = KBBPrefs::instance()->mRecentPackages;
+        BugServer *server = BugSystem::self()->server();
+        QStringList recent = server->serverConfig().recentPackages();
         if( !recent.contains( recent_key ) ) {
             recent.prepend( recent_key );
             if ( int( recent.count() ) > KBBPrefs::instance()->mRecentPackagesCount ) {
                 recent.remove( recent.last() );
             }
-            KBBPrefs::instance()->mRecentPackages = recent;
+            kdDebug() << "RECENT: " << recent.join(",") << endl;
+            server->serverConfig().setRecentPackages( recent );
         }
     } else {
         QListViewItem *recentItem = mRecentList->selectedItem();
