@@ -38,6 +38,7 @@
 #include "functionitem.h"
 #include "costlistitem.h"
 #include "configuration.h"
+#include "toplevel.h"
 
 FunctionSelection::FunctionSelection( TopLevel* top,
 				      QWidget* parent, const char* name)
@@ -66,14 +67,18 @@ FunctionSelection::FunctionSelection( TopLevel* top,
   // groupList->setShowSortIndicator(true);
   groupList->setResizeMode(QListView::LastColumn);
 
-#if 1
-  // single click activation
+#if 0
+  // single click press activation
   connect(functionList, SIGNAL(selectionChanged(QListViewItem*)),
           this, SLOT(functionActivated(QListViewItem*)));
+  connect(functionList,
+	  SIGNAL(contextMenuRequested(QListViewItem*, const QPoint &, int)),
+          this, SLOT(functionContext(QListViewItem*, const QPoint &, int)));
 #else
+  // single click release activation
   connect(functionList, SIGNAL(selectionChanged(QListViewItem*)),
           this, SLOT(functionSelected(QListViewItem*)));
-  connect(functionList, SIGNAL(doubleClicked(QListViewItem*)),
+  connect(functionList, SIGNAL(clicked(QListViewItem*)),
 	  this, SLOT(functionActivated(QListViewItem*)));
   connect(functionList, SIGNAL(returnPressed(QListViewItem*)),
 	  this, SLOT(functionActivated(QListViewItem*)));
@@ -101,7 +106,7 @@ FunctionSelection::~FunctionSelection()
 }
 
 void FunctionSelection::functionContext(QListViewItem* i,
-					const QPoint & p, int)
+					const QPoint & p, int c)
 {
   QPopupMenu popup;
   TraceFunction* f = 0;
@@ -111,19 +116,21 @@ void FunctionSelection::functionContext(QListViewItem* i,
       popup.insertItem(i18n("Go to %1").arg(f->prettyName()), 93);
       popup.insertSeparator();
   }
-  popup.insertItem(i18n("Go Back"), 90);
-  popup.insertItem(i18n("Go Forward"), 91);
-  popup.insertItem(i18n("Go Up"), 92);
+
+  if ((c == 0) || (c == 1)) {
+    addCostMenu(&popup,false);
+    popup.insertSeparator();
+  }
+  addGroupMenu(&popup);  
+  popup.insertSeparator();
+  addGoMenu(&popup);
 
   int r = popup.exec(p);
-  if      (r == 90) activated(Back);
-  else if (r == 91) activated(Forward);
-  else if (r == 92) activated(Up);
-  else if (r == 93) activated(f);
+  if (r == 93) activated(f);
 }
 
 void FunctionSelection::groupContext(QListViewItem* /*i*/,
-				     const QPoint & p, int)
+				     const QPoint & p, int c)
 {
   QPopupMenu popup;
 
@@ -137,16 +144,45 @@ void FunctionSelection::groupContext(QListViewItem* /*i*/,
       }
   }
 #endif
-  popup.insertItem(i18n("Go Back"), 90);
-  popup.insertItem(i18n("Go Forward"), 91);
-  popup.insertItem(i18n("Go Up"), 92);
+  if (c == 0) {
+    addCostMenu(&popup,false);
+    popup.insertSeparator();
+  }
+  addGroupMenu(&popup);  
+  popup.insertSeparator();
+  addGoMenu(&popup);
 
-  int r = popup.exec(p);
-  if      (r == 90) activated(Back);
-  else if (r == 91) activated(Forward);
-  else if (r == 92) activated(Up);
+  popup.exec(p);
 }
 
+
+void FunctionSelection::addGroupMenu(QPopupMenu* popup)
+{
+  QPopupMenu *popup1 = new QPopupMenu(popup);
+  popup1->setCheckable(true);
+
+  if (_groupType != TraceItem::Function) {
+    popup1->insertItem(i18n("No Grouping"),0);
+    popup1->insertSeparator();
+  }
+  popup1->insertItem(TraceCost::i18nTypeName(TraceItem::Object),1);
+  popup1->insertItem(TraceCost::i18nTypeName(TraceItem::File),2);
+  popup1->insertItem(TraceCost::i18nTypeName(TraceItem::Class),3);
+  popup1->insertItem(TraceCost::i18nTypeName(TraceItem::FunctionCycle),4);
+  switch(_groupType) {
+  case TraceItem::Object:        popup1->setItemChecked(1, true); break;
+  case TraceItem::File:          popup1->setItemChecked(2, true); break;
+  case TraceItem::Class:         popup1->setItemChecked(3, true); break;
+  case TraceItem::FunctionCycle: popup1->setItemChecked(4, true); break;
+  default: break;
+  }
+  connect(popup1,SIGNAL(activated(int)),
+	  _topLevel,SLOT(groupTypeSelected(int)));
+
+  popup->insertItem(i18n("Grouping"), popup1);
+}    
+
+
 TraceItem* FunctionSelection::canShow(TraceItem* i)
 {
     TraceItem::CostType t = i ? i->type() : TraceItem::NoCostType;
@@ -180,6 +216,9 @@ void FunctionSelection::doUpdate(int changeType)
     // Special case ?
     if (changeType == selectedItemChanged) return;
 
+    // we don't show cost 2 at all...
+    if (changeType == costType2Changed) return;
+
     if (changeType == activeItemChanged) {
 	if (_activeItem ==0) {
 	    functionList->clearSelection();
@@ -289,9 +328,7 @@ void FunctionSelection::refresh()
 
     groupList->setColumnText(1, TraceItem::i18nTypeName(_groupType));
 
-    double total = _data ? ((double)_data->subCost(_costType)) : 0.0;
-
-    if (!_data || (total==0.0) || _data->parts().count()==0) {
+    if (!_data || _data->parts().count()==0) {
 	functionList->clear();
 	groupList->setUpdatesEnabled(true);
 	groupList->repaint();
@@ -368,11 +405,10 @@ void FunctionSelection::refresh()
 	  oldFunction = 0;
       }
 
-      functionList->setUpdatesEnabled(false);
+      // switching off QListView updates is buggy with some QT versions...
+      //functionList->setUpdatesEnabled(false);
       functionList->clear();
-      functionList->setColumnWidth(0, 50);
-      functionList->setColumnWidth(1, 50);
-      functionList->setColumnWidth(2, 50);
+      setCostColumnWidths();
 
       if (0) qDebug("Function %s at %d, Item %p",
 		    oldFunction ? oldFunction->name().ascii() : "-",
@@ -424,9 +460,8 @@ void FunctionSelection::refresh()
       else
 	functionList->clearSelection();
 
-      functionList->setUpdatesEnabled(true);
-      functionList->repaint();
-      //functionList->triggerUpdate();
+      //functionList->setUpdatesEnabled(true);
+      //functionList->repaint();
       groupList->setUpdatesEnabled(true);
       groupList->repaint();
       return;
@@ -493,31 +528,41 @@ void FunctionSelection::groupSelected(QListViewItem* i)
     return;
   }
 
-  functionList->setUpdatesEnabled(false);
+  // switching off QListView updates is buggy with some QT versions...
+  //functionList->setUpdatesEnabled(false);
 
   functionList->clear();
-  functionList->setColumnWidth(0, 50);
-  functionList->setColumnWidth(1, 50);
-  functionList->setColumnWidth(2, 50);
+  setCostColumnWidths();
 
   double total;
   if (Configuration::showExpanded())
       total = (double) g->subCost(_costType);
   else
       total = (double) _data->subCost(_costType);
+#if 0
   if (total == 0.0) {
       functionList->setUpdatesEnabled(true);
       functionList->repaint();
       return;
   }
+#endif
 
+  FunctionItem* fitem = 0;
   TraceFunction *f;
   _hc.clear(Configuration::maxListCount());
-  for (f=list.first();f;f=list.next())
+  for (f=list.first();f;f=list.next()) {
     _hc.addCost(f, f->cumulative()->subCost(_costType));
+    if (_activeItem == f)
+      fitem = new FunctionItem(functionList, (TraceFunction*)_activeItem,
+			       _costType, _groupType);
+  }
+
+  for(int i=0;i<_hc.realCount();i++) {
+    if (_activeItem == (TraceFunction*)_hc[i]) continue;
+    new FunctionItem(functionList, (TraceFunction*)_hc[i],
+		     _costType, _groupType);
+  }
 
-  for(int i=0;i<_hc.realCount();i++)
-    new FunctionItem(functionList, (TraceFunction*)_hc[i], _costType, _groupType);
   if (_hc.hasMore()) {
     // a placeholder for all the functions skipped ...
     new FunctionItem(functionList, _hc.count() - _hc.maxSize(),
@@ -525,8 +570,15 @@ void FunctionSelection::groupSelected(QListViewItem* i)
   }
   functionList->sort();
 
-  functionList->setUpdatesEnabled(true);
-  functionList->repaint();
+  if (fitem) {
+    functionList->ensureItemVisible(fitem);
+    _inSetFunction = true;
+    functionList->setSelected(fitem, true);
+    _inSetFunction = false;
+  }
+
+  //functionList->setUpdatesEnabled(true);
+  //functionList->repaint();
 
   // Don't emit signal if cost item was changed programatically
   if (!_inSetGroup) {
@@ -647,9 +699,7 @@ void FunctionSelection::query(QString query)
   FunctionItem *fi, *item = 0;
 
   functionList->clear();
-  functionList->setColumnWidth(0, 50);
-  functionList->setColumnWidth(1, 50);
-  functionList->setColumnWidth(2, 50);
+  setCostColumnWidths();
 
   for(int i=0;i<_hc.realCount();i++) {
       fi = new FunctionItem(functionList, (TraceFunction*)_hc[i],
@@ -682,8 +732,28 @@ bool FunctionSelection::setTopFunction()
   QListViewItem* i = functionList->firstChild();
   // this emits a function selection
   functionList->setSelected(i, true);
+  functionActivated(i);
   return i!=0;
 }
 
+void FunctionSelection::setCostColumnWidths()
+{
+  if (_costType && (_costType->subCost(_data->callMax())>0) ) {
+    functionList->setColumnWidthMode(0, QListView::Maximum);
+    functionList->setColumnWidth(0,50);
+    functionList->setColumnWidthMode(2, QListView::Maximum);
+    functionList->setColumnWidth(2,50);
+  }
+  else {
+    functionList->setColumnWidthMode(0, QListView::Manual);
+    functionList->setColumnWidth(0,0);
+    functionList->setColumnWidthMode(2, QListView::Manual);
+    functionList->setColumnWidth(2,0);
+  }
+
+  functionList->setColumnWidth(1, 50);
+}
+
+
 
 #include "functionselection.moc"
