@@ -25,53 +25,46 @@
 #include <qwhatsthis.h>
 #include <qpopupmenu.h>
 #include <klocale.h>
+#include <kconfig.h>
+#include <kdebug.h>
 
 #include "configuration.h"
 #include "instritem.h"
 #include "instrview.h"
 
+// InstrView defaults
+
+#define DEFAULT_SHOWHEXCODE true
+
 
 // Helpers for parsing output of 'objdump'
 
-static uint parseAddr(char* buf)
+static Addr parseAddr(char* buf)
 {
-    uint addr = 0;
+    Addr addr;
     uint pos = 0;
 
     // check for instruction line: <space>* <hex address> ":" <space>*
     while(buf[pos]==' ' || buf[pos]=='\t') pos++;
 
-    while(1) {
-	if (buf[pos]>='0' && buf[pos]<='9')
-	    addr = 16*addr + (buf[pos]-'0');
-	else if (buf[pos]>='a' && buf[pos]<='f')
-	    addr = 16*addr + 10 + (buf[pos]-'a');
-	else break;
-	pos++;
-    }
-    if (buf[pos] != ':') addr = 0;
+    int digits = addr.set(buf + pos);
+    if ((digits==0) || (buf[pos+digits] != ':')) return Addr(0);
 
     return addr;
 }
 
 
-static bool parseLine(char* buf, uint& addr,
+static bool parseLine(char* buf, Addr& addr,
                       uint& pos1, uint& pos2, uint& pos3)
 {
     // check for instruction line: <space>* <hex address> ":" <space>*
+
     pos1 = 0;
     while(buf[pos1]==' ' || buf[pos1]=='\t') pos1++;
 
-    addr = 0;
-    while(1) {
-	if (buf[pos1]>='0' && buf[pos1]<='9')
-	    addr = 16*addr + (buf[pos1]-'0');
-	else if (buf[pos1]>='a' && buf[pos1]<='f')
-	    addr = 16*addr + 10 + (buf[pos1]-'a');
-	else break;
-	pos1++;
-    }
-    if ((addr == 0) || (buf[pos1] != ':')) return false;
+    int digits = addr.set(buf + pos1);
+    pos1 += digits;
+    if ((digits==0) || (buf[pos1] != ':')) return false;
 
     // further parsing of objdump output...
     pos1++;
@@ -103,8 +96,8 @@ static bool parseLine(char* buf, uint& addr,
     if (strlen(buf+pos2) > 50)
 	strcpy(buf+pos2+47, "...");
 
-    if (0) qDebug("For 0x%x: Code '%s', Mnc '%s', Args '%s'",
-		  addr, buf+pos1, buf+pos2, buf+pos3);
+    if (0) qDebug("For 0x%s: Code '%s', Mnc '%s', Args '%s'",
+		  addr.toString().ascii(), buf+pos1, buf+pos2, buf+pos3);
 
     return true;
 }
@@ -121,6 +114,9 @@ InstrView::InstrView(TraceItemView* parentView,
                      QWidget* parent, const char* name)
   : QListView(parent, name), TraceItemView(parentView)
 {
+  _showHexCode = DEFAULT_SHOWHEXCODE;
+  _lastHexCodeWidth = 50;
+
   _inSelectionUpdate = false;
   _arrowLevels = 0;
   _lowList.setSortLow(true);
@@ -128,14 +124,16 @@ InstrView::InstrView(TraceItemView* parentView,
 
   addColumn( i18n( "#" ) );
   addColumn( i18n( "Cost" ) );
+  addColumn( i18n( "Cost 2" ) );
   addColumn( "" );
-  addColumn( i18n( "Machine Code" ) );
-  addColumn( i18n( "Cmd." ) );
+  addColumn( i18n( "Hex" ) );
+  addColumn( "" ); // Instruction
   addColumn( i18n( "Assembler" ) );
   addColumn( i18n( "Source Position" ) );
 
   setAllColumnsShowFocus(true);
   setColumnAlignment(1, Qt::AlignRight);
+  setColumnAlignment(2, Qt::AlignRight);
 
   connect(this,
           SIGNAL(contextMenuRequested(QListViewItem*, const QPoint &, int)),
@@ -177,7 +175,7 @@ QString InstrView::whatsThis() const
 		 "make the destination function of this call current.</p>");
 }
 
-void InstrView::context(QListViewItem* i, const QPoint & p, int)
+void InstrView::context(QListViewItem* i, const QPoint & p, int c)
 {
   QPopupMenu popup;
 
@@ -198,18 +196,29 @@ void InstrView::context(QListViewItem* i, const QPoint & p, int)
     popup.insertSeparator();
   }
 
-  popup.insertItem(i18n("Go Back"), 90);
-  popup.insertItem(i18n("Go Forward"), 91);
-  popup.insertItem(i18n("Go Up"), 92);
+  if ((c == 1) || (c == 2)) {
+    addCostMenu(&popup);
+    popup.insertSeparator();
+  }
+  addGoMenu(&popup);
+
+  popup.insertSeparator();
+  popup.setCheckable(true);
+  popup.insertItem(i18n("Hex Code"), 94);
+  if (_showHexCode) popup.setItemChecked(94,true);
 
   int r = popup.exec(p);
-  if      (r == 90) activated(Back);
-  else if (r == 91) activated(Forward);
-  else if (r == 92) activated(Up);
-  else if (r == 93) {
+  if (r == 93) {
     if (f) activated(f);
     if (instr) activated(instr);
   }
+  else if (r == 94) {
+    _showHexCode = !_showHexCode;
+    // remember width when hiding
+    if (!_showHexCode)
+      _lastHexCodeWidth = columnWidth(4);
+    setColumnWidths();
+  }
 }
 
 
@@ -346,25 +355,43 @@ void InstrView::doUpdate(int changeType)
     QListViewItem *item, *item2;
     for (item = firstChild();item;item = item->nextSibling())
       for (item2 = item->firstChild();item2;item2 = item2->nextSibling())
-        ((InstrItem*)item2)->setGroupType(_groupType);
+        ((InstrItem*)item2)->updateGroup();
     return;
   }
 
   refresh();
 }
 
+void InstrView::setColumnWidths()
+{
+  if (_showHexCode) {
+    setColumnWidthMode(4, QListView::Maximum);
+    setColumnWidth(4, _lastHexCodeWidth);
+  }
+  else {
+    setColumnWidthMode(4, QListView::Manual);
+    setColumnWidth(4, 0);
+  }
+}
+
 void InstrView::refresh()
 {
     _arrowLevels = 0;
+    _lastHexCodeWidth = 50;
 
     clear();
     setColumnWidth(0, 20);
     setColumnWidth(1, 50);
-    setColumnWidth(2, 0);  // arrows, defaults to invisible
-    setColumnWidth(3, 50); // machine code column
-    setColumnWidth(4, 20); // command column
-    setColumnWidth(5, 200); // arg column
+    setColumnWidth(2, _costType2 ? 50:0);
+    setColumnWidth(3, 0);   // arrows, defaults to invisible
+    setColumnWidth(4, 0);   // hex code column
+    setColumnWidth(5, 20);  // command column
+    setColumnWidth(6, 200); // arg column
     setSorting(0); // always reset to address number sort
+    if (_costType)
+      setColumnText(1, _costType->name());
+    if (_costType2)
+      setColumnText(2, _costType2->name());
 
     if (!_data || !_activeItem) return;
 
@@ -382,6 +409,9 @@ void InstrView::refresh()
 
     if (!f) return;
 
+    // Allow resizing of column 2
+    setColumnWidthMode(2, QListView::Maximum);
+
     // check for instruction map
     TraceInstrMap::Iterator itStart, it, tmpIt, itEnd;
     TraceInstrMap* instrMap = f->instrMap();
@@ -389,16 +419,20 @@ void InstrView::refresh()
 	it    = instrMap->begin();
 	itEnd = instrMap->end();
 	// get first instruction with cost of selected type
-	while((it != itEnd) && !(*it).hasCost(_costType)) ++it;
+	while(it != itEnd) {
+	  if ((*it).hasCost(_costType)) break;
+	  if (_costType2 && (*it).hasCost(_costType2)) break;
+	  ++it;
+	}
     }
     if (!instrMap || (it == itEnd)) {
-	new InstrItem(this, 1,
-		      i18n("There is no instruction info in the trace file."));
-	new InstrItem(this, 2,
+	new InstrItem(this, this, 1,
+		      i18n("There is no instruction info in the profile data file."));
+	new InstrItem(this, this, 2,
 		      i18n("For the Valgrind Calltree Skin, rerun with option"));
-	new InstrItem(this, 3, i18n("      --dump-instr=yes"));
-	new InstrItem(this, 4, i18n("To see (conditional) jumps, additionally specify"));
-	new InstrItem(this, 5, i18n("      --trace-jump=yes"));
+	new InstrItem(this, this, 3, i18n("      --dump-instr=yes"));
+	new InstrItem(this, this, 4, i18n("To see (conditional) jumps, additionally specify"));
+	new InstrItem(this, this, 5, i18n("      --trace-jump=yes"));
 	return;
     }
 
@@ -416,7 +450,11 @@ void InstrView::refresh()
 	    _highList.append(ij);
 	}
 	++it;
-	while((it != itEnd) && !(*it).hasCost(_costType)) ++it;
+	while(it != itEnd) {
+	  if ((*it).hasCost(_costType)) break;
+	  if (_costType2 && (*it).hasCost(_costType2)) break;
+	  ++it;
+	}
 	if (it == itEnd) break;
     }
     _lowList.sort();
@@ -434,27 +472,39 @@ void InstrView::refresh()
 	while(1) {
 	    tmpIt = it;
 	    ++it;
-	    while((it != itEnd) && !(*it).hasCost(_costType)) ++it;
+	    while(it != itEnd) {
+	      if ((*it).hasCost(_costType)) break;
+	      if (_costType2 && (*it).hasCost(_costType2)) break;
+	      ++it;
+	    }
 	    if (it == itEnd) break;
-	    if ((*it).addr() - (*tmpIt).addr() > 10000) break;
+	    if (!(*it).addr().isInRange( (*tmpIt).addr(),10000) ) break;
 	}
 
 	// tmpIt is always last instruction with cost
 	if (!fillInstrRange(f, itStart, ++tmpIt)) break;
 	if (it == itEnd) break;
     }
+
+    _lastHexCodeWidth = columnWidth(4);
+    setColumnWidths();
+
+    if (!_costType2) {
+      setColumnWidthMode(2, QListView::Manual);
+      setColumnWidth(2, 0);
+    }
 }
 
 
-void InstrView::updateJumpArray(uint addr, InstrItem* ii,
+void InstrView::updateJumpArray(Addr addr, InstrItem* ii,
 				bool ignoreFrom, bool ignoreTo)
 {
     TraceInstrJump* ij;
-    uint lowAddr, highAddr;
+    Addr lowAddr, highAddr;
     int iEnd = -1, iStart = -1;
 
-    if (0) qDebug("updateJumpArray(addr 0x%x, jump to %s)",
-		  addr,
+    if (0) qDebug("updateJumpArray(addr 0x%s, jump to %s)",
+		  addr.toString().ascii(),
 		  ii->instrJump()
 		  ? ii->instrJump()->instrTo()->name().ascii() : "?" );
 
@@ -507,8 +557,9 @@ void InstrView::updateJumpArray(uint addr, InstrItem* ii,
 	for(iEnd=0;iEnd<_arrowLevels;iEnd++)
 	    if (_jump[iEnd] == ij) break;
 	if (iEnd==_arrowLevels) {
-	    qDebug("InstrView: no jump start for end at %x ?", highAddr);
-	    iEnd = -1;
+	  kdDebug() << "InstrView: no jump start for end at 0x"
+		    << highAddr.toString() << " ?" << endl;
+	  iEnd = -1;
 	}
 
 	if (0 && (iEnd>=0))
@@ -541,8 +592,8 @@ bool InstrView::fillInstrRange(TraceFunction* function,
                                TraceInstrMap::Iterator it,
                                TraceInstrMap::Iterator itEnd)
 {
-    uint costAddr, nextCostAddr, objAddr, addr;
-    uint dumpStartAddr, dumpEndAddr;
+    Addr costAddr, nextCostAddr, objAddr, addr;
+    Addr dumpStartAddr, dumpEndAddr;
     TraceInstrMap::Iterator costIt;
 
     // shouldn't happen
@@ -552,30 +603,31 @@ bool InstrView::fillInstrRange(TraceFunction* function,
     TraceInstrMap::Iterator tmpIt = itEnd;
     --tmpIt;
     nextCostAddr = (*it).addr();
-    dumpStartAddr = (nextCostAddr<20) ? 0 : nextCostAddr -20;
+    dumpStartAddr = (nextCostAddr<20) ? Addr(0) : nextCostAddr -20;
     dumpEndAddr   = (*tmpIt).addr() +20;
 
     // generate command
     QString popencmd, objfile;
     objfile = function->object()->name();
     objfile = objfile.replace(QRegExp("[\"']"), ""); // security...
-    popencmd = QString("objdump -C -D "
+    popencmd = QString("objdump -C -d "
                        "--start-address=0x%1 --stop-address=0x%2 \"%3\"")
-	.arg(dumpStartAddr,0,16).arg(dumpEndAddr,0,16)
+	.arg(dumpStartAddr.toString()).arg(dumpEndAddr.toString())
 	.arg(objfile);
-    if (0) qDebug("Running '%s'...", popencmd.ascii());
+    if (1) qDebug("Running '%s'...", popencmd.ascii());
 
     // and run...
     FILE* iFILE = popen(QFile::encodeName( popencmd ), "r");
     if (iFILE == 0) {
-	new InstrItem(this, 1,
+	new InstrItem(this, this, 1,
 		      i18n("There is an error trying to execute the command"));
-	new InstrItem(this, 2, "");
-	new InstrItem(this, 3, popencmd);
-	new InstrItem(this, 4, "");
-	new InstrItem(this, 5,
-		      i18n("Check that you have installed the 'objdump'\n"
-                   "utility from the 'binutils' package and try again."));
+	new InstrItem(this, this, 2, "");
+	new InstrItem(this, this, 3, popencmd);
+	new InstrItem(this, this, 4, "");
+	new InstrItem(this, this, 5,
+		      i18n("Check that you have installed 'objdump'."));
+	new InstrItem(this, this, 6,
+		      i18n("This utility can be found in the 'binutils' package."));
 	return false;
     }
     QFile file;
@@ -604,14 +656,17 @@ bool InstrView::fillInstrRange(TraceFunction* function,
         // read next objdump line
         while (1) {
           readBytes=file.readLine(buf, BUF_SIZE);
-          if (readBytes<=0) break;
+          if (readBytes<=0) { 
+	    objAddr = 0; 
+	    break;
+	  }
 
           objdumpLineno++;
           if (readBytes == BUF_SIZE) {
 	    qDebug("ERROR: Line %d of '%s' too long\n",
                    objdumpLineno, popencmd.ascii());
           }
-          if (buf[readBytes-1] == '\n')
+          else if ((readBytes>0) && (buf[readBytes-1] == '\n'))
 	    buf[readBytes-1] = 0;
 
           objAddr = parseAddr(buf);
@@ -620,23 +675,27 @@ bool InstrView::fillInstrRange(TraceFunction* function,
           if (objAddr != 0) break;
         }
 
-        if (0) qDebug("Got ObjAddr: 0x%x", objAddr);
+        if (0) kdDebug() << "Got ObjAddr: 0x" << objAddr.toString() << endl;
       }
 
       // try to keep objAddr in [costAddr;nextCostAddr]
       if (needCostAddr &&
 	  (nextCostAddr > 0) &&
-	  ((objAddr ==0) || (objAddr >= nextCostAddr)) ) {
+	  ((objAddr == Addr(0)) || (objAddr >= nextCostAddr)) ) {
 	  needCostAddr = false;
 
 	  costIt = it;
 	  ++it;
-	  while((it != itEnd) && !(*it).hasCost(_costType)) ++it;
+	  while(it != itEnd) {
+	    if ((*it).hasCost(_costType)) break;
+	    if (_costType2 && (*it).hasCost(_costType2)) break;
+	    ++it;
+	  }
 	  costAddr = nextCostAddr;
-	  nextCostAddr = (it == itEnd) ? 0 : (*it).addr();
+	  nextCostAddr = (it == itEnd) ? Addr(0) : (*it).addr();
 
-	  if (0) qDebug("Got nextCostAddr: 0x%x, costAddr 0x%x",
-			nextCostAddr, costAddr);
+	  if (0) kdDebug() << "Got nextCostAddr: 0x" << nextCostAddr.toString()
+			   << ", costAddr 0x" << costAddr.toString() << endl;
       }
 
       // if we have no more address from objdump, stop
@@ -663,9 +722,10 @@ bool InstrView::fillInstrRange(TraceFunction* function,
 
 	  needObjAddr = true;
 
-	  if (0) qDebug("Dump Obj Addr: 0x%x [%s %s], cost (0x%x, next 0x%x)",
-			addr, cmd.ascii(), args.ascii(),
-			costAddr, nextCostAddr);
+	  if (0) kdDebug() << "Dump Obj Addr: 0x" << addr.toString()
+			   << " [" << cmd << " " << args << "], cost (0x"
+			   << costAddr.toString() << ", next 0x"
+			   << nextCostAddr.toString() << ")" << endl;
       }
       else {
 	  addr = costAddr;
@@ -676,8 +736,8 @@ bool InstrView::fillInstrRange(TraceFunction* function,
 	  needCostAddr = true;
 
 	  noAssLines++;
-	  if (0) qDebug("Dump Cost Addr: 0x%x (no ass), objAddr 0x%x",
-			addr, objAddr);
+	  if (0) kdDebug() << "Dump Cost Addr: 0x" << addr.toString()
+			   << " (no ass), objAddr 0x" << objAddr.toString() << endl;
       }
 
       // update inside
@@ -685,9 +745,10 @@ bool InstrView::fillInstrRange(TraceFunction* function,
 	  if (currInstr) inside = true;
       }
       else {
-	  if (0) qDebug("Check if 0x%x is in ]0x%x,0x%x[",
-			addr, costAddr,
-			nextCostAddr - 3*Configuration::noCostInside() );
+	if (0) kdDebug() << "Check if 0x" << addr.toString() << " is in ]0x"
+			 << costAddr.toString() << ",0x"
+			 << (nextCostAddr - 3*Configuration::noCostInside()).toString()
+			 << "[" << endl;
 
 	  // Suppose a average instruction len of 3 bytes
 	  if ( (addr > costAddr) &&
@@ -696,8 +757,7 @@ bool InstrView::fillInstrRange(TraceFunction* function,
 	      inside = false;
       }
 
-      int context = inside ? Configuration::contextInside() :
-                    Configuration::contextOutside();
+      int context = Configuration::context();
 
       if ( ((costAddr==0)     || (addr > costAddr + 3*context)) &&
            ((nextCostAddr==0) || (addr < nextCostAddr - 3*context)) ) {
@@ -719,17 +779,16 @@ bool InstrView::fillInstrRange(TraceFunction* function,
 	  skipLineWritten = false;
 
 
-      ii = new InstrItem(this, addr, inside,
-                         code, cmd, args, currInstr, _costType);
+      ii = new InstrItem(this, this, addr, inside,
+                         code, cmd, args, currInstr);
       dumpedLines++;
-      if (0) qDebug("Dumped 0x%x %s%s", addr,
-		    inside ? "Inside " : "Outside",
-		    currInstr ? "Cost" : "");
+      if (0) kdDebug() << "Dumped 0x" << addr.toString() << " "
+		       << (inside ? "Inside " : "Outside")
+		       << (currInstr ? "Cost" : "") << endl;
 
       // no calls/jumps if we have no cost for this line
       if (!currInstr) continue;
 
-
       if (!selected &&
 	  (currInstr == _selectedItem) ||
 	  (currInstr->line() == _selectedItem)) selected = ii;
@@ -745,14 +804,15 @@ bool InstrView::fillInstrRange(TraceFunction* function,
       TraceInstrCallList list = currInstr->instrCalls();
       TraceInstrCall* ic;
       for (ic=list.first();ic;ic=list.next()) {
-	  if (ic->subCost(_costType)==0) continue;
+	  if ((ic->subCost(_costType)==0) &&
+	      (ic->subCost(_costType2)==0)) continue;
 
 	  if (ic->subCost(_costType) > most) {
 	      item = ii;
 	      most = ic->subCost(_costType);
 	  }
 
-	  ii2 = new InstrItem(ii, addr, currInstr, ic, _costType, _groupType);
+	  ii2 = new InstrItem(this, ii, addr, currInstr, ic);
 
 	  if (!selected && (ic->call()->called() == _selectedItem))
 	      selected = ii2;
@@ -763,7 +823,7 @@ bool InstrView::fillInstrRange(TraceFunction* function,
       for (ij=jlist.first();ij;ij=jlist.next()) {
 	  if (ij->executedCount()==0) continue;
 
-	  new InstrItem(ii, addr, currInstr, ij);
+	  new InstrItem(this, ii, addr, currInstr, ij);
       }
     }
 
@@ -779,7 +839,6 @@ bool InstrView::fillInstrRange(TraceFunction* function,
     file.close();
     pclose(iFILE);
 
-
     // for arrows: go down the list according to list sorting
     sort();
     QListViewItem *item1, *item2;
@@ -797,44 +856,44 @@ bool InstrView::fillInstrRange(TraceFunction* function,
     }
 
     if (arrowLevels())
-	setColumnWidth(2, 10 + 6*arrowLevels() + itemMargin() * 2);
+	setColumnWidth(3, 10 + 6*arrowLevels() + itemMargin() * 2);
     else
-	setColumnWidth(2, 0);
+	setColumnWidth(3, 0);
 
 
     if (noAssLines > 1) {
 	// trace cost not machting code
-	new InstrItem(this, 1,
+
+	new InstrItem(this, this, 1,
 		      i18n("There is %n cost line without assembler code.",
-                   "There are %n cost lines without assembler code.",
-                   noAssLines));
-	new InstrItem(this, 2,
+                           "There are %n cost lines without assembler code.", noAssLines));
+	new InstrItem(this, this, 2,
 		      i18n("This happens because the code of"));
-	new InstrItem(this, 3, QString("        %1").arg(objfile));
-	new InstrItem(this, 4,
-		      i18n("doesn't seem to match the trace file."));
-	new InstrItem(this, 5, "");
-	new InstrItem(this, 6,
-		      i18n("Are you using an old trace file or is the above mentioned"));
-	new InstrItem(this, 7,
+	new InstrItem(this, this, 3, QString("        %1").arg(objfile));
+	new InstrItem(this, this, 4,
+		      i18n("doesn't seem to match the profile data file."));
+	new InstrItem(this, this, 5, "");
+	new InstrItem(this, this, 6,
+		      i18n("Are you using an old profile data file or is the above mentioned"));
+	new InstrItem(this, this, 7,
 		      i18n("ELF object from an updated installation/another machine?"));
-	new InstrItem(this, 8, "");
+	new InstrItem(this, this, 8, "");
 	return false;
     }
 
     if (dumpedLines == 0) {
 	// no matching line read from popen
-	new InstrItem(this, 1,
+	new InstrItem(this, this, 1,
 		      i18n("There seems to be an error trying to execute the command"));
-	new InstrItem(this, 2, "");
-	new InstrItem(this, 3, popencmd);
-	new InstrItem(this, 4, "");
-	new InstrItem(this, 5,
-		      i18n("Check that the ELF object used in the command is existing"));
-	new InstrItem(this, 5,
-		      i18n("on this machine and that you have installed the 'objdump'"));
-	new InstrItem(this, 6,
-		      i18n("utility from the 'binutils' package and try again."));
+	new InstrItem(this, this, 2, "");
+	new InstrItem(this, this, 3, popencmd);
+	new InstrItem(this, this, 4, "");
+	new InstrItem(this, this, 5,
+		      i18n("Check that the ELF object used in the command exists."));
+	new InstrItem(this, this, 6,
+		      i18n("Check that you have installed 'objdump'."));
+	new InstrItem(this, this, 7,
+		      i18n("This utility can be found in the 'binutils' package."));
 	return false;
     }
 
@@ -851,14 +910,34 @@ void InstrView::updateInstrItems()
 	TraceInstr* instr = ii->instr();
 	if (!instr) continue;
 
-	ii->update();
+	ii->updateCost();
 
 	QListViewItem *next, *i  = ii->firstChild();
 	for (;i;i = next) {
 	    next = i->nextSibling();
-	    ((InstrItem*)i)->update();
+	    ((InstrItem*)i)->updateCost();
 	}
     }
 }
 
+void InstrView::readViewConfig(KConfig* c, 
+			       QString prefix, QString postfix, bool)
+{
+    KConfigGroup* g = configGroup(c, prefix, postfix);
+
+    if (0) qDebug("InstrView::readViewConfig");
+
+    _showHexCode  = g->readBoolEntry("ShowHexCode", DEFAULT_SHOWHEXCODE);
+
+    delete g;
+}
+
+void InstrView::saveViewConfig(KConfig* c,
+			       QString prefix, QString postfix, bool)
+{
+    KConfigGroup g(c, (prefix+postfix).ascii());
+
+    writeConfigEntry(&g, "ShowHexCode", _showHexCode, DEFAULT_SHOWHEXCODE);
+}
+
 #include "instrview.moc"
