@@ -2,10 +2,12 @@
                                 komparelistview.h  -  description
                                 -------------------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001-2003 by Otto Bruggeman
-                                  and John Firebaugh
+        copyright               : (C) 2001-2004 Otto Bruggeman
+                                  (C) 2001-2003 John Firebaugh
+                                  (C) 2004      Jeff Snyder
         email                   : otto.bruggeman@home.nl
                                   jfirebaugh@kde.org
+                                  jeff@caffeinated.me.uk
 ****************************************************************************/
 
 /***************************************************************************
@@ -24,12 +26,14 @@
 
 #include <kdebug.h>
 #include <kglobal.h>
+#include <kglobalsettings.h>
 
 #include "diffmodel.h"
 #include "diffhunk.h"
 #include "difference.h"
 #include "viewsettings.h"
 #include "komparemodellist.h"
+#include "komparesplitter.h"
 
 #include "komparelistview.h"
 
@@ -41,6 +45,62 @@
 
 using namespace Diff2;
 
+KompareListViewFrame::KompareListViewFrame( bool isSource,
+                                            ViewSettings* settings,
+                                            KompareSplitter* parent,
+                                            const char* name ):
+	QFrame ( parent, name ),
+	m_view ( isSource, settings, this, name ),
+	m_label ( isSource?"Source":"Dest", this ),
+	m_layout ( this )
+{
+	setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored) );
+	m_label.setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed) );
+	QFrame *frame1 = new QFrame(this), *frame2 = new QFrame(this);
+	frame1->setFrameShape(QFrame::HLine);
+	frame1->setFrameShadow ( QFrame::Plain );
+	frame1->setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed) );
+	frame1->setFixedHeight(1);
+	frame2->setFrameShape(QFrame::HLine);
+	frame2->setFrameShadow ( QFrame::Plain );
+	frame2->setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed) );
+	frame2->setFixedHeight(1);
+	m_label.setMargin(3);
+	m_layout.setSpacing(0);
+	m_layout.setMargin(0);
+	m_layout.addWidget(frame1);
+	m_layout.addWidget(&m_label);
+	m_layout.addWidget(frame2);
+	m_layout.addWidget(&m_view);
+
+	connect( &m_view, SIGNAL(differenceClicked(const Diff2::Difference*)),
+	         parent, SLOT(slotDifferenceClicked(const Diff2::Difference*)) );
+
+	connect( parent, SIGNAL(scrollViewsToId(int)), &m_view, SLOT(scrollToId(int)) );
+	connect( parent, SIGNAL(setXOffset(int)), &m_view, SLOT(setXOffset(int)) );
+	connect( &m_view, SIGNAL(resized()), parent, SLOT(slotUpdateScrollBars()) );
+}
+
+void KompareListViewFrame::slotSetModel( const DiffModel* model )
+{
+	if( model )
+	{
+		if( view()->isSource() ) {
+			if( !model->sourceRevision().isEmpty() )
+				m_label.setText( model->sourceFile() + " (" + model->sourceRevision() + ")" );
+			else
+				m_label.setText( model->sourceFile() );
+		} else {
+			if( !model->destinationRevision().isEmpty() )
+				m_label.setText( model->destinationFile() + " (" + model->destinationRevision() + ")" );
+			else
+				m_label.setText( model->destinationFile() );
+		}
+	} else {
+		m_label.setText( QString::null );
+	}
+}
+
 KompareListView::KompareListView( bool isSource,
                                   ViewSettings* settings,
                                   QWidget* parent, const char* name ) :
@@ -64,6 +124,12 @@ KompareListView::KompareListView( bool isSource,
 	setColumnWidthMode( COL_LINE_NO, Maximum );
 	setColumnWidthMode( COL_MAIN, Maximum );
 	setResizeMode( LastColumn );
+	setFrameStyle( QFrame::NoFrame );
+	setVScrollBarMode( QScrollView::AlwaysOff );
+	setHScrollBarMode( QScrollView::AlwaysOff );
+	setFocusPolicy( QWidget::NoFocus );
+	setFont( m_settings->m_font );
+	setSpaces( m_settings->m_tabToNumberOfSpaces );
 }
 
 KompareListView::~KompareListView()
@@ -72,7 +138,7 @@ KompareListView::~KompareListView()
 
 KompareListViewItem* KompareListView::itemAtIndex( int i )
 {
-	return m_items.at( i );
+	return m_items[ i ];
 }
 
 int KompareListView::firstVisibleDifference()
@@ -92,7 +158,7 @@ int KompareListView::firstVisibleDifference()
 	}
 
 	if( item )
-		return m_items.findRef( ((KompareListViewLineItem*)item)->diffItemParent() );
+		return m_items.findIndex( ((KompareListViewLineItem*)item)->diffItemParent() );
 
 	return -1;
 }
@@ -111,11 +177,11 @@ int KompareListView::lastVisibleDifference()
 		KompareListViewLineItem* lineItem = dynamic_cast<KompareListViewLineItem*>(item);
 		if( lineItem && lineItem->diffItemParent()->difference()->type() != Difference::Unchanged )
 			break;
-		item = dynamic_cast<KompareListViewItem*>(item)->previousItem();
+		item = item->itemAbove();
 	}
 
 	if( item )
-		return m_items.findRef( ((KompareListViewLineItem*)item)->diffItemParent() );
+		return m_items.findIndex( ((KompareListViewLineItem*)item)->diffItemParent() );
 
 	return -1;
 }
@@ -138,6 +204,7 @@ int KompareListView::minScrollId()
 int KompareListView::maxScrollId()
 {
 	KompareListViewItem* item = (KompareListViewItem*)firstChild();
+	if(!item) return 0;
 	while( item && item->nextSibling() ) {
 		item = (KompareListViewItem*)item->nextSibling();
 	}
@@ -146,6 +213,11 @@ int KompareListView::maxScrollId()
 	return maxId;
 }
 
+int KompareListView::contentsWidth()
+{
+	return ( columnWidth(COL_LINE_NO) + columnWidth(COL_MAIN) );
+}
+
 void KompareListView::setXOffset( int x )
 {
 	kdDebug(8104) << "SetXOffset : Scroll to x position: " << x << endl;
@@ -194,8 +266,19 @@ int KompareListView::scrollId()
 
 void KompareListView::setSelectedDifference( const Difference* diff, bool scroll )
 {
-	kdDebug(8104) << "KompareListView::setSelectedDifference( diff = " << diff << ", scroll = " << scroll << ")" << endl;
+	kdDebug(8104) << "KompareListView::setSelectedDifference(" << diff << ", " << scroll << ")" << endl;
 
+	// When something other than a click causes this function to be called,
+	// it'll only get called once, and all is simple.
+	//
+	// When the user clicks on a diff, this function will get called once when
+	// komparesplitter::slotDifferenceClicked runs, and again when the
+	// setSelection signal from the modelcontroller arrives.
+	//
+	// the first call (which will always be from the splitter) will have
+	// scroll==false, and the the second call will bail out here.
+	// Which is why clicking on a difference does not cause the listviews to
+	// scroll.
 	if ( m_selectedDifference == diff )
 		return;
 
@@ -206,21 +289,12 @@ void KompareListView::setSelectedDifference( const Difference* diff, bool scroll
 		kdDebug(8104) << "KompareListView::slotSetSelection(): couldn't find our selection!" << endl;
 		return;
 	}
-	// Only scroll to item if it isn't selected. This is so that
-	// clicking an item doesn't scroll to it. KompareView sets the
-	// selection manually in that case.
+
+	// why does this not happen when the user clicks on a diff? see the comment above.
 	if( scroll )
-	{
-		m_idToScrollTo = item->scrollId();
-		kdDebug(8104) << "Triggering a singleshot timer... should scroll to ID : " << m_idToScrollTo << endl;
-		QTimer::singleShot( 0, this, SLOT( slotDelayedScrollToId() ) );
-	}
+		scrollToId(item->scrollId());
 	setSelected( item, true );
 }
-void KompareListView::slotDelayedScrollToId()
-{
-	scrollToId( m_idToScrollTo );
-}
 
 void KompareListView::slotSetSelection( const Difference* diff )
 {
@@ -231,7 +305,7 @@ void KompareListView::slotSetSelection( const Difference* diff )
 
 void KompareListView::slotSetSelection( const DiffModel* model, const Difference* diff )
 {
-	kdDebug(8104) << "KompareListView::slotSetSelection( const DiffModel* model = " << model << ", const Difference* diff = " << diff << " )" << endl;
+	kdDebug(8104) << "KompareListView::slotSetSelection( const DiffModel* model, const Difference* diff )" << endl;
 
 	if( m_selectedModel && m_selectedModel == model ) {
 		slotSetSelection( diff );
@@ -245,35 +319,42 @@ void KompareListView::slotSetSelection( const DiffModel* model, const Difference
 
 	m_itemDict.resize(model->differenceCount());
 
-	kdDebug(8104) << "Cleared " << (m_isSource ? "source" : "destination") << " view..." << endl;
-
-	QPtrListIterator<DiffHunk> hunkIt(model->hunks());
+	DiffHunkListConstIterator hunkIt = model->hunks()->begin();
+	DiffHunkListConstIterator hEnd   = model->hunks()->end();
 
 	KompareListViewItem* item = 0;
-	for( ; hunkIt.current(); ++hunkIt ) {
-		DiffHunk* hunk = hunkIt.current();
+	Difference* tmpdiff = 0;
+	DiffHunk* hunk = 0;
+	
+
+	for ( ; hunkIt != hEnd; ++hunkIt )
+	{
+		hunk = *hunkIt;
 
 		if( item )
-			item = new KompareListViewHunkItem( this, item, hunk );
+			item = new KompareListViewHunkItem( this, item, hunk, model->isBlended() );
 		else
-			item = new KompareListViewHunkItem( this, hunk );
+			item = new KompareListViewHunkItem( this, hunk, model->isBlended() );
 
-		QPtrListIterator<Difference> diffIt(hunk->differences());
+		DifferenceListConstIterator diffIt = hunk->differences().begin();
+		DifferenceListConstIterator dEnd   = hunk->differences().end();
 
-		for( ; diffIt.current(); ++diffIt ) {
-			Difference* diff = diffIt.current();
+		for ( ; diffIt != dEnd; ++diffIt )
+		{
+			tmpdiff = *diffIt;
 
-			item = new KompareListViewDiffItem( this, item, diff );
+			item = new KompareListViewDiffItem( this, item, tmpdiff );
 
-			if( diff->type() != Difference::Unchanged ) {
+			int type = tmpdiff->type();
+
+			if ( type != Difference::Unchanged )
+			{
 				m_items.append( (KompareListViewDiffItem*)item );
-				m_itemDict.insert( diff, (KompareListViewDiffItem*)item );
+				m_itemDict.insert( tmpdiff, (KompareListViewDiffItem*)item );
 			}
 		}
 	}
 
-	kdDebug(8104) << "All are newed now..." << endl;
-
 	slotSetSelection( diff );
 }
 
@@ -321,12 +402,13 @@ void KompareListView::slotApplyDifference( const Difference* diff, bool apply )
 	m_itemDict[ (void*)diff ]->applyDifference( apply );
 }
 
-void KompareListView::slotConfigChanged()
+void KompareListView::setSpaces( int spaces )
 {
-	m_spaces = "";
-	kdDebug( 8104 ) << "tabToNumberOfSpaces: " << settings()->m_tabToNumberOfSpaces << endl;
-	for ( int i = 0; i < settings()->m_tabToNumberOfSpaces; i++ )
+	m_spaces.truncate( 0 );
+	kdDebug( 8104 ) << "tabToNumberOfSpaces: " << spaces << endl;
+	for ( int i = 0; i < spaces; i++ )
 		m_spaces += " ";
+
 	triggerUpdate();
 }
 
@@ -335,33 +417,36 @@ void KompareListView::wheelEvent( QWheelEvent* e )
 	e->ignore(); // we want the parent to catch wheel events
 }
 
+void KompareListView::resizeEvent( QResizeEvent* e )
+{
+	KListView::resizeEvent(e);
+	emit resized();
+	kdDebug() << "resizeEvent " << endl;
+}
+
 KompareListViewItem::KompareListViewItem( KompareListView* parent )
 	: QListViewItem( parent ),
-	m_scrollId( 0 ),
-	m_previousItem( 0 )
+	m_scrollId( 0 )
 {
 //	kdDebug(8104) << "Created KompareListViewItem with scroll id " << m_scrollId << endl;
 }
 
 KompareListViewItem::KompareListViewItem( KompareListView* parent, KompareListViewItem* after )
 	: QListViewItem( parent, after ),
-	m_scrollId( after->scrollId() + after->maxHeight() ),
-	m_previousItem( after )
+	m_scrollId( after->scrollId() + after->maxHeight() )
 {
 //	kdDebug(8104) << "Created KompareListViewItem with scroll id " << m_scrollId << endl;
 }
 
 KompareListViewItem::KompareListViewItem( KompareListViewItem* parent )
 	: QListViewItem( parent ),
-	m_scrollId( 0 ),
-	m_previousItem( 0 )
+	m_scrollId( 0 )
 {
 }
 
-KompareListViewItem::KompareListViewItem( KompareListViewItem* parent, KompareListViewItem* after )
+KompareListViewItem::KompareListViewItem( KompareListViewItem* parent, KompareListViewItem* /*after*/ )
 	: QListViewItem( parent ),
-	m_scrollId( 0 ),
-	m_previousItem( after )
+	m_scrollId( 0 )
 {
 }
 
@@ -434,16 +519,11 @@ int KompareListViewDiffItem::maxHeight()
 void KompareListViewDiffItem::setSelected( bool b )
 {
 	kdDebug(8104) << "KompareListViewDiffItem::setSelected( " << b << " )" << endl;
-//	kdDebug(8104) << kdBacktrace() << endl;
 	KompareListViewItem::setSelected( b );
 	QListViewItem* item = m_sourceItem->isVisible() ?
 	                      m_sourceItem->firstChild() :
 	                      m_destItem->firstChild();
-#if INLINE_DIFFERENCES
 	while( item && item->isVisible() ) {
-#else
-	while( item ) {
-#endif
 		item->repaint();
 		item = item->nextSibling();
 	}
@@ -493,30 +573,18 @@ int KompareListViewLineContainerItem::lineNumber() const
 	                    diffItemParent()->difference()->destinationLineNumber();
 }
 
-#if INLINE_DIFFERENCES
 DifferenceString* KompareListViewLineContainerItem::lineAt( int i ) const
-#else
-QString KompareListViewLineContainerItem::lineAt( int i ) const
-#endif
 {
 	return m_isSource ? diffItemParent()->difference()->sourceLineAt( i ) :
 	                    diffItemParent()->difference()->destinationLineAt( i );
 }
 
-#if INLINE_DIFFERENCES
 KompareListViewLineItem::KompareListViewLineItem( KompareListViewLineContainerItem* parent, int line, DifferenceString* text )
-#else
-KompareListViewLineItem::KompareListViewLineItem( KompareListViewLineContainerItem* parent, int line, const QString& text )
-#endif
 	: KompareListViewItem( parent )
 {
 	setText( COL_LINE_NO, QString::number( line ) );
-#if INLINE_DIFFERENCES
 	setText( COL_MAIN, text->string() );
 	m_text = text;
-#else
-	setText( COL_MAIN, text );
-#endif
 }
 
 void KompareListViewLineItem::setup()
@@ -528,7 +596,6 @@ void KompareListViewLineItem::setup()
 void KompareListViewLineItem::paintCell( QPainter * p, const QColorGroup & cg, int column, int width, int align )
 {
 	QColor bg = cg.base();
-#if INLINE_DIFFERENCES
 	p->fillRect( 0, 0, width, height(), bg );
 	if ( diffItemParent()->difference()->type() == Difference::Unchanged )
 	{
@@ -552,48 +619,19 @@ void KompareListViewLineItem::paintCell( QPainter * p, const QColorGroup & cg, i
 
 	paintText( p, bg, column, width, align );
 
-	if( diffItemParent()->isSelected() ) {
-		if( this == parent()->firstChild() )
+	if ( diffItemParent()->isSelected() )
+	{
+		if ( this == parent()->firstChild() )
 			p->drawLine( 0, 0, width, 0 );
-		if( nextSibling() == 0 )
+		if ( nextSibling() == 0 )
 			p->drawLine( 0, height() - 1, width, height() - 1 );
 	}
-#else
-	if( diffItemParent()->difference()->type() != Difference::Unchanged ) {
-		bg = kompareListView()->settings()->colorForDifferenceType(
-		          diffItemParent()->difference()->type(),
-		          diffItemParent()->isSelected(),
-		          diffItemParent()->difference()->applied() );
-	} else if( column == COL_LINE_NO ) {
-		bg = cg.background();
-	}
-
-	p->fillRect( 0, 0, width, height(), bg );
-
-	p->setPen( cg.foreground() );
-
-	if( diffItemParent()->isSelected() ) {
-		if( this == parent()->firstChild() )
-			p->drawLine( 0, 0, width, 0 );
-		if( nextSibling() == 0 )
-			p->drawLine( 0, height() - 1, width, height() - 1 );
-	}
-
-	paintText( p, cg, column, width, align );
-#endif
 }
 
-#if INLINE_DIFFERENCES
 void KompareListViewLineItem::paintText( QPainter* p, const QColor& bg, int column, int width, int align )
-#else
-void KompareListViewLineItem::paintText( QPainter * p, const QColorGroup& /*cg*/, int column, int width, int align )
-#endif
 {
-	QString adjustedText;
-	switch( column )
+	if ( column == COL_MAIN )
 	{
-	case COL_MAIN:
-#if INLINE_DIFFERENCES
 		QString textChunk;
 		int offset = listView()->itemMargin();
 		unsigned int prevValue = 0;
@@ -609,18 +647,23 @@ void KompareListViewLineItem::paintText( QPainter * p, const QColorGroup& /*cg*/
 		}
 
 		p->fillRect( 0, 0, offset, height(), normalBrush );
-		if ( !m_text->commandsList().isEmpty() )
+
+		if ( !m_text->markerList().isEmpty() )
 		{
-			Command* c = m_text->commandsList()->first();
-			for ( ; c; c = m_text->commandsList()->next() )
+			MarkerListConstIterator markerIt = m_text->markerList().begin();
+			MarkerListConstIterator mEnd     = m_text->markerList().end();
+			Marker* m = *markerIt;
+
+			for ( ; markerIt != mEnd; ++markerIt )
 			{
-				textChunk = m_text->string().mid( prevValue, c->offset() - prevValue );
+				m  = *markerIt;
+				textChunk = m_text->string().mid( prevValue, m->offset() - prevValue );
 //				kdDebug(8104) << "TextChunk   = \"" << textChunk << "\"" << endl;
 //				kdDebug(8104) << "c->offset() = " << c->offset() << endl;
 //				kdDebug(8104) << "prevValue   = " << prevValue << endl;
-				textChunk.replace( QRegExp( "\\t" ), kompareListView()->spaces() );
-				prevValue = c->offset();
-				if ( c->type() == Command::End )
+				textChunk.replace( QChar('\t'), kompareListView()->spaces() );
+				prevValue = m->offset();
+				if ( m->type() == Marker::End )
 				{
 					QFont font( p->font() );
 					font.setBold( true );
@@ -648,7 +691,7 @@ void KompareListViewLineItem::paintText( QPainter * p, const QColorGroup& /*cg*/
 		{
 			// Still have to draw some string without changes
 			textChunk = m_text->string().mid( prevValue, kMax( ( unsigned int )1, m_text->string().length() - prevValue ) );
-			textChunk.replace( QRegExp( "\\t" ), kompareListView()->spaces() );
+			textChunk.replace( QChar('\t'), kompareListView()->spaces() );
 //			kdDebug(8104) << "TextChunk   = \"" << textChunk << "\"" << endl;
 			QFont font( p->font() );
 			font.setBold( false );
@@ -661,26 +704,10 @@ void KompareListViewLineItem::paintText( QPainter * p, const QColorGroup& /*cg*/
 			offset += chunkWidth;
 		}
 		p->fillRect( offset, 0, width - offset, height(), normalBrush );
-#else
-		adjustedText = text( column );
-		adjustedText.replace( QRegExp( "\\t" ), kompareListView()->spaces() );
-		p->drawText( listView()->itemMargin(), 0,
-		             width - listView()->itemMargin(), height(),
-		             align, adjustedText );
-#endif
-		break;
-	case COL_LINE_NO:
-#if INLINE_DIFFERENCES
+	}
+	else
+	{
 		p->fillRect( 0, 0, width, height(), bg );
-#endif
-		p->drawText( listView()->itemMargin(), 0,
-		             width - listView()->itemMargin(), height(),
-		             align, text( column ) );
-		break;
-	default:
-#if INLINE_DIFFERENCES
-		p->fillRect( 0, 0, width, height(), bg );
-#endif
 		p->drawText( listView()->itemMargin(), 0,
 		             width - listView()->itemMargin(), height(),
 		             align, text( column ) );
@@ -694,11 +721,7 @@ KompareListViewDiffItem* KompareListViewLineItem::diffItemParent() const
 }
 
 KompareListViewBlankLineItem::KompareListViewBlankLineItem( KompareListViewLineContainerItem* parent )
-#if INLINE_DIFFERENCES
 	: KompareListViewLineItem( parent, 0, new DifferenceString() )
-#else
-	: KompareListViewLineItem( parent, 0, QString::null )
-#endif
 {
 }
 
@@ -708,30 +731,26 @@ void KompareListViewBlankLineItem::setup()
 	setHeight( BLANK_LINE_HEIGHT );
 }
 
-#if INLINE_DIFFERENCES
 void KompareListViewBlankLineItem::paintText( QPainter* p, const QColor& bg, int column, int width, int )
-#else
-void KompareListViewBlankLineItem::paintText( QPainter*, const QColorGroup&, int, int, int )
-#endif
 {
-#if INLINE_DIFFERENCES
 	if ( column == COL_MAIN )
 	{
 		QBrush normalBrush( bg, SolidPattern );
 		p->fillRect( 0, 0, width, height(), normalBrush );
 	}
-#endif
 }
 
-KompareListViewHunkItem::KompareListViewHunkItem( KompareListView* parent, DiffHunk* hunk )
+KompareListViewHunkItem::KompareListViewHunkItem( KompareListView* parent, DiffHunk* hunk, bool zeroHeight )
 	: KompareListViewItem( parent ),
+	m_zeroHeight( zeroHeight ),
 	m_hunk( hunk )
 {
 	setSelectable( false );
 }
 
-KompareListViewHunkItem::KompareListViewHunkItem( KompareListView* parent, KompareListViewItem* after, DiffHunk* hunk )
+KompareListViewHunkItem::KompareListViewHunkItem( KompareListView* parent, KompareListViewItem* after, DiffHunk* hunk,  bool zeroHeight )
 	: KompareListViewItem( parent, after ),
+	m_zeroHeight( zeroHeight ),
 	m_hunk( hunk )
 {
 	setSelectable( false );
@@ -739,7 +758,9 @@ KompareListViewHunkItem::KompareListViewHunkItem( KompareListView* parent, Kompa
 
 int KompareListViewHunkItem::maxHeight()
 {
-	if( m_hunk->function().isEmpty() ) {
+	if( m_zeroHeight ) {
+		return 0;
+	} else if( m_hunk->function().isEmpty() ) {
 		return HUNK_LINE_HEIGHT;
 	} else {
 		return listView()->fontMetrics().lineSpacing();
