@@ -2,8 +2,8 @@
                                 main.cpp  -  description
                                 -------------------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001-2003 by Otto Bruggeman
-                                  and John Firebaugh
+        copyright               : (C) 2001-2004 Otto Bruggeman
+                                  (C) 2001-2003 John Firebaugh
         email                   : otto.bruggeman@home.nl
                                   jfirebaugh@kde.org
 ****************************************************************************/
@@ -25,20 +25,22 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 
+#include "kompare_part.h"
 #include "kompare_shell.h"
 #include "kompareurldialog.h"
 
 static const char description[] =
-	I18N_NOOP("A program to view the differences between files and optionally generate a diff." );
+	I18N_NOOP("A program to view the differences between files and optionally generate a diff" );
 
-static const char version[] = "3.2.1";
+static const char version[] = "3.3";
 
 static KCmdLineOptions options[] =
 {
-	{ "c", I18N_NOOP( "This will compare URL1 with URL2." ), 0 },
+	{ "c", I18N_NOOP( "This will compare URL1 with URL2" ), 0 },
 	{ "o", I18N_NOOP( "This will open URL1 and expect it to be diff output. URL1 can also be a '-' and then it will read from standard input. Can be used for instance for cvs diff | kompare -o -. Kompare will do a check to see if it can find the original file(s) and then blend the original file(s) into the diffoutput and show that in the viewer. -n disables the check." ), 0 },
 	{ "b", I18N_NOOP( "This will blend URL2 into URL1, URL2 is expected to be diff output and URL1 the file or folder that the diffoutput needs to be blended into. " ), 0 },
 	{ "n", I18N_NOOP( "Disables the check for automatically finding the original file(s) when using '-' as URL with the -o option." ), 0 },
+	{ "e", I18N_NOOP( "Use this to specify the encoding when calling it from the command line. It will default to the local encoding if not specified." ), 0 },
 	{ "+[URL1 [URL2]]",0 , 0 },
 	{ "+-", 0, 0 },
 //	{ "", I18N_NOOP( "" ), 0 },
@@ -49,9 +51,10 @@ int main(int argc, char *argv[])
 {
 	KAboutData aboutData( "kompare", I18N_NOOP("Kompare"), version, description,
 	                      KAboutData::License_GPL,
-	                      I18N_NOOP("(c) 2001-2003, John Firebaugh and Otto Bruggeman"), 0, "http://bruggie.dnsalias.org/kompare/" );
+	                      I18N_NOOP("(c) 2001-2004, John Firebaugh and Otto Bruggeman"), 0, "http://bruggie.dnsalias.org/kompare/" );
 	aboutData.addAuthor( "John Firebaugh", I18N_NOOP("Author"), "jfirebaugh@kde.org" );
 	aboutData.addAuthor( "Otto Bruggeman", I18N_NOOP("Author"), "otto.bruggeman@home.nl" );
+	aboutData.addCredit( "Chris Luetchford", I18N_NOOP("Kompare icon artist"), "chris@os11.com" );
 	aboutData.addCredit( "Malte Starostik", I18N_NOOP("A lot of good advice"), "malte@kde.org" );
 	aboutData.addCredit( "Bernd Gehrmann", I18N_NOOP("Cervisia diff viewer"), "bernd@physik.hu-berlin.de" );
 
@@ -137,6 +140,11 @@ int main(int argc, char *argv[])
 				difault = false;
 			}
 		}
+		else if ( args->isSet( "e" ) )
+		{
+			// Encoding given...
+			// FIXME: Need to implement this...
+		}
 		else if ( args->count() == 1 )
 		{
 			ks = new KompareShell();
@@ -189,6 +197,7 @@ int main(int argc, char *argv[])
 			{
 				ks = new KompareShell();
 				ks->show();
+				ks->viewPart()->setEncoding( dialog->encoding() );
 				ks->compare( dialog->getFirstURL(), dialog->getSecondURL() );
 			}
 			else
