@@ -6,14 +6,14 @@
 
 static KCmdLineOptions options[] =
 {
-    { "+[URL]", I18N_NOOP( "Document to open." ), 0 },
+    { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
     KCmdLineLastOption
 };
 
 int main(int argc, char **argv)
 {
     KAboutData about("kuiviewer", I18N_NOOP("KUIViewer"), "0.1",
-		     I18N_NOOP("Displays Designer's UI files."),
+		     I18N_NOOP("Displays Designer's UI files"),
 		     KAboutData::License_LGPL );
     about.addAuthor("Richard Moore", 0, "rich@kde.org");
     about.addAuthor("Ian Reinhart Geiser", 0, "geiseri@kde.org");
