@@ -81,6 +81,8 @@
 (define-key global-map [(meta down)] 'scroll-other-down)
 (define-key global-map [(control j)] 'goto-line)
 (global-set-key "%" 'match-paren);;for all buffers :)
+(global-set-key [(control %)] 'match-paren)
+
 (if (featurep 'igrep)
     (progn
       (setq igrep-find-prune-clause
@@ -128,6 +130,7 @@
 (define-key c-mode-map [(f6)] 'kde-switch-cpp-h)
 (define-key c++-mode-map [(f7)] 'switch-to-function-def)
 (define-key c++-mode-map [(f9)] 'agulbra-make-member)
+(define-key c-mode-map [(f9)] 'agulbra-make-member)
 (define-key global-map [(meta n)] 'next-error)
 
 ; kde-emacs-headers:
