@@ -11,6 +11,7 @@
 #define ATTRIBUTE_H
 
 #include "classifierlistitem.h"
+#include "umlnamespace.h"
 
 /**
  * This class is used to set up information for an attribute.  This is like
@@ -34,14 +35,15 @@ public:
 	 * @param s		The scope of the UMLAttribute.
 	 * @param iv		The initial value of the attribute.
 	 */
-	UMLAttribute(UMLObject *parent, QString name, int id, QString type = "int", Scope s = Private, QString iv = 0);
+	UMLAttribute(const UMLObject *parent, QString name, int id, QString type = "int",
+		     Scope s = Private, QString iv = 0);
 
 	/**
 	 * Sets up an attribute.
 	 *
 	 * @param parent	The parent of this UMLAttribute.
 	 */
-	UMLAttribute(UMLObject *parent);
+	UMLAttribute(const UMLObject *parent);
 
 	/**
 	 * Overloaded '==' operator
@@ -53,6 +55,17 @@ public:
 	 */
 	virtual ~UMLAttribute();
 
+	/**
+	 * Copy the internal presentation of this object into the UMLAttribute
+	 * object.
+	 */
+	virtual void copyInto(UMLAttribute *rhs) const;
+
+	/**
+	 * Make a clone of the UMLAttribute.
+	 */
+	virtual UMLObject* clone() const;
+
 	/**
 	 * Returns the type of the UMLAttribute.
 	 *
@@ -67,19 +80,19 @@ public:
 	 */
 	QString getInitialValue();
 
-       /**
-         * Sets the type of the UMLAttribute.
-         *
-         * @param type		The type of the UMLAttribute.
-         */
-        void setTypeName(QString type);
+	/**
+	 * Sets the type of the UMLAttribute.
+	 *
+	 * @param type		The type of the UMLAttribute.
+	 */
+	void setTypeName(QString type);
 
-        /**
-         * Sets the initial value of the UMLAttribute.
-         *
-         * @param iv		The inital value of the UMLAttribute.
-         */
-        void setInitialValue(QString iv);
+	/**
+	 * Sets the initial value of the UMLAttribute.
+	 *
+	 * @param iv		The inital value of the UMLAttribute.
+	 */
+	void setInitialValue(QString iv);
 
 	/**
 	 * Returns a string representation of the UMLAttribute.
@@ -93,22 +106,26 @@ public:
 	/**
 	 * Creates the <UML:Attribute> XMI element.
 	 */
-	bool saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
-
-	/**
-	 * Loads the <UML:Attribute> XMI element.
-	 */
-	bool loadFromXMI( QDomElement & element );
+	void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
 
 	/**
 	 * Display the properties configuration dialogue for the attribute.
 	 */
 	bool showPropertiesDialogue(QWidget* parent);
 
+	void setParmKind (Uml::Parameter_Kind pk);
+	Uml::Parameter_Kind getParmKind () const;
+
+protected:
+	/**
+	 * Loads the <UML:Attribute> XMI element.
+	 */
+	bool load( QDomElement & element );
+
 private:
 	QString m_TypeName;     ///< text for the attribute type.
 	QString m_InitialValue; ///< text for the attribute's initial value.
-
+	Uml::Parameter_Kind m_ParmKind;
 };
 
 #endif
