@@ -12,11 +12,11 @@
 
 #include "classifierlistitem.h"
 
-UMLClassifierListItem::UMLClassifierListItem(UMLObject *parent, QString Name, int id)
-  : UMLObject(parent, Name, id) { 
+UMLClassifierListItem::UMLClassifierListItem(const UMLObject *parent, QString Name, int id)
+  : UMLObject(parent, Name, id) {
 }
 
-UMLClassifierListItem::UMLClassifierListItem(UMLObject *parent)
+UMLClassifierListItem::UMLClassifierListItem(const UMLObject *parent)
   : UMLObject(parent) {
 }
 
@@ -27,4 +27,11 @@ QString UMLClassifierListItem::getShortName() {
 	return getName();
 }
 
+void UMLClassifierListItem::copyInto(UMLClassifierListItem *rhs) const
+{
+	// Call the parent.
+	UMLObject::copyInto(rhs);
+}
+
+
 #include "classifierlistitem.moc"
