@@ -26,6 +26,7 @@
 #include "../umlobjectlist.h"
 #include "../umlview.h"
 #include "../umlwidget.h"
+#include "../uml.h"
 
 UMLClipboard::UMLClipboard() {
 	m_type = clip1;
@@ -47,7 +48,7 @@ QMimeSource* UMLClipboard::copy(UMLDoc* Doc, bool fromView/*=false*/) {
 	UMLDrag *data = 0;
 	QPixmap* png = 0;
 
-	UMLListView * listView = Doc->listView;
+	UMLListView * listView = UMLApp::app()->getListView();
 	UMLListViewItemList selectedItems;
 	selectedItems.setAutoDelete(false);
 
@@ -232,12 +233,10 @@ void UMLClipboard::setCopyType(UMLListViewItemList& SelectedItems, UMLDoc* Doc)
 		m_type = clip5;
 	} else if(withDiagrams) {
 		m_type = clip2;
+	} else if(withObjects) {
+		m_type = clip1;
 	} else {
-		if(withObjects) {
-			m_type = clip1;
-		} else {
-			m_type = clip3;
-		}
+		m_type = clip3;
 	}
 }
 
@@ -303,6 +302,7 @@ bool UMLClipboard::pasteChildren(UMLListViewItem* Parent, UMLListViewItemListIt*
 	//of children to be added
 	UMLListViewItem* item = 0;
 	int children = itemdata -> childCount();
+	UMLListView *listView = UMLApp::app()->getListView();
 	for(int i = 0; i < children; i++) {
 		++(*It);
 		itemdata = It->current();
@@ -311,7 +311,7 @@ bool UMLClipboard::pasteChildren(UMLListViewItem* Parent, UMLListViewItemListIt*
 			return false; //Error this function gets called only if the parent Item
 			//has children and that means It->current() shouldn't be null
 		}
-		item = Doc->listView->createItem(*itemdata, ChangeLog, Parent);
+		item = listView->createItem(*itemdata, ChangeLog, Parent);
 		int count = itemdata -> childCount();
 		if( item && count ) {
 			kdDebug()<<count<<endl;
@@ -349,13 +349,18 @@ bool UMLClipboard::pasteClip1(UMLDoc* doc, QMimeSource* data) {
 	if(!result) {
 		return false;
 	}
+	UMLListView *lv = UMLApp::app()->getListView();
+	if ( !lv->startedCopy() )
+		return true;
+	lv->setStartedCopy(false);
+	// If we get here we are pasting after a Copy and need to
+	// assign new IDs to the copied items/objects.
 	UMLObject *obj = 0;
 	UMLObjectListIt object_it(objects);
 	while ( (obj=object_it.current()) != 0 ) {
 		++object_it;
-		if(!doc->addUMLObjectPaste(obj)) {
+		if(!doc->assignNewIDs(obj)) {
 			return false;
-
 		}
 		idchanges = doc->getChangeLog();
 		if(!idchanges) {
@@ -367,12 +372,11 @@ bool UMLClipboard::pasteClip1(UMLDoc* doc, QMimeSource* data) {
 	UMLListViewItem* itemdata = 0;
 	UMLListViewItemListIt it(itemdatalist);
 	while ( (itemdata=it.current()) != 0 ) {
-		if ( (item = doc->listView->findItem(idchanges->findNewID(itemdata->getID()))) ) {
+		UMLListViewItem *parent = (UMLListViewItem *)lv->currentItem();
+		if ( (item = lv->findItem(idchanges->findNewID(itemdata->getID()))) ) {
 			objectAlreadyExists = true;
-		} else {
-			item = doc->listView->createItem(*itemdata, *idchanges);
-		}
-
+		} else
+			item = lv->createItem(*itemdata, *idchanges, parent);
 
 		if(!item) {
 			return false;
@@ -381,7 +385,6 @@ bool UMLClipboard::pasteClip1(UMLDoc* doc, QMimeSource* data) {
 			if(!pasteChildren(item, &it, *idchanges, doc)) {
 				return false;
 			}
-
 		}
 		++it;
 	}
@@ -414,7 +417,7 @@ bool UMLClipboard::pasteClip2(UMLDoc* doc, QMimeSource* data) {
 	}
 	while ( (obj=object_it.current()) != 0 ) {
 		++object_it;
-		if(!doc->addUMLObjectPaste(obj)) {
+		if(!doc->assignNewIDs(obj)) {
 			kdDebug()<<"UMLClipboard: error adding umlobject"<<endl;
 			return false;
 		}
@@ -429,11 +432,12 @@ bool UMLClipboard::pasteClip2(UMLDoc* doc, QMimeSource* data) {
 		}
 	}
 
+	UMLListView *listView = UMLApp::app()->getListView();
 	UMLListViewItem* item = 0;
 	UMLListViewItem* itemdata = 0;
 	UMLListViewItemListIt it(itemdatalist);
 	while ( (itemdata=it.current()) != 0 ) {
-		item = doc->listView->createItem(*itemdata, *idchanges);
+		item = listView->createItem(*itemdata, *idchanges);
 		if(!item) {
 			return false;
 		}
@@ -461,13 +465,14 @@ bool UMLClipboard::pasteClip3(UMLDoc* doc, QMimeSource* data) {
 		return false;
 	}
 
-	bool result = UMLDrag::decodeClip3(data, itemdatalist, doc->listView);
+	UMLListView *listView = UMLApp::app()->getListView();
+	bool result = UMLDrag::decodeClip3(data, itemdatalist, listView);
 	if(!result) {
 		return false;
 	}
 	UMLListViewItemListIt it(itemdatalist);
 	while ( (itemdata=it.current()) != 0 ) {
-		item = doc->listView->createItem(*itemdata, *idchanges);
+		item = listView->createItem(*itemdata, *idchanges);
 		if(itemdata -> childCount()) {
 			if(!pasteChildren(item, &it, *idchanges, doc)) {
 				return false;
@@ -521,7 +526,7 @@ bool UMLClipboard::pasteClip4(UMLDoc* doc, QMimeSource* data) {
 	UMLObject* obj = 0;
 	while ( (obj=object_it.current()) != 0 ) {
 		++object_it;
-		if(!doc->addUMLObjectPaste(obj)) {
+		if(!doc->assignNewIDs(obj)) {
 			return false;
 		}
 	}
@@ -562,11 +567,12 @@ bool UMLClipboard::pasteClip4(UMLDoc* doc, QMimeSource* data) {
 	}
 	doc->getCurrentView()->endPartialWidgetPaste();
 
+	UMLListView *listView = UMLApp::app()->getListView();
 	UMLListViewItem* item = 0;
 	UMLListViewItem* itemdata = 0;
 	UMLListViewItemListIt it(itemdatalist);
 	while ( (itemdata=it.current()) != 0 ) {
-		item = doc->listView->createItem(*itemdata, *idchanges);
+		item = listView->createItem(*itemdata, *idchanges);
 		if(!item) {
 			return false;
 		}
@@ -587,7 +593,8 @@ bool UMLClipboard::pasteClip4(UMLDoc* doc, QMimeSource* data) {
 /** If clipboard has mime type application/x-uml-clip5,
 Pastes the data from the clipboard into the current Doc */
 bool UMLClipboard::pasteClip5(UMLDoc* doc, QMimeSource* data) {
-	UMLListViewItem* lvitem = dynamic_cast<UMLListViewItem *>( doc->listView->currentItem() );
+	UMLListView *listView = UMLApp::app()->getListView();
+	UMLListViewItem* lvitem = dynamic_cast<UMLListViewItem *>( listView->currentItem() );
 	if(!lvitem || (lvitem->getType() != Uml::lvt_Class)) {
 		return false;
 	}
@@ -665,7 +672,7 @@ bool UMLClipboard::checkPasteWidgets( UMLWidgetList & widgetList ) {
 				break;
 
 			case Uml::wt_Text:
-				if( dynamic_cast<FloatingText *>( p )->
+				if( static_cast<FloatingText *>( p )->
 				        getRole() != Uml::tr_Floating )
 					return false;
 				break;
