@@ -36,7 +36,7 @@
 #include "../umlnamespace.h"
 
 IDLWriter::IDLWriter(UMLDoc *parent, const char *name)
-		: SimpleCodeGenerator(parent, name) {
+		: SimpleCodeGenerator(parent, name, false) {
 	indentlevel = 0;
 	// FIXME: Eventually we should fabricate an Indenter class
 	// that can be used by all code generators.
@@ -47,7 +47,10 @@ IDLWriter::~IDLWriter() {}
 
 QString IDLWriter::spc() {
 	QString s;
-	s.fill(' ', indentlevel * 3);
+	if (m_indentation == " ")
+		s.fill(' ', indentlevel * m_indentationAmount);
+	else
+		s.fill('\t', indentlevel * m_indentationAmount);
 	return s;
 }
 
@@ -55,6 +58,7 @@ bool IDLWriter::isOOClass(UMLClassifier *c) {
 	QString stype = c->getStereotype();
 	if (stype == "CORBAConstant" || stype == "CORBAEnum" ||
 	        stype == "CORBAStruct" || stype == "CORBAUnion" ||
+	        stype == "CORBASequence" || stype == "CORBAArray" ||
 	        stype == "CORBATypedef")
 		return false;
 
@@ -76,10 +80,18 @@ QString IDLWriter::qualifiedName(UMLClassifier *c) {
 	return retval;
 }
 
+/**
+ * returns "IDL"
+ */
 QString IDLWriter::getLanguage() {
         return "IDL";
 }
 
+/**
+ * checks whether type is "IDLWriter"
+ *
+ * @param type
+ */
 bool IDLWriter::isType (QString & type)
 {
    if(type == "IDLWriter")
@@ -88,37 +100,48 @@ bool IDLWriter::isType (QString & type)
 }
 
 void IDLWriter::computeAssocTypeAndRole
-       (UMLAssociation *a, QString& typeName, QString& roleName) {
-	UMLClassifier* c = (UMLClassifier*) m_doc->findUMLObject(a->getRoleAId());
-	typeName = cleanName(c->getName());
-	QString multiplicity = a->getMultiA();
+       (UMLAssociation *a, UMLClassifier *c, QString& typeName, QString& roleName)
+{
+	// Determine which is the "remote" end of the association:
+	bool IAmRoleA = true;
+	UMLObject *other = a->getObject(B);
+	if (c->getName() == other->getName()) {
+		IAmRoleA = false;
+		other = a->getObject(A);
+	}
+	// Construct the type name:
+	typeName = cleanName(other->getName());
+	QString multiplicity;
+	if (IAmRoleA)
+		multiplicity = a->getMulti(B);
+	else
+		multiplicity = a->getMulti(A);
 	if (!multiplicity.isEmpty() && multiplicity != "1")
 		typeName.append("Vector");
-	roleName = a->getRoleNameA();
+	// Construct the member name:
+	if (IAmRoleA)
+		roleName = a->getRoleName(B);
+	else
+		roleName = a->getRoleName(A);
 	if (roleName.isEmpty()) {
-		if (multiplicity.isEmpty() || multiplicity == "1") {
-			roleName = "m_";
-			roleName.append(typeName);
-		} else {
-			roleName = typeName;
-			roleName.append("Vector");
+		roleName = a->getName();
+		if (roleName.isEmpty()) {
+			roleName = "m_" + typeName;
 		}
 	}
 }
 
 void IDLWriter::writeClass(UMLClassifier *c) {
 	if (!c) {
-		kdDebug() << "Cannot write class of NULL concept!\n";
+		kdDebug() << "Cannot write class of NULL concept!" << endl;
 		return;
 	}
 
 	UMLClass * myClass = dynamic_cast<UMLClass*>(c);
 	QString classname = cleanName(c->getName());
-	QString fileName = c->getName().lower();
-	fileName.replace(QRegExp("."), "-");
 
 	//find an appropriate name for our file
-	fileName = findFileName(c, ".idl");
+	QString fileName = findFileName(c, ".idl");
 	if (!fileName) {
 		emit codeGenerated(c, false);
 		return;
@@ -151,30 +174,33 @@ void IDLWriter::writeClass(UMLClassifier *c) {
 				continue;
 			QString baseName = findFileName(conc, ".idl");
 			if (!baseName.isEmpty())
-				idl << "#include \"" << baseName << ".idl\"\n";
+				idl << "#include \"" << baseName << ".idl\"" << m_newLineEndingChars;
 		}
-		idl << "\n";
+		idl << m_newLineEndingChars;
 	}
 
-	QString pkg = c->getPackage();
-	if (! pkg.isEmpty()) {
-		idl << spc() << "module " << pkg << " {\n\n";
+	// Generate the module declaration(s) for the package(s) in which
+	// we are embedded.
+	UMLPackageList pkgList = c->getPackages();
+	UMLPackage *pkg;
+	for (pkg = pkgList.first(); pkg != NULL; pkg = pkgList.next()) {
+		idl << spc() << "module " << pkg->getName() << " {" << m_newLineEndingChars << m_newLineEndingChars;
 		indentlevel++;
 	}
 
 	// Write class Documentation if non-empty or if force option set.
 	if (forceDoc() || !c->getDoc().isEmpty()) {
-		idl << "//\n";
+		idl << "//" << m_newLineEndingChars;
 		idl << "// class " << classname << endl;
 		idl << formatDoc(c->getDoc(), "// ");
-		idl << "\n";
+		idl << m_newLineEndingChars;
 	}
 
 	if (c->getBaseType() == Uml::ot_Enum) {
 		UMLEnum *ue = static_cast<UMLEnum*>(c);
 		UMLEnumLiteralList litList = ue->getFilteredEnumLiteralList();
 		uint i = 0;
-		idl << spc() << "enum " << classname << " {\n";
+		idl << spc() << "enum " << classname << " {" << m_newLineEndingChars;
 		indentlevel++;
 		for (UMLEnumLiteral *lit = litList.first(); lit; lit = litList.next()) {
 			QString enumLiteral = cleanName(lit->getName());
@@ -184,58 +210,87 @@ void IDLWriter::writeClass(UMLClassifier *c) {
 			idl << endl;
 		}
 		indentlevel--;
-		idl << spc() << "};\n\n";
-		if (! pkg.isEmpty()) {
+		idl << spc() << "};" << m_newLineEndingChars << m_newLineEndingChars;
+		// Close the modules inside which we might be nested.
+		for (pkg = pkgList.first(); pkg != NULL; pkg = pkgList.next()) {
 			indentlevel--;
-			idl << spc() << "};\n\n";
+			idl << spc() << "};" << m_newLineEndingChars << m_newLineEndingChars;
 		}
 		return;
 	}
 	if (! isOOClass(c)) {
 		QString stype = c->getStereotype();
 		if (stype == "CORBAConstant") {
-			idl << spc() << "// " << stype << " is Not Yet Implemented\n\n";
-		} else if(stype == "CORBAEnum") {
-			if(myClass) {
-				UMLAttributeList *atl = myClass->getFilteredAttributeList();
-				UMLAttribute *at;
-				idl << spc() << "enum " << classname << " {\n";
-				indentlevel++;
-				uint i = 0;
-				for (at = atl->first(); at; at = atl->next()) {
-					QString enumLiteral = cleanName(at->getName());
-					idl << spc() << enumLiteral;
-					if (++i < atl->count())
-						idl << ",";
-					idl << endl;
-				}
-				indentlevel--;
-				idl << spc() << "};\n\n";
-			}
-		} else if(stype == "CORBAStruct") {
-			if(myClass) {
-				UMLAttributeList *atl = myClass->getFilteredAttributeList();
-				UMLAttribute *at;
-				idl << spc() << "struct " << classname << " {\n";
-				indentlevel++;
-				for (at = atl->first(); at; at = atl->next()) {
-					QString name = cleanName(at->getName());
-					idl << spc() << at->getTypeName() << " " << name << ";\n";
-					// Initial value not possible in IDL.
-				}
-				indentlevel--;
-				idl << spc() << "};\n\n";
-			}
-		} else if(stype == "CORBAUnion") {
-			idl << spc() << "// " << stype << " is Not Yet Implemented\n\n";
-		} else if(stype == "CORBATypedef") {
-			idl << spc() << "// " << stype << " is Not Yet Implemented\n\n";
-		} else {
-			idl << spc() << "// " << stype << ": Unknown stereotype\n\n";
+			kdError() << "The stereotype " << stype << " cannot be applied to "
+				  << c->getName() << ", but only to attributes." << endl;
+			return;
 		}
-		if (! pkg.isEmpty()) {
+		if (myClass == NULL) {
+			kdError() << "The stereotype " << stype
+				  << " cannot be applied to " << c->getName()
+				  << ", but only to classes." << endl;
+			return;
+		}
+		if (stype == "CORBAEnum") {
+			UMLAttributeList *atl = myClass->getFilteredAttributeList();
+			UMLAttribute *at;
+			idl << spc() << "enum " << classname << " {" << m_newLineEndingChars;
+			indentlevel++;
+			uint i = 0;
+			for (at = atl->first(); at; at = atl->next()) {
+				QString enumLiteral = cleanName(at->getName());
+				idl << spc() << enumLiteral;
+				if (++i < atl->count())
+					idl << ",";
+				idl << endl;
+			}
 			indentlevel--;
-			idl << spc() << "};\n\n";
+			idl << spc() << "};" << m_newLineEndingChars << m_newLineEndingChars;
+		} else if (stype == "CORBAStruct") {
+			UMLAttributeList *atl = myClass->getFilteredAttributeList();
+			UMLAttribute *at;
+			idl << spc() << "struct " << classname << " {" << m_newLineEndingChars;
+			indentlevel++;
+			for (at = atl->first(); at; at = atl->next()) {
+				QString name = cleanName(at->getName());
+				idl << spc() << at->getTypeName() << " " << name << ";" << m_newLineEndingChars;
+				// Initial value not possible in IDL.
+			}
+			UMLAssociationList compositions = c->getCompositions();
+			if (!compositions.isEmpty()) {
+				idl << spc() << "// Compositions." << m_newLineEndingChars;
+				for (UMLAssociation *a = compositions.first(); a; a = compositions.next()) {
+					QString memberType, memberName;
+					computeAssocTypeAndRole(a, c, memberType, memberName);
+					idl << spc() << memberType << " " << memberName << ";" << m_newLineEndingChars;
+				}
+			}
+			UMLAssociationList aggregations = c->getAggregations();
+			if (!aggregations.isEmpty()) {
+				idl << spc() << "// Aggregations." << m_newLineEndingChars;
+				for (UMLAssociation *a = aggregations.first(); a; a = aggregations.next()) {
+					QString memberType, memberName;
+					computeAssocTypeAndRole(a, c, memberType, memberName);
+					idl << spc() << memberType << " " << memberName << ";" << m_newLineEndingChars;
+				}
+			}
+			indentlevel--;
+			idl << spc() << "};" << m_newLineEndingChars << m_newLineEndingChars;
+		} else if (stype == "CORBAUnion") {
+			idl << spc() << "// " << stype << " " << c->getName()
+			    << " is Not Yet Implemented" << m_newLineEndingChars << m_newLineEndingChars;
+		} else if (stype == "CORBATypedef") {
+			UMLClassifierList superclasses = c->getSuperClasses();
+			UMLClassifier* firstParent = superclasses.first();
+			idl << spc() << "typedef " << firstParent->getName() << " "
+			    << c->getName() << ";" << m_newLineEndingChars << m_newLineEndingChars;
+		} else {
+			idl << spc() << "// " << stype << ": Unknown stereotype" << m_newLineEndingChars << m_newLineEndingChars;
+		}
+		// Close the modules inside which we might be nested.
+		for (pkg = pkgList.first(); pkg != NULL; pkg = pkgList.next()) {
+			indentlevel--;
+			idl << spc() << "};" << m_newLineEndingChars << m_newLineEndingChars;
 		}
 		return;
 	}
@@ -256,7 +311,7 @@ void IDLWriter::writeClass(UMLClassifier *c) {
 	        	parent = superclasses.next();
 		}
 	}
-	idl << " {\n\n";
+	idl << " {" << m_newLineEndingChars << m_newLineEndingChars;
 	indentlevel++;
 
 	// Generate auxiliary declarations for multiplicity of associations
@@ -264,32 +319,32 @@ void IDLWriter::writeClass(UMLClassifier *c) {
 	bool didComment = false;
 	UMLAssociationList aggregations = c->getAggregations();
 	for (a = aggregations.first(); a; a = aggregations.next()) {
-		QString multiplicity = a->getMultiA();
+		QString multiplicity = a->getMulti(A);
 		if (multiplicity.isEmpty() || multiplicity == "1")
 			continue;
 		if (!didComment) {
-			idl << spc() << "// Types for association multiplicities\n\n";
+			idl << spc() << "// Types for association multiplicities" << m_newLineEndingChars << m_newLineEndingChars;
 			didComment = true;
 		}
-		UMLClassifier* other = (UMLClassifier*)m_doc->findUMLObject(a->getRoleAId());
+		UMLClassifier* other = (UMLClassifier*)m_doc->findUMLObject(a->getRoleId(A));
 		QString bareName = cleanName(other->getName());
 		idl << spc() << "typedef sequence<" << qualifiedName(other) << "> "
-		    << bareName << "Vector;\n\n";
+		    << bareName << "Vector;" << m_newLineEndingChars << m_newLineEndingChars;
 	}
 
 	UMLAssociationList compositions = c->getCompositions();
 	for (a = compositions.first(); a; a = compositions.next()) {
-		QString multiplicity = a->getMultiA();
+		QString multiplicity = a->getMulti(A);
 		if (multiplicity.isEmpty() || multiplicity == "1")
 			continue;
 		if (!didComment) {
-			idl << spc() << "// Types for association multiplicities\n\n";
+			idl << spc() << "// Types for association multiplicities" << m_newLineEndingChars << m_newLineEndingChars;
 			didComment = true;
 		}
-		UMLClassifier* other = (UMLClassifier*)m_doc->findUMLObject(a->getRoleAId());
+		UMLClassifier* other = (UMLClassifier*)m_doc->findUMLObject(a->getRoleId(A));
 		QString bareName = cleanName(other->getName());
 		idl << spc() << "typedef sequence<" << qualifiedName(other) << "> "
-		    << bareName << "Vector;\n\n";
+		    << bareName << "Vector;" << m_newLineEndingChars << m_newLineEndingChars;
 	}
 
 	// Generate public attributes.
@@ -302,56 +357,57 @@ void IDLWriter::writeClass(UMLClassifier *c) {
 				atpub.append(at);
 		}
 		if (forceSections() || atpub.count()) {
-			idl << spc() << "// Public attributes:\n\n";
+			idl << spc() << "// Public attributes:" << m_newLineEndingChars << m_newLineEndingChars;
 			for (at = atpub.first(); at; at = atpub.next()) {
 				QString attName = cleanName(at->getName());
 				idl << spc() << "attribute " << at->getTypeName()
-				    << " " << attName << ";\n\n";
+				    << " " << attName << ";" << m_newLineEndingChars << m_newLineEndingChars;
 			}
 		}
 	}
 
 	// Generate public operations.
-	UMLOperationList *opl = c->getFilteredOperationsList();
+	UMLOperationList opl(c->getFilteredOperationsList());
 	UMLOperationList oppub;
 	UMLOperation *op;
-	for (op = opl->first(); op; op = opl->next()) {
+	for (op = opl.first(); op; op = opl.next()) {
 		if (op->getScope() == Uml::Public)
 			oppub.append(op);
 	}
 	if (forceSections() || oppub.count()) {
-		idl << spc() << "// Public methods:\n\n";
+		idl << spc() << "// Public methods:" << m_newLineEndingChars << m_newLineEndingChars;
 		for (op = oppub.first(); op; op = oppub.next())
 			writeOperation(op, idl);
-		idl << "\n";
+		idl << m_newLineEndingChars;
 	}
 
 
 	if (forceSections() || !aggregations.isEmpty()) {
-		idl << spc() << "// Aggregations:\n";
+		idl << spc() << "// Aggregations:" << m_newLineEndingChars;
 		for (UMLAssociation *a = aggregations.first(); a; a = aggregations.next()) {
 			QString typeName, roleName;
-			computeAssocTypeAndRole(a, typeName, roleName);
-			idl << spc() << "// " << typeName << " " << roleName << ";\n";
+			computeAssocTypeAndRole(a, c, typeName, roleName);
+			idl << spc() << "// " << typeName << " " << roleName << ";" << m_newLineEndingChars;
 		}
 		idl << endl;
 	}
 	if (forceSections() || !compositions.isEmpty()) {
-		idl << spc() << "// Compositions:\n";
+		idl << spc() << "// Compositions:" << m_newLineEndingChars;
 		for (UMLAssociation *a = compositions.first(); a; a = compositions.next()) {
 			QString typeName, roleName;
-			computeAssocTypeAndRole(a, typeName, roleName);
-			idl << spc() << "// " << typeName << " " << roleName << ";\n";
+			computeAssocTypeAndRole(a, c, typeName, roleName);
+			idl << spc() << "// " << typeName << " " << roleName << ";" << m_newLineEndingChars;
 		}
 		idl << endl;
 	}
 
 	indentlevel--;
-	idl << spc() << "};\n\n";
+	idl << spc() << "};" << m_newLineEndingChars << m_newLineEndingChars;
 
-	if (!pkg.isEmpty()) {
+	// Close the modules inside which we might be nested.
+	for (pkg = pkgList.first(); pkg != NULL; pkg = pkgList.next()) {
 		indentlevel--;
-		idl << spc() << "};\n\n";
+		idl << spc() << "};" << m_newLineEndingChars << m_newLineEndingChars;
 	}
 	file.close();
 	emit codeGenerated(c, true);
@@ -367,21 +423,27 @@ void IDLWriter::writeOperation(UMLOperation *op, QTextStream &idl, bool is_comme
 		idl << "// ";
 	idl << rettype << " " << cleanName(op->getName()) << " (";
 	if (atl->count()) {
-		idl << "\n";
+		idl << m_newLineEndingChars;
 		indentlevel++;
 		uint i = 0;
 		for (UMLAttribute *at = atl->first(); at; at = atl->next()) {
 			idl << spc();
 			if (is_comment)
 				idl << "// ";
-			idl << "in " << at->getTypeName() << " "
-			    << cleanName(at->getName());
+			Uml::Parameter_Kind pk = at->getParmKind();
+			if (pk == Uml::pk_Out)
+				idl << "out ";
+			else if (pk == Uml::pk_InOut)
+				idl << "inout ";
+			else
+				idl << "in ";
+			idl << at->getTypeName() << " " << cleanName(at->getName());
 			if (++i < atl->count())
-				idl << ",\n";
+				idl << "," << m_newLineEndingChars;
 		}
 		indentlevel--;
 	}
-	idl << ");\n\n";
+	idl << ");" << m_newLineEndingChars << m_newLineEndingChars;
 }
 
 void IDLWriter::createDefaultDatatypes() {
@@ -397,3 +459,55 @@ void IDLWriter::createDefaultDatatypes() {
 	m_doc->createDatatype("string");
 }
 
+/**
+ * List of reserved keywords for this code generator.
+ *
+ * Just add new keywords, then mark all lines and
+ * pipe it through the external 'sort' program.
+ */
+static const char *ReservedWords[] = {
+  "any",
+  "attribute",
+  "boolean",
+  "case",
+  "char",
+  "const",
+  "context",
+  "default",
+  "double",
+  "enum",
+  "exception",
+  "FALSE",
+  "float",
+  "in",
+  "inout",
+  "interface",
+  "long",
+  "module",
+  "octet",
+  "oneway",
+  "out",
+  "raises",
+  "readonly",
+  "sequence",
+  "short",
+  "string",
+  "struct",
+  "switch",
+  "TRUE",
+  "typedef",
+  "union",
+  "unsigned",
+  "void",
+  NULL
+};
+
+/**
+ * get list of reserved keywords
+ */
+const char **
+IDLWriter::getReservedKeywords() {
+  return ReservedWords;
+}
+
+
