@@ -45,6 +45,7 @@
 #include "../classifiercodedocument.h"
 #include "../ownedhierarchicalcodeblock.h"
 
+#include "codeviewerdialog.h"
 #include "classpropdlg.h"
 #include "umlattributedialog.h"
 #include "umlroledialog.h"
@@ -80,7 +81,7 @@ void CodeEditor::clearText () {
 
 }
 
-CodeViewerDialog::CodeViewerState CodeEditor::getState()
+Settings::CodeViewerState CodeEditor::getState()
 {
 	return m_parentDlg->getState();
 }
@@ -648,22 +649,26 @@ QPopupMenu * CodeEditor::createPopupMenu ( const QPoint & pos )
 	TextBlock * tb = m_selectedTextBlock;
 	m_lastPara = paragraphAt(pos);
 
-//  	return QTextEdit::createPopupMenu ( pos );
 	QPopupMenu * menu = new QPopupMenu(this);
+	// ugh. A bug in the Qt interaction between QTextEdit and Menu
+	// can sometimes trigger a clear() call of the text area after
+	// the popup menu is destroyed. The workaround is to disable
+	// the behavior by blocking the destroy signal from the menu.
+	menu->blockSignals(true);
 
 	if (m_selectedTextBlock)
 	{
 		if(tb->getWriteOutText())
-			menu->insertItem("Hide",this,SLOT(slotChangeSelectedBlockView()), Key_H , 0);
+			menu->insertItem("Hide",this,SLOT(slotChangeSelectedBlockView()), Key_H, 0);
 		else
-			menu->insertItem("Show",this,SLOT(slotChangeSelectedBlockView()), Key_H , 0);
+			menu->insertItem("Show",this,SLOT(slotChangeSelectedBlockView()), Key_S, 0);
 
 		CodeBlockWithComments * cb = dynamic_cast<CodeBlockWithComments*>(tb);
 		if(cb)
 			if(cb->getComment()->getWriteOutText())
 				menu->insertItem("Hide Comment",this,SLOT(slotChangeSelectedBlockCommentView()), CTRL+Key_H, 1);
 			else
-				menu->insertItem("Show Comment",this,SLOT(slotChangeSelectedBlockCommentView()), CTRL+Key_H, 1);
+				menu->insertItem("Show Comment",this,SLOT(slotChangeSelectedBlockCommentView()), CTRL+Key_S, 1);
 		menu->insertSeparator();
 
 		menu->insertItem("Insert Code Block Before",this,SLOT(slotInsertCodeBlockBeforeSelected()), CTRL+Key_B, 2);
@@ -690,7 +695,9 @@ QPopupMenu * CodeEditor::createPopupMenu ( const QPoint & pos )
 		if(dynamic_cast<OwnedCodeBlock*>(m_selectedTextBlock) ||
 			dynamic_cast<HierarchicalCodeBlock*>(m_selectedTextBlock))
 			menu->setItemEnabled (4, false);
-
+		
+		// TBD
+		// m_selectedTextBlock->insertCodeEditMenuItems(menu, this);
 	}
 
 	return menu;
@@ -754,6 +761,10 @@ void CodeEditor::slotPasteTextBlock ( ) {
 
 }
 
+void CodeEditor::slotRedrawText() {
+	rebuildView(m_lastPara);
+}
+
 void CodeEditor::init ( CodeViewerDialog * parentDlg, CodeDocument * parentDoc ) {
 
 	// safety to insure that we are up to date
@@ -808,7 +819,8 @@ void CodeEditor::updateTextBlockFromText (TextBlock * block) {
         if (block) {
 
 		CodeMethodBlock * cmb = dynamic_cast<CodeMethodBlock*>(block);
-		QString baseIndent = block->getNewEditorLine(block->getIndentationLevel()+(cmb ? 1 : 0));
+		//QString baseIndent = block->getNewEditorLine(block->getIndentationLevel()+(cmb ? 1 : 0));
+		QString baseIndent = block->getIndentationString(block->getIndentationLevel()+(cmb ? 1 : 0));
 
                 TextBlockInfo *info = (*m_tbInfoMap)[block];
   		UMLObject * parentObj = info->getParent();
@@ -888,7 +900,7 @@ void CodeEditor::cursorPositionChanged(int para, int pos)
                 // auto-indent new lines
                 QString currentParaText = text(para);
 		QString baseIndent = tBlock->getNewEditorLine(tBlock->getIndentationLevel()+(cmb ? 1 : 0));
-//cerr<<"AUTO INDENT:["<<baseIndent.latin1()<<"] isMethod?"<<(cmb?"true":"false")<<endl;
+// cerr<<"AUTO INDENT:["<<baseIndent.latin1()<<"] isMethod?"<<(cmb?"true":"false")<<endl;
                 int minPos = baseIndent.length();
 
                 // add indent chars to the current line, if missing
@@ -954,7 +966,7 @@ void CodeEditor::cursorPositionChanged(int para, int pos)
 
         // look for changes in editability, if they occur, we need to record
         // the edits which have been made
-        if((editPara && !lastParaIsEditable) || (!editPara && lastParaIsEditable)) {
+        if((editPara && !m_lastTextBlockToBeEdited) || (!editPara && m_lastTextBlockToBeEdited)) {
 
                 setReadOnly(editPara ? false : true);
 
