@@ -49,7 +49,8 @@ public:
 	~DiagramPrintPage();
 
 	/**
-	 * Overriden method.
+	 * Overriden method. It builds a list with the diagram name and the diagram
+	 * IDs.
 	 */
 	void getOptions(QMap<QString,QString>& opts, bool /* incldef=false */);
 
@@ -72,11 +73,26 @@ private:
 
 	UMLDoc * m_pDoc;
 	Uml::Diagram_Type m_ViewType;
-	int m_nIdList[100];//allow 100 diagrams
+
+	/**
+	 * list containing the IDs of diagrams to print
+	 */
+	QValueList<int> m_nIdList;
 
 	enum FilterType{Current = 0, All, Select, Type};
 public slots:
+
+	/**
+	 * Gets called when the users chooses to print all diagrams, the current
+	 * diagram, a selection of diagrams or diagrams by type. It will change the
+	 * listed diagrams in the diagram box.
+	 */
 	void slotClicked(int id);
+
+	/**
+	 * Gets called when the user chooses another diagram type. Only diagrams of
+	 * this type will be shown in the diagram box.
+	 */
 	void slotActivated(const QString & text);
 };
 
