@@ -6,33 +6,36 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
+// own header
+#include "settingsdlg.h"
+
+// qt includes
+#include <qlayout.h>
+#include <qvbox.h>
+// kde includes
 #include <kdebug.h>
-//kde includes
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kfiledialog.h>
-#include <kdebug.h>
-//qt includes
-#include <qlayout.h>
-#include <qvbox.h>
-//app includes
-#include "settingsdlg.h"
+// app includes
 #include "codegenerationoptionspage.h"
 #include "codevieweroptionspage.h"
+#include "dialog_utils.h"
 
-SettingsDlg::SettingsDlg( QWidget * parent, OptionState state,
+SettingsDlg::SettingsDlg( QWidget * parent, Settings::OptionState *state,
 			  QDict<GeneratorInfo> ldict, QString activeLanguage, CodeGenerator * gen)
 	: KDialogBase( IconList, i18n("Umbrello Setup"),
         Help | Default | Apply | Ok | Cancel, Ok, parent, 0, true, true ) {
 	m_bChangesApplied = false;
-	m_OptionState = state;
+	m_pOptionState = state;
 	setHelp( "umbrello/index.html", QString::null );
 	setupGeneralPage();
 	setupFontPage();
 	setupUIPage();
 	setupClassPage();
 	setupCodeGenPage(gen, ldict, activeLanguage);
-	setupCodeViewerPage(state.codeViewerState);
+	setupCodeViewerPage(state->codeViewerState);
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 SettingsDlg::~SettingsDlg() {}
@@ -49,7 +52,7 @@ void SettingsDlg::setupUIPage() {
 	m_UiWidgets.lineColorL = new QLabel( i18n("Line color:"), m_UiWidgets.colorGB );
 	colorLayout -> addWidget( m_UiWidgets.lineColorL, 0, 0 );
 
-	m_UiWidgets.lineColorB = new KColorButton( m_OptionState.uiState.lineColor, m_UiWidgets.colorGB );
+	m_UiWidgets.lineColorB = new KColorButton( m_pOptionState->uiState.lineColor, m_UiWidgets.colorGB );
 	colorLayout -> addWidget( m_UiWidgets.lineColorB, 0, 1 );
 
 	m_UiWidgets.lineDefaultB = new QPushButton( i18n("D&efault Color"), m_UiWidgets.colorGB );
@@ -58,16 +61,30 @@ void SettingsDlg::setupUIPage() {
 	m_UiWidgets.fillColorL = new QLabel( i18n("Fill color:"), m_UiWidgets.colorGB );
 	colorLayout -> addWidget( m_UiWidgets.fillColorL, 1, 0 );
 
-	m_UiWidgets.fillColorB = new KColorButton( m_OptionState.uiState.fillColor, m_UiWidgets.colorGB );
+	m_UiWidgets.fillColorB = new KColorButton( m_pOptionState->uiState.fillColor, m_UiWidgets.colorGB );
 	colorLayout -> addWidget( m_UiWidgets.fillColorB, 1, 1 );
 
 	m_UiWidgets.fillDefaultB = new QPushButton( i18n("De&fault Color"), m_UiWidgets.colorGB );
 	colorLayout -> addWidget( m_UiWidgets.fillDefaultB, 1, 2 );
 
+
+	m_UiWidgets.lineWidthL = new QLabel( i18n("Line width:"), m_UiWidgets.colorGB );
+	colorLayout -> addWidget( m_UiWidgets.lineWidthL, 2, 0 );
+
+	// Low-Limit: 0, High-Limit: 10, Step: 1, Initial-Val: m_pOptionState->uiState.lineWidth
+	// Number-Base: 10 ( decimal ), Parent: m_UiWidgets.colorGB
+	m_UiWidgets.lineWidthB = new KIntSpinBox( 0, 10, 1, m_pOptionState->uiState.lineWidth, 10, m_UiWidgets.colorGB );
+	colorLayout -> addWidget( m_UiWidgets.lineWidthB, 2, 1 );
+
+	m_UiWidgets.lineWidthDefaultB = new QPushButton( i18n("D&efault Width"), m_UiWidgets.colorGB );
+	colorLayout -> addWidget( m_UiWidgets.lineWidthDefaultB, 2, 2 );
+
+
+
 	m_UiWidgets.useFillColorCB = new QCheckBox( i18n("&Use fill color"), m_UiWidgets.colorGB );
-	colorLayout -> setRowStretch( 2, 2 );
-	colorLayout -> addWidget( m_UiWidgets.useFillColorCB, 2, 0 );
-	m_UiWidgets.useFillColorCB -> setChecked( m_OptionState.uiState.useFillColor );
+	colorLayout -> setRowStretch( 3, 2 );
+	colorLayout -> addWidget( m_UiWidgets.useFillColorCB, 3, 0 );
+	m_UiWidgets.useFillColorCB -> setChecked( m_pOptionState->uiState.useFillColor );
 
 	//connect button signals up
 	connect( m_UiWidgets.lineDefaultB, SIGNAL(clicked()), this, SLOT(slotLineBClicked()) );
@@ -79,32 +96,41 @@ void SettingsDlg::setupGeneralPage() {
 
 	QVBox * page = addVBoxPage( i18n("General"), i18n("General Settings"), DesktopIcon( "misc")  );
 
+	// Set up undo setting
+	m_GeneralWidgets.miscGB = new QGroupBox( i18n("Miscellaneous"), page );
+
+	QGridLayout * miscLayout = new QGridLayout( m_GeneralWidgets.miscGB, 1, 1 );
+	miscLayout -> setSpacing( spacingHint() );
+	miscLayout -> setMargin( fontMetrics().height() );
+
+	m_GeneralWidgets.undoCB = new QCheckBox( i18n("Enable undo"), m_GeneralWidgets.miscGB );
+	m_GeneralWidgets.undoCB -> setChecked( m_pOptionState->generalState.undo );
+	miscLayout -> addWidget( m_GeneralWidgets.undoCB, 0, 0 );
+
 	//setup autosave settings
 
 	m_GeneralWidgets.autosaveGB = new QGroupBox( i18n("Autosave"), page );
 
-	QGridLayout * autosaveLayout = new QGridLayout( m_GeneralWidgets.autosaveGB, 2, 2 );
+	QGridLayout * autosaveLayout = new QGridLayout( m_GeneralWidgets.autosaveGB, 3, 2 );
 	autosaveLayout -> setSpacing( spacingHint() );
 	autosaveLayout -> setMargin( fontMetrics().height() );
 
 	m_GeneralWidgets.autosaveCB = new QCheckBox( i18n("E&nable autosave"), m_GeneralWidgets.autosaveGB );
-	m_GeneralWidgets.autosaveCB -> setChecked( m_OptionState.generalState.autosave );
+	m_GeneralWidgets.autosaveCB -> setChecked( m_pOptionState->generalState.autosave );
 	autosaveLayout -> addWidget( m_GeneralWidgets.autosaveCB, 0, 0 );
 
 	m_GeneralWidgets.autosaveL = new QLabel( i18n("Select auto-save time interval (mins):"), m_GeneralWidgets.autosaveGB );
-
-
 	autosaveLayout -> addWidget( m_GeneralWidgets.autosaveL, 1, 0 );
 
-	m_GeneralWidgets.timeKB = new KComboBox( m_GeneralWidgets.autosaveGB );
-	m_GeneralWidgets.timeKB -> setEnabled( m_OptionState.generalState.autosave );
-	autosaveLayout -> addWidget( m_GeneralWidgets.timeKB, 1, 1 );
+	m_GeneralWidgets.timeISB = new KIntSpinBox( 1, 600, 1, m_pOptionState->generalState.autosavetime, 10, m_GeneralWidgets.autosaveGB );
+	m_GeneralWidgets.timeISB -> setEnabled( m_pOptionState->generalState.autosave );
+	autosaveLayout -> addWidget( m_GeneralWidgets.timeISB, 1, 1 );
 
-	QString time[4] = { i18n("5"), i18n("10"), i18n("15"), i18n("30") };
-	for( int i=0; i < 4; i++ )
-		m_GeneralWidgets.timeKB -> insertItem( time[i] );
-	m_GeneralWidgets.timeKB -> setDuplicatesEnabled( false );
-	m_GeneralWidgets.timeKB -> setCurrentItem( m_OptionState.generalState.time );
+	// 2004-05-17 Achim Spangler: Allow definition of Suffix for autosave
+	// ( default: ".xmi" )
+	Dialog_Utils::makeLabeledEditField( m_GeneralWidgets.autosaveGB, autosaveLayout, 2,
+					    m_GeneralWidgets.autosaveSuffixL, i18n("Set autosave suffix:"),
+					    m_GeneralWidgets.autosaveSuffixT, m_pOptionState->generalState.autosavesuffix );
 
 	//setup startup settings
 	m_GeneralWidgets.startupGB = new QGroupBox( i18n("Startup"), page );
@@ -114,15 +140,15 @@ void SettingsDlg::setupGeneralPage() {
 	startupLayout -> setMargin( fontMetrics().height() );
 
 	m_GeneralWidgets.logoCB = new QCheckBox( i18n("Sta&rtup logo"), m_GeneralWidgets.startupGB );
-	m_GeneralWidgets.logoCB -> setChecked( m_OptionState.generalState.logo );
+	m_GeneralWidgets.logoCB -> setChecked( m_pOptionState->generalState.logo );
 	startupLayout -> addWidget( m_GeneralWidgets.logoCB, 0, 0 );
 
 	m_GeneralWidgets.tipCB = new QCheckBox( i18n("&Tip of the day"), m_GeneralWidgets.startupGB );
-	m_GeneralWidgets.tipCB -> setChecked( m_OptionState.generalState.tip );
+	m_GeneralWidgets.tipCB -> setChecked( m_pOptionState->generalState.tip );
 	startupLayout -> addWidget( m_GeneralWidgets.tipCB, 0, 1 );
 
 	m_GeneralWidgets.loadlastCB = new QCheckBox( i18n("&Load last project"), m_GeneralWidgets.startupGB );
-	m_GeneralWidgets.loadlastCB -> setChecked( m_OptionState.generalState.loadlast );
+	m_GeneralWidgets.loadlastCB -> setChecked( m_pOptionState->generalState.loadlast );
 	startupLayout -> addWidget( m_GeneralWidgets.loadlastCB, 1, 0 );
 
 	m_GeneralWidgets.startL = new QLabel( i18n("Start new project with:"), m_GeneralWidgets.startupGB );
@@ -139,7 +165,7 @@ void SettingsDlg::setupGeneralPage() {
 	for( int i=0; i<9; i++)
 		m_GeneralWidgets.diagramKB -> insertItem( diagrams[i] );
 
-	m_GeneralWidgets.diagramKB -> setCurrentItem( (int) m_OptionState.generalState.diagram );
+	m_GeneralWidgets.diagramKB -> setCurrentItem( (int) m_pOptionState->generalState.diagram );
 	connect( m_GeneralWidgets.autosaveCB, SIGNAL(clicked()), this, SLOT(slotAutosaveCBClicked()) );
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -154,32 +180,32 @@ void SettingsDlg::setupClassPage() {
 	visibilityLayout -> setMargin(  fontMetrics().height()  );
 
 	m_ClassWidgets.showScopeCB = new QCheckBox(i18n("Show &visibility"), m_ClassWidgets.visibilityGB);
-	m_ClassWidgets.showScopeCB -> setChecked(  m_OptionState.classState.showScope );
+	m_ClassWidgets.showScopeCB -> setChecked(  m_pOptionState->classState.showScope );
 	visibilityLayout -> addWidget( m_ClassWidgets.showScopeCB, 0, 0 );
 
 	m_ClassWidgets.showAttsCB = new QCheckBox( i18n("Show attributes"), m_ClassWidgets.visibilityGB );
-	m_ClassWidgets.showAttsCB -> setChecked(  m_OptionState.classState.showAtts );
+	m_ClassWidgets.showAttsCB -> setChecked(  m_pOptionState->classState.showAtts );
 	visibilityLayout -> addWidget( m_ClassWidgets.showAttsCB, 0, 1 );
 
 	m_ClassWidgets.showOpsCB = new QCheckBox( i18n("Show operations"), m_ClassWidgets.visibilityGB );
-	m_ClassWidgets.showOpsCB -> setChecked(  m_OptionState.classState.showOps );
+	m_ClassWidgets.showOpsCB -> setChecked(  m_pOptionState->classState.showOps );
 	visibilityLayout -> addWidget( m_ClassWidgets.showOpsCB, 1, 0 );
 
 	m_ClassWidgets.showStereotypeCB = new QCheckBox( i18n("Show stereot&ype"), m_ClassWidgets.visibilityGB );
-	m_ClassWidgets.showStereotypeCB -> setChecked(  m_OptionState.classState.showStereoType );
+	m_ClassWidgets.showStereotypeCB -> setChecked(  m_pOptionState->classState.showStereoType );
 	visibilityLayout -> addWidget( m_ClassWidgets.showStereotypeCB, 1, 1 );
 
 	m_ClassWidgets.showAttSigCB = new QCheckBox(i18n("Show attribute signature"), m_ClassWidgets.visibilityGB);
-	m_ClassWidgets.showAttSigCB -> setChecked(   m_OptionState.classState.showAttSig );
+	m_ClassWidgets.showAttSigCB -> setChecked(   m_pOptionState->classState.showAttSig );
 	visibilityLayout -> addWidget( m_ClassWidgets.showAttSigCB, 2, 0 );
 
 
 	m_ClassWidgets.showPackageCB = new QCheckBox(i18n("Show package"), m_ClassWidgets.visibilityGB);
-	m_ClassWidgets.showPackageCB -> setChecked(  m_OptionState.classState.showPackage );
+	m_ClassWidgets.showPackageCB -> setChecked(  m_pOptionState->classState.showPackage );
 	visibilityLayout -> addWidget( m_ClassWidgets.showPackageCB, 2, 1 );
 
 	m_ClassWidgets.showOpSigCB = new QCheckBox( i18n("Show operation signature"), m_ClassWidgets.visibilityGB );
-	m_ClassWidgets.showOpSigCB -> setChecked(  m_OptionState.classState.showOpSig );
+	m_ClassWidgets.showOpSigCB -> setChecked(  m_pOptionState->classState.showOpSig );
 	visibilityLayout -> addWidget( m_ClassWidgets.showOpSigCB, 3, 0 );
 	visibilityLayout -> setRowStretch( 3, 1 );
 
@@ -198,14 +224,14 @@ void SettingsDlg::setupClassPage() {
 	m_ClassWidgets.m_pAttribScopeCB->insertItem( tr2i18n( "Public" ) );
 	m_ClassWidgets.m_pAttribScopeCB->insertItem( tr2i18n( "Private" ) );
 	m_ClassWidgets.m_pAttribScopeCB->insertItem( tr2i18n( "Protected" ) );
-	m_ClassWidgets.m_pAttribScopeCB->setCurrentItem((m_OptionState.classState.defaultAttributeScope - 200));
+	m_ClassWidgets.m_pAttribScopeCB->setCurrentItem((m_pOptionState->classState.defaultAttributeScope - 200));
         scopeLayout -> addWidget( m_ClassWidgets.m_pAttribScopeCB, 0, 1 );
 
         m_ClassWidgets.m_pOperationScopeCB = new QComboBox(m_ClassWidgets.scopeGB);
 	m_ClassWidgets.m_pOperationScopeCB->insertItem( tr2i18n( "Public" ) );
 	m_ClassWidgets.m_pOperationScopeCB->insertItem( tr2i18n( "Private" ) );
 	m_ClassWidgets.m_pOperationScopeCB->insertItem( tr2i18n( "Protected" ) );
-	m_ClassWidgets.m_pOperationScopeCB->setCurrentItem((m_OptionState.classState.defaultOperationScope - 200));
+	m_ClassWidgets.m_pOperationScopeCB->setCurrentItem((m_pOptionState->classState.defaultOperationScope - 200));
         scopeLayout -> addWidget( m_ClassWidgets.m_pOperationScopeCB, 1, 1 );
 
 }
@@ -217,7 +243,7 @@ void SettingsDlg::setupCodeGenPage(CodeGenerator *gen, QDict<GeneratorInfo> ldic
 	connect( m_pCodeGenPage, SIGNAL(languageChanged()), this, SLOT(slotApply()) );
 }
 
-void SettingsDlg::setupCodeViewerPage(CodeViewerDialog::CodeViewerState options) {
+void SettingsDlg::setupCodeViewerPage(Settings::CodeViewerState options) {
 	//setup code generation settings page
 	QVBox * page = addVBoxPage( i18n("Code Viewer"), i18n("Code Viewer Settings"), DesktopIcon( "source") );
 	m_pCodeViewerPage = new CodeViewerOptionsPage(options, page);
@@ -226,21 +252,22 @@ void SettingsDlg::setupCodeViewerPage(CodeViewerDialog::CodeViewerState options)
 void SettingsDlg::setupFontPage() {
 	QVBox * page = addVBoxPage( i18n("Font"), i18n("Font Settings"), DesktopIcon( "fonts")  );
 	m_FontWidgets.chooser = new KFontChooser( page, "font", false, QStringList(), false);
+	m_FontWidgets.chooser->setFont( m_pOptionState->uiState.font );
 
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 void SettingsDlg::slotApply() {
-	applyPage( (Page) activePageIndex() );
+	applyPage( (Settings::Page) activePageIndex() );
 	emit applyClicked();
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 void SettingsDlg::slotOk() {
-	applyPage( page_general );
-	applyPage( page_font );
-	applyPage( page_UI );
-	applyPage( page_class );
-	applyPage( page_codegen );
-	applyPage( page_codeview );
+	applyPage( Settings::page_general );
+	applyPage( Settings::page_font );
+	applyPage( Settings::page_UI );
+	applyPage( Settings::page_class );
+	applyPage( Settings::page_codegen );
+	applyPage( Settings::page_codeview );
 	accept();
 }
 
@@ -252,27 +279,28 @@ void SettingsDlg::slotDefault() {
 	   If defaults are set anywhere else, like in setting up config file, make sure the same.
 	*/
 	switch( activePageIndex() ) {
-		case page_general:
+		case Settings::page_general:
 			m_GeneralWidgets.autosaveCB -> setChecked( false );
-			m_GeneralWidgets.timeKB -> setCurrentItem( 0 );
-                        m_GeneralWidgets.timeKB->setEnabled( false );
+			m_GeneralWidgets.timeISB -> setValue( 5 );
+			m_GeneralWidgets.timeISB->setEnabled( true );
 			m_GeneralWidgets.logoCB -> setChecked( true );
 			m_GeneralWidgets.tipCB -> setChecked( true );
 			m_GeneralWidgets.loadlastCB -> setChecked( true );
 			m_GeneralWidgets.diagramKB -> setCurrentItem( 0 );
 			break;
 
-		case page_font:
+		case Settings::page_font:
 			m_FontWidgets.chooser -> setFont( parentWidget() -> font() );
 			break;
 
-		case page_UI:
+		case Settings::page_UI:
 			m_UiWidgets.useFillColorCB -> setChecked( true );
 			m_UiWidgets.fillColorB -> setColor( QColor( 255, 255, 192 ) );
 			m_UiWidgets.lineColorB -> setColor( red );
+			m_UiWidgets.lineWidthB -> setValue( 0 );
 			break;
 
-		case page_class:
+		case Settings::page_class:
 			m_ClassWidgets.showScopeCB -> setChecked( false );
 			m_ClassWidgets.showAttsCB -> setChecked( true );
 			m_ClassWidgets.showOpsCB -> setChecked( true );
@@ -284,54 +312,58 @@ void SettingsDlg::slotDefault() {
 			m_ClassWidgets.m_pOperationScopeCB->setCurrentItem(0); // Public
 			break;
 
-		case page_codegen:
-		case page_codeview:
+		case Settings::page_codegen:
+		case Settings::page_codeview:
 			// do nothing
 			break;
 	};
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
-void SettingsDlg::applyPage( Page page ) {
+void SettingsDlg::applyPage( Settings::Page page ) {
 	m_bChangesApplied = true;
 	switch( page ) {
-		case page_general:
-			m_OptionState.generalState.autosave = m_GeneralWidgets.autosaveCB -> isChecked();
-			m_OptionState.generalState.time = m_GeneralWidgets.timeKB -> currentItem();
-			m_OptionState.generalState.logo = m_GeneralWidgets.logoCB -> isChecked();
-			m_OptionState.generalState.tip = m_GeneralWidgets.tipCB -> isChecked();
-			m_OptionState.generalState.loadlast = m_GeneralWidgets.loadlastCB -> isChecked();
-			m_OptionState.generalState.diagram  = ( Diagram ) m_GeneralWidgets.diagramKB -> currentItem();
+		case Settings::page_general:
+			m_pOptionState->generalState.undo = m_GeneralWidgets.undoCB -> isChecked();
+			m_pOptionState->generalState.autosave = m_GeneralWidgets.autosaveCB -> isChecked();
+			m_pOptionState->generalState.autosavetime = m_GeneralWidgets.timeISB -> value();
+			// 2004-05-17 Achim Spangler: retrieve Suffix setting from dialog entry
+			m_pOptionState->generalState.autosavesuffix = m_GeneralWidgets.autosaveSuffixT -> text();
+			m_pOptionState->generalState.logo = m_GeneralWidgets.logoCB -> isChecked();
+			m_pOptionState->generalState.tip = m_GeneralWidgets.tipCB -> isChecked();
+			m_pOptionState->generalState.loadlast = m_GeneralWidgets.loadlastCB -> isChecked();
+			m_pOptionState->generalState.diagram  = ( Settings::Diagram ) m_GeneralWidgets.diagramKB -> currentItem();
 			break;
 
-		case page_font:
-			m_OptionState.uiState.font = m_FontWidgets.chooser -> font();
+		case Settings::page_font:
+			m_pOptionState->uiState.font = m_FontWidgets.chooser -> font();
 			break;
 
-		case page_UI:
-			m_OptionState.uiState.useFillColor = m_UiWidgets.useFillColorCB -> isChecked();
-			m_OptionState.uiState.fillColor = m_UiWidgets.fillColorB -> color();
-			m_OptionState.uiState.lineColor = m_UiWidgets.lineColorB -> color();
+		case Settings::page_UI:
+			m_pOptionState->uiState.useFillColor = m_UiWidgets.useFillColorCB -> isChecked();
+			m_pOptionState->uiState.fillColor = m_UiWidgets.fillColorB -> color();
+			m_pOptionState->uiState.lineColor = m_UiWidgets.lineColorB -> color();
+			m_pOptionState->uiState.lineWidth = m_UiWidgets.lineWidthB -> value();
 			break;
 
-		case page_class:
-			m_OptionState.classState.showScope = m_ClassWidgets.showScopeCB -> isChecked();
-			m_OptionState.classState.showAtts = m_ClassWidgets.showAttsCB -> isChecked();
-			m_OptionState.classState.showOps = m_ClassWidgets.showOpsCB -> isChecked();
-			m_OptionState.classState.showStereoType = m_ClassWidgets.showStereotypeCB -> isChecked();
-			m_OptionState.classState.showAttSig = m_ClassWidgets.showAttSigCB -> isChecked();
-			m_OptionState.classState.showOpSig = m_ClassWidgets.showOpSigCB -> isChecked();
-			m_OptionState.classState.showPackage = m_ClassWidgets.showPackageCB -> isChecked();
-			m_OptionState.classState.defaultAttributeScope = (Uml::Scope) (m_ClassWidgets.m_pAttribScopeCB->currentItem() + 200);
-			m_OptionState.classState.defaultOperationScope = (Uml::Scope) (m_ClassWidgets.m_pOperationScopeCB->currentItem() + 200);
+		case Settings::page_class:
+			m_pOptionState->classState.showScope = m_ClassWidgets.showScopeCB -> isChecked();
+			m_pOptionState->classState.showAtts = m_ClassWidgets.showAttsCB -> isChecked();
+			m_pOptionState->classState.showOps = m_ClassWidgets.showOpsCB -> isChecked();
+			m_pOptionState->classState.showStereoType = m_ClassWidgets.showStereotypeCB -> isChecked();
+			m_pOptionState->classState.showAttSig = m_ClassWidgets.showAttSigCB -> isChecked();
+			m_pOptionState->classState.showOpSig = m_ClassWidgets.showOpSigCB -> isChecked();
+			m_pOptionState->classState.showPackage = m_ClassWidgets.showPackageCB -> isChecked();
+			m_pOptionState->classState.defaultAttributeScope = (Uml::Scope) (m_ClassWidgets.m_pAttribScopeCB->currentItem() + 200);
+			m_pOptionState->classState.defaultOperationScope = (Uml::Scope) (m_ClassWidgets.m_pOperationScopeCB->currentItem() + 200);
 			break;
 
-		case page_codegen:
+		case Settings::page_codegen:
 			m_pCodeGenPage->apply();
 			break;
 
-		case page_codeview:
+		case Settings::page_codeview:
 			m_pCodeViewerPage->apply();
-			m_OptionState.codeViewerState = m_pCodeViewerPage->getOptions();
+			m_pOptionState->codeViewerState = m_pCodeViewerPage->getOptions();
 			break;
 	}
 }
@@ -345,7 +377,7 @@ void SettingsDlg::slotFillBClicked() {
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 void SettingsDlg::slotAutosaveCBClicked() {
-	m_GeneralWidgets.timeKB -> setEnabled( m_GeneralWidgets.autosaveCB -> isChecked() );
+	m_GeneralWidgets.timeISB -> setEnabled( m_GeneralWidgets.autosaveCB -> isChecked() );
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 QString SettingsDlg::getCodeGenerationLanguage() {
