@@ -7,21 +7,35 @@
  *                                                                         *
  ***************************************************************************/
 
+// own header
 #include "umlattributedialog.h"
+
+// qt includes
+#include <qlayout.h>
+#include <qlineedit.h>
+#include <qcheckbox.h>
+#include <qgroupbox.h>
+#include <qbuttongroup.h>
+#include <qradiobutton.h>
+#include <qlabel.h>
+
+// kde includes
+#include <kcombobox.h>
+#include <kcompletion.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+#include <kdebug.h>
+
+// app includes
 #include "../attribute.h"
 #include "../interface.h"
 #include "../classifier.h"
 #include "../umldoc.h"
 #include "../uml.h"
-#include <kcombobox.h>
-#include <kcompletion.h>
-#include <klineedit.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kdebug.h>
-#include <qlayout.h>
+#include "dialog_utils.h"
 
-UMLAttributeDialog::UMLAttributeDialog( QWidget * pParent, UMLAttribute * pAttribute ) : KDialogBase( Plain, i18n("Attribute Properties"), Help | Ok | Cancel , Ok, pParent, "_UMLATTRIBUTEDLG_", true, true) {
+UMLAttributeDialog::UMLAttributeDialog( QWidget * pParent, UMLAttribute * pAttribute )
+  : KDialogBase( Plain, i18n("Attribute Properties"), Help | Ok | Cancel , Ok, pParent, "_UMLATTRIBUTEDLG_", true, true) {
 	m_pAttribute = pAttribute;
 	setupDialog();
 }
@@ -29,46 +43,41 @@ UMLAttributeDialog::UMLAttributeDialog( QWidget * pParent, UMLAttribute * pAttri
 UMLAttributeDialog::~UMLAttributeDialog() {}
 
 void UMLAttributeDialog::setupDialog() {
-	UMLClassifier * pConcept = dynamic_cast<UMLClassifier *>( m_pAttribute -> parent() );
-	UMLDoc * pDoc = dynamic_cast<UMLDoc *>( pConcept -> parent() );
+	UMLDoc * pDoc = UMLApp::app()->getDocument();
 	int margin = fontMetrics().height();
 
 	QVBoxLayout * mainLayout = new QVBoxLayout( plainPage() );
 
 	m_pValuesGB = new QGroupBox(i18n("General Properties"), plainPage() );
-	QGridLayout * valuesLayout = new QGridLayout(m_pValuesGB, 4, 2);
+	QGridLayout * valuesLayout = new QGridLayout(m_pValuesGB, 5, 2);
 	valuesLayout -> setMargin(margin);
 	valuesLayout -> setSpacing(10);
 
 	m_pTypeL = new QLabel(i18n("&Type:"), m_pValuesGB);
 	valuesLayout -> addWidget(m_pTypeL, 0, 0);
 
-	m_pNameL = new QLabel(i18n("&Name:"), m_pValuesGB);
-	valuesLayout -> addWidget(m_pNameL, 1, 0);
-
-	m_pInitialL = new QLabel(i18n("&Initial value:"), m_pValuesGB);
-	valuesLayout -> addWidget(m_pInitialL, 2, 0);
-
 	m_pTypeCB = new KComboBox(true, m_pValuesGB);
 	valuesLayout -> addWidget(m_pTypeCB, 0, 1);
+	m_pTypeL->setBuddy(m_pTypeCB);
 
-	m_pNameLE = new KLineEdit(m_pValuesGB);
-	valuesLayout -> addWidget(m_pNameLE, 1, 1);
-	m_pNameLE -> setText( m_pAttribute -> getName() );
+	Dialog_Utils::makeLabeledEditField( m_pValuesGB, valuesLayout, 1,
+					    m_pNameL, i18n("&Name:"),
+					    m_pNameLE, m_pAttribute->getName() );
 
-	m_pInitialLE = new KLineEdit(m_pValuesGB);
-	valuesLayout -> addWidget(m_pInitialLE, 2, 1);
+	Dialog_Utils::makeLabeledEditField( m_pValuesGB, valuesLayout, 2,
+					    m_pInitialL, i18n("&Initial value:"),
+					    m_pInitialLE, m_pAttribute->getInitialValue() );
+
+	Dialog_Utils::makeLabeledEditField( m_pValuesGB, valuesLayout, 3,
+					    m_pStereoTypeL, i18n("Stereotype name:"),
+					    m_pStereoTypeLE, m_pAttribute->getStereotype() );
 
 	m_pStaticCB = new QCheckBox( i18n("Classifier &scope (\"static\")"), m_pValuesGB );
 	m_pStaticCB -> setChecked( m_pAttribute -> getStatic() );
-	valuesLayout -> addWidget(m_pStaticCB, 3, 0);
+	valuesLayout -> addWidget(m_pStaticCB, 4, 0);
 
-	m_pTypeL->setBuddy(m_pTypeCB);
-	m_pNameL->setBuddy(m_pNameLE);
-	m_pInitialL->setBuddy(m_pInitialLE);
 
 	mainLayout -> addWidget(m_pValuesGB);
-	m_pInitialLE -> setText( m_pAttribute -> getInitialValue() );
 
 
 	m_pScopeBG = new QButtonGroup(i18n("Visibility"), plainPage() );
@@ -145,7 +154,11 @@ bool UMLAttributeDialog::apply() {
 		m_pAttribute->setScope(Uml::Protected);
 	}
 
-	m_pAttribute->setTypeName( m_pTypeCB->currentText() );
+	QString typeName = m_pTypeCB->currentText();
+	// TODO: The type of UMLAttributes is just a "passive" string.
+	// UMLAttribute should be enhanced to give the user the choice
+	// of referencing existing UMLClassifiers instead.
+	m_pAttribute->setTypeName( typeName );
 	m_pAttribute->setInitialValue( m_pInitialLE->text() );
 	QString name = m_pNameLE->text();
 	if( name.length() == 0 ) {
@@ -155,6 +168,8 @@ bool UMLAttributeDialog::apply() {
 		return false;
 	}
 
+	m_pAttribute->setStereotype( m_pStereoTypeLE->text() );
+
 	UMLObjectList list= pConcept->findChildObject(Uml::ot_Attribute, name);
 	if( list.count() != 0 && list.findRef( m_pAttribute ) ) {
 		KMessageBox::error(this, i18n("The attribute name you have chosen is already being used in this operation."),
@@ -165,7 +180,9 @@ bool UMLAttributeDialog::apply() {
 	m_pAttribute->setName(name);
 	m_pAttribute->setStatic( m_pStaticCB->isChecked() );
 
-	UMLApp::app()->getDocument()->createDatatype( m_pTypeCB->currentText() );
+	UMLDoc *umldoc = UMLApp::app()->getDocument();
+	if (umldoc->findUMLObject(typeName) == NULL)
+		umldoc->createDatatype( m_pTypeCB->currentText() );
 
 	return true;
 }
