@@ -81,19 +81,23 @@ public:
 	 * for the current project instead of the widget documentation.
 	 *
 	 * This is usually called before displaying a properties dialog.
+	 *
+	 * @param clear	If true, show the documentation of current project
+	 * @param startup	If true, no setModified(true) calls will be done and nothing is pushed to the undo stack
 	 */
-	void updateDocumentation( bool clear = false );
+	void updateDocumentation( bool clear = false, bool startup = false );
 
 
 	/**
 	 *  Re-initializes the class for a new document.
 	 */
 	void newDocumentation( );
-
+	
 	/**
 	 * Checks if the user is typing in the documentation edit window
 	 */
 	bool isTyping();
+
 private:
 	/**
 	 * Used internally to know which type of object we are showing
