@@ -19,7 +19,7 @@ UMLEnum::UMLEnum(const QString& name, int id) : UMLClassifier(name, id) {
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 UMLEnum::~UMLEnum() {
-  	m_EnumLiteralList.clear();
+	m_EnumLiteralList.clear();
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 bool UMLEnum::operator==( UMLEnum & rhs ) {
@@ -28,29 +28,25 @@ bool UMLEnum::operator==( UMLEnum & rhs ) {
 	}
 	return UMLClassifier::operator==(rhs);
 }
-////////////////////////////////////////////////////////////////////////////////////////////////////
-QString UMLEnum::uniqChildName(UMLObject_Type type) {
-	QString currentName;
-	if (type == ot_Association) {
-		return UMLCanvasObject::uniqChildName(type);
-	} else if (type == ot_EnumLiteral) {
-		currentName = i18n("new_literal");
-	} else if (type == ot_Stereotype) {
-		currentName = i18n("new_stereotype");
-	} else {
-		kdWarning() << "uniqChildName() called for unknown child type" << endl;
-	}
 
-	QString name = currentName;
-	for (int number = 1; findChildObject(type, name).count(); ++number) {
-		name = currentName + "_" + QString::number(number);
-	}
-	return name;
+void UMLEnum::copyInto(UMLEnum *rhs) const
+{
+	UMLClassifier::copyInto(rhs);
+
+	m_EnumLiteralList.copyInto(&(rhs->m_EnumLiteralList));
 }
-////////////////////////////////////////////////////////////////////////////////////////////////////
-bool UMLEnum::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
-	QDomElement enumElement = qDoc.createElement("UML:Enum");
-	bool status = UMLObject::saveToXMI(qDoc, enumElement);
+
+UMLObject* UMLEnum::clone() const
+{
+	UMLEnum *clone = new UMLEnum();
+	copyInto(clone);
+
+	return clone;
+}
+
+
+void UMLEnum::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
+	QDomElement enumElement = UMLObject::save("UML:Enumeration", qDoc);
 	//save operations
 	UMLClassifierListItem* pEnumLiteral = 0;
 	for ( pEnumLiteral = m_EnumLiteralList.first(); pEnumLiteral != 0;
@@ -58,38 +54,25 @@ bool UMLEnum::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
 		pEnumLiteral->saveToXMI(qDoc, enumElement);
 	}
 	qElement.appendChild(enumElement);
-	return status;
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
-bool UMLEnum::loadFromXMI(QDomElement& element) {
-	if( !UMLObject::loadFromXMI(element) ) {
-		return false;
-	}
-
+bool UMLEnum::load(QDomElement& element) {
 	QDomNode node = element.firstChild();
 	QDomElement tempElement = node.toElement();
 	while( !tempElement.isNull() ) {
 		QString tag = tempElement.tagName();
-		if (tag == "UML:EnumLiteral") {
+		if (tagEq(tag, "EnumerationLiteral") ||
+		    tagEq(tag, "EnumLiteral")) {   // for backward compatibility
 			UMLEnumLiteral* pEnumLiteral = new UMLEnumLiteral(this);
 			if( !pEnumLiteral->loadFromXMI(tempElement) ) {
 				return false;
 			}
 			m_EnumLiteralList.append(pEnumLiteral);
 		} else if (tag == "stereotype") {
-			UMLStereotype* newStereotype = new UMLStereotype(this);
-			if ( !newStereotype->loadFromXMI(tempElement) ) {
-				return false;
-			}
-			QString listTypeString = tempElement.attribute("listtype", "-1");
-			UMLObject_Type listType = (UMLObject_Type)listTypeString.toInt();
-			if (listType == ot_EnumLiteral) {
-				m_EnumLiteralList.append(newStereotype);
-			} else {
-				kdWarning() << "unknown listtype with stereotype:" << listType << endl;
-			}
+			kdDebug() << "UMLEnum::load(" << m_Name
+				  << "): losing old-format stereotype." << endl;
 		} else {
-			kdWarning() << "loading unknown child type in UMLClass::loadFromXMI" << endl;
+			kdWarning() << "unknown child type in UMLEnum::load" << endl;
 		}
 		node = node.nextSibling();
 		tempElement = node.toElement();
@@ -103,8 +86,8 @@ void UMLEnum::init() {
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 UMLObject* UMLEnum::addEnumLiteral(QString name, int id) {
-  	UMLEnumLiteral* literal = new UMLEnumLiteral(this, name, id);
-  	m_EnumLiteralList.append(literal);
+	UMLEnumLiteral* literal = new UMLEnumLiteral(this, name, id);
+	m_EnumLiteralList.append(literal);
 	emit modified();
 	connect(literal,SIGNAL(modified()),this,SIGNAL(modified()));
 	emit enumLiteralAdded(literal);
@@ -160,37 +143,33 @@ int UMLEnum::removeEnumLiteral(UMLObject* literal) {
 	return m_EnumLiteralList.count();
 }
 ////////////////////////////////////////////////////////////////////////////////////////////////////
-bool UMLEnum::addStereotype(UMLStereotype* newStereotype, UMLObject_Type list, IDChangeLog* log /* = 0*/) {
-	QString name = newStereotype->getName();
-	if (findChildObject(Uml::ot_Template, name).count() == 0) {
-		newStereotype->parent()->removeChild(newStereotype);
-		this->insertChild(newStereotype);
-		if (list == ot_EnumLiteral) {
-			m_EnumLiteralList.append(newStereotype);
-			emit modified();
-			connect(newStereotype, SIGNAL(modified()), this, SIGNAL(modified()));
-		} else {
-			kdWarning() << "unknown list type in addStereotype()" << endl;
-		}
-		return true;
-	} else if (log) {
-		log->removeChangeByNewID( newStereotype->getID() );
-		delete newStereotype;
+UMLEnumLiteral* UMLEnum::takeEnumLiteral(UMLEnumLiteral* el) {
+	int index = m_EnumLiteralList.findRef( el );
+	el = (index == -1 ? 0 : dynamic_cast<UMLEnumLiteral*>(m_EnumLiteralList.take( )));
+	if (el) {
+		emit enumLiteralRemoved(el);
+		emit modified();
 	}
-	return false;
+	return el;
 }
-////////////////////////////////////////////////////////////////////////////////////////////////////
-UMLObjectList UMLEnum::findChildObject(UMLObject_Type t, QString n) {
-  	UMLObjectList list;
- 	if (t == ot_Association) {
-		return UMLClassifier::findChildObject(t, n);
- 	} else if (t == ot_EnumLiteral || t == ot_Stereotype) {
-  		UMLClassifierListItem * obj=0;
-  		for(obj=m_EnumLiteralList.first();obj != 0;obj=m_EnumLiteralList.next()) {
-  			if(obj->getBaseType() == t && obj -> getName() == n)
+
+UMLObjectList UMLEnum::findChildObject(UMLObject_Type t, QString n,
+				       bool seekStereo /* = false */) {
+	UMLObjectList list;
+	if (t == ot_Association) {
+		return UMLClassifier::findChildObject(t, n, seekStereo);
+	} else if (t == ot_EnumLiteral) {
+		UMLClassifierListItem * obj=0;
+		for(obj=m_EnumLiteralList.first();obj != 0;obj=m_EnumLiteralList.next()) {
+			if (obj->getBaseType() != t)
+				continue;
+			if (seekStereo) {
+				if (obj->getStereotype() == n)
+					list.append( obj );
+			} else if (obj->getName() == n)
 				list.append( obj );
 		}
- 	} else {
+	} else {
 		kdWarning() << "finding child object of unknown type" <<t<<" (requested name = "<<n<<")"<<endl;
 	}
 
