@@ -49,23 +49,22 @@ public:
 	 * Overloaded '==' operator.
 	 */
   	bool operator==(UMLEnum& rhs);
-  
+
 	/**
-	 * Returns a name for the new enumliteral
-	 * appended with a number if the default name is
-	 * taken e.g. new_literal, new_literal_1 etc
+	 * Copy the internal presentation of this object into the new
+	 * object.
 	 */
-	virtual QString uniqChildName(const UMLObject_Type type);
+	virtual void copyInto(UMLEnum *rhs) const;
+
+	/**
+	 * Make a clone of this object.
+	 */
+	virtual UMLObject* clone() const;
 
 	/**
 	 * Creates the <UML:Enum> element including its enumliterals.
 	 */
-	virtual bool saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
-
-	/**
-	 * Loads the <UML:Enum> element including its enumliterals.
-	 */
-	virtual bool loadFromXMI( QDomElement & element );
+	virtual void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
 
 	virtual bool isInterface () { return false; }
 
@@ -87,7 +86,7 @@ public:
 	 * @return	True if the enumliteral was sucessfully added.
 	 */
 	bool addEnumLiteral(UMLEnumLiteral* Att, IDChangeLog* Log = 0);
-	
+
 	/**
 	 * Adds an enumliteral to the enum, at the given position.
 	 * If position is negative or too large, the enumliteral is added
@@ -108,6 +107,15 @@ public:
 	 *		Returns -1 if the given enumliteral was not found.
 	 */
 	int removeEnumLiteral(UMLObject *a);
+	/**
+	 * Take and return an enumliteral from class.
+	 * It is the callers responsibility to pass on ownership of
+	 * the returned enumliteral (or to delete the enumliteral)
+	 *
+	 * @param  el enumliteral to tkae
+	 * @return pointer to the enumliteral or null if not found.
+	 */
+	UMLEnumLiteral* takeEnumLiteral(UMLEnumLiteral* el);
 
 	/**
 	 * Returns the number of enumliterals for the class.
@@ -135,9 +143,12 @@ public:
 	 *
 	 * @param t		The type to find.
 	 * @param n		The name of the object to find.
+	 * @param seekStereo	Set this true if we should look at the object's
+	 *			stereotype instead of its name.
 	 * @return	List of objects found.  Will be empty if none found.
 	 */
-	 virtual UMLObjectList findChildObject(UMLObject_Type t, QString n);
+	 virtual UMLObjectList findChildObject(UMLObject_Type t, QString n,
+	 				       bool seekStereo = false);
 
 	/**
 	 * Find an enumliteral
@@ -147,22 +158,16 @@ public:
 	 */
 	virtual UMLObject* findChildObject(int id);
 
-	/**
-	 * Add an already created stereotype to the list identified by the
-	 * given UMLObject_type.
-	 *
-	 * @param newStereotype	Pointer to the UMLStereotype to add.
-	 * @param list		The object type for the list on which to add.
-	 * @param log		Pointer to the IDChangeLog.
-	 * @return	True if the newStereotype was successfully added.
-	 */
-	virtual bool addStereotype(UMLStereotype* newStereotype, UMLObject_Type list, IDChangeLog* log = 0);
-
 signals:
 	void enumLiteralAdded(UMLObject*);
 	void enumLiteralRemoved(UMLObject*);
 
 protected:
+	/**
+	 * Loads the <UML:Enum> element including its enumliterals.
+	 */
+	bool load( QDomElement & element );
+
 	/**
 	 * List of all the enumliterals in this class.
 	 */
@@ -175,4 +180,5 @@ private:
 
 };
 
-#endif // ENUM_H 
+#endif // ENUM_H
+
