@@ -14,9 +14,10 @@
 #include <config.h>
 #endif
 
-#include "dialogs/settingsdlg.h"
+#include "optionstate.h"
 
 #include <qmap.h>
+#include <qdict.h>
 #include <qprogressbar.h>
 
 #include <kdockwidget.h>
@@ -24,15 +25,19 @@
 #include <kurl.h>
 
 // forward declaration of the UML classes
+class AlignToolBar;
 class CodeDocument;
 class CodeGenerator;
 class CodeGenerationPolicy;
+class GeneratorInfo;
 class DocWindow;
+class UMLClassifier;
 class UMLDoc;
 class UMLListView;
 class UMLView;
 class WorkToolBar;
 class InfoWidget;
+class SettingsDlg;
 
 class KPlayerPopupSliderAction;
 
@@ -100,6 +105,13 @@ public:
 	 */
 	UMLDoc *getDocument() const;
 
+	/**
+	 * Returns a pointer to the list view.
+	 *
+	 * @return	The listview being used.
+	 */
+	UMLListView* getListView();
+
 	/**
 	 * Returns the toolbar being used.
 	 *
@@ -445,6 +457,20 @@ public slots:
 	 */
 	void slotEditPaste();
 
+// #if !KDE_IS_VERSION(3,1,90)
+	/**
+	 * Toggles the toolbar.
+	 * Deprecated. For compatibility with KDE 3.1, remove if we stop supporting KDE 3.1
+	 */
+	void slotViewToolBar();
+
+	/**
+	 * Toggles the statusbar.
+	 * Deprecated. For compatibility with KDE 3.1, remove if we stop supporting KDE 3.1
+	 */
+	void slotViewStatusBar();
+// #endif
+
 	/**
 	 * Changes the statusbar contents for the standard label
 	 * permanently, used to indicate current actions.
@@ -722,7 +748,7 @@ private:
 	/**
 	 * Listview shows the current open file.
 	 */
-	UMLListView* listView;
+	UMLListView* m_listView;
 
 	/**
 	 * The widget which shows the diagrams.
@@ -790,9 +816,15 @@ private:
 	KAction* classWizard;
 	KAction* deleteSelectedWidget;
 	KAction* deleteDiagram;
+//Remove these once we stop supporting KDE 3.1
+// #if !KDE_IS_VERSION(3,1,90)
+	KToggleAction* viewToolBar;
+	KToggleAction* viewStatusBar;
+// #endif
 	WorkToolBar* toolsbar;
 	QTimer* m_clipTimer;
 	QTimer* m_copyTimer;
+	AlignToolBar* m_alignToolBar;
 
 	KStatusBarLabel* m_statusLabel;
 
@@ -801,7 +833,7 @@ private:
 	 * True if the application is opening an existing document
 	 */
 	bool loading;
-	SettingsDlg::OptionState optionState;
+	Settings::OptionState optionState;
 
 	/**
 	 * Blank widget, displayed when there are no diagrams
@@ -824,7 +856,7 @@ public:
 	 * the global UML settings dialogue
 	 */
 	SettingsDlg* dlg;
-	SettingsDlg::OptionState getOptionState() {
+	Settings::OptionState getOptionState() {
 		return optionState;
 	}
 
