@@ -13,7 +13,6 @@
 #include "umllistviewitemlist.h"
 #include "umllistviewitem.h"
 #include <klistview.h>
-#include <qpixmap.h>
 
 /**
  *	This is one of the main classes used in this program.
@@ -75,7 +74,15 @@ class UMLListView : public KListView {
 		it_Protected_Method,
 		it_Public_Attribute,
 		it_Private_Attribute,
-		it_Protected_Attribute
+		it_Protected_Attribute,
+		it_Diagram_Activity,
+		it_Diagram_Class,
+		it_Diagram_Collaboration,
+		it_Diagram_Component,
+		it_Diagram_Deployment,
+		it_Diagram_Sequence,
+		it_Diagram_State,
+		it_Diagram_Usecase
 	};
 
 	/**
@@ -244,16 +251,39 @@ class UMLListView : public KListView {
 	 */
 	void setStartedCut(bool startedCut);
 
+	/**
+	 * Set the variable m_bStartedCopy.
+	 * NB: While m_bStartedCut is reset as soon as the Cut operation is done,
+	 *     the variable m_bStartedCopy is reset much later - upon pasting.
+	 */
+	void setStartedCopy(bool startedCopy);
+
+	/**
+	 * Return the variable m_bStartedCopy.
+	 */
+	bool startedCopy() const;
+
+	/**
+	 * Converts an object type enum to the equivalent list view type
+	 */
+	static Uml::ListView_Type convert_OT_LVT(Uml::UMLObject_Type ot);
+
+	/**
+	 * Moves an object given is unique ID and listview type into an
+	 * other listview parent item.
+	 * Also takes care of the corresponding move in the model.
+	 */
+	UMLListViewItem * moveObject(int srcId, Uml::ListView_Type srcType,
+				     UMLListViewItem *newParent);
+
 	void closeDatatypesFolder();
 
-	bool saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
+	void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
 
 	bool loadFromXMI( QDomElement & element );
 
 	bool loadChildrenFromXMI( UMLListViewItem * parent, QDomElement & element );
 
-	
-
  protected:
 	UMLListViewItem* rv;//root view
 	UMLListViewItem* ucv;//use case view item
@@ -265,7 +295,7 @@ class UMLListView : public KListView {
 	ListPopupMenu * m_pMenu;
 	QString oldText, message;
 	UMLDoc *m_doc;
-	bool loading, m_bStartedCut, m_bIgnoreCancelRename;
+	bool loading, m_bStartedCut, m_bStartedCopy, m_bIgnoreCancelRename;
 
 	/**
 	 * Used when creating an attribute or an operation to stop it adding a second listViewItem
@@ -302,6 +332,14 @@ class UMLListView : public KListView {
 		QPixmap Public_Attribute;
 		QPixmap Private_Attribute;
 		QPixmap Protected_Attribute;
+		QPixmap Diagram_Activity;
+		QPixmap Diagram_Class;
+		QPixmap Diagram_Collaboration;
+		QPixmap Diagram_Component;
+		QPixmap Diagram_Deployment;
+		QPixmap Diagram_Sequence;
+		QPixmap Diagram_State;
+		QPixmap Diagram_Usecase;
 	}
 	m_Pixmaps;
 	void contentsMouseReleaseEvent(QMouseEvent * me);
@@ -335,20 +373,14 @@ class UMLListView : public KListView {
 	 */
 	static Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt);
 
-	/**
-	 * Converts an object type enum to the equivalent list view type
-	 */
-	static Uml::ListView_Type convert_OT_LVT(Uml::UMLObject_Type ot);
-
 	/**
 	 * Converts a list view type enum to the equivalent object type.
 	 *
 	 * @param lvt		The ListView_Type to convert.
-	 * @param ot		The converted UMLObject_Type.
-	 * @return	True if conversion was successful, i.e. the listview
-	 *		type has a UMLObject_Type representation.
+	 * @return	The converted UMLObject_Type if the listview type
+	 *		has a UMLObject_Type representation, else 0.
 	 */
-	static bool convert_LVT_OT(Uml::ListView_Type lvt, Uml::UMLObject_Type& ot);
+	static Uml::UMLObject_Type convert_LVT_OT(Uml::ListView_Type lvt);
 
 	/**
 	 * 	Loads the pixmaps to use in the list items.
