@@ -8,3 +8,15 @@
  ***************************************************************************/
 
 #include "umlnamespace.h"
+#include "qregexp.h"
+
+namespace Uml {
+
+    bool tagEq (QString tag, QString pattern) {
+	tag.remove( QRegExp("^\\w+:") );  // remove leading "UML:" or other
+	int patSections = pattern.contains( '.' ) + 1;
+	QString tagEnd = tag.section( '.', -patSections );
+	return (tagEnd.lower() == pattern.lower());
+    }
+
+}
