@@ -10,6 +10,7 @@
 #ifndef UMLNAMESPACE_H
 #define UMLNAMESPACE_H
 
+#include <qstring.h>
 
 //uncomment for use with Luis' diagram code
 //namespace Umbrello
@@ -70,7 +71,8 @@ namespace Uml {
 	    wt_Activity,		// does not have UMLObject representation
 	    wt_Component,		// has UMLObject representation
 	    wt_Artifact,		// has UMLObject representation
-	    wt_Node			// has UMLObject representation
+	    wt_Node,			// has UMLObject representation
+	    wt_Association		// has UMLObject representation
 	};
 
 	enum Diagram_Type
@@ -99,7 +101,7 @@ namespace Uml {
 	    at_Seq_Message,
 	    at_Coll_Message_Self,
 	    at_Seq_Message_Self,
-	    at_Implementation,
+	    at_Containment,
 	    at_Composition,
 	    at_Realization,
 	    at_UniAssociation,
@@ -187,6 +189,25 @@ namespace Uml {
 		sequence_message_asynchronous
 	};
 
-  }
+	/**
+	 * Constants used for indexing the roles of associations. 
+	 */
+	enum Role_Type { A, B };
+
+	/**
+	 * Direction of operation parameters:
+	 *   in = operation uses the parameter as an input value
+	 *   out = operation fills the parameter as a return value
+	 *   inout = operation both reads and writes the parameter
+	 * The numeric values of this enum are not currently saved to file.
+	 */
+	enum Parameter_Kind { pk_In, pk_InOut, pk_Out };
+
+	/**
+	 * Function for comparing tags in XMI files.
+	 */
+	bool tagEq (QString tag, QString pattern);
+
+}
 
 #endif
