@@ -13,7 +13,6 @@
 #include <ktoolbar.h>
 #include "umlnamespace.h"
 
-#include <qmap.h>
 
 /**
  * This is the toolbar that is displayed on the right-hand side of the program
@@ -27,22 +26,6 @@ class WorkToolBar : public KToolBar {
 	Q_OBJECT
 public:
 
-	/**
-	 * Enumeration of all available edit tools.
-	 */
-	enum EditTool {
-		Select = 0,
-		Generalization, Aggregation, Dependency, Association,
-		CollMessage, SeqMessage,
-		Composition, UniAssociation,
-		StateTransition, ActivityTransition,
-		Anchor, Note, Box, Text,
-		Actor, UseCase, Class, Interface,
-		Package, Component, Artifact, Object,
-		InitialState, State, EndState,
-		InitialActivity, Activity, EndActivity, Branch, Fork
-	};
-
 	/**
 	 * Creates a work tool bar.
 	 *
@@ -64,13 +47,6 @@ public:
 	 */
 	void setDefaultTool();
 
-	/**
-	 * Returns the currently selected EditTool.
-	 *
-	 * @return	The currently selected EditTool.
-	 */
-	EditTool currentTool();
-
 	/**
 	 * Standard deconstructor.
 	 */
@@ -87,6 +63,7 @@ public:
 	    tbb_Aggregation,
 	    tbb_Dependency,
 	    tbb_Association,
+	    tbb_Containment,
 	    tbb_Coll_Message,
 	    tbb_Seq_Message_Synchronous,
 	    tbb_Seq_Message_Asynchronous,
@@ -145,6 +122,7 @@ private:
 		QPixmap Case;
 		QPixmap Component;
 		QPixmap Composition;
+		QPixmap Containment;
 		QPixmap Dependency;
 		QPixmap EndState;
 		QPixmap Fork;
@@ -189,7 +167,6 @@ private:
 
 signals:
 	void sigButtonChanged(int);
-	void toolSelected(WorkToolBar::EditTool);
 public slots:
 	void slotCheckToolBar(Uml::Diagram_Type dt);
 	void buttonChanged(int b);
